<?php
/**
 * Plugin Name: Meta Box
 * Plugin URI:  https://metabox.io
 * Description: Create custom meta boxes and custom fields in WordPress.
 * Version:     5.3.3
 * Author:      MetaBox.io
 * Author URI:  https://metabox.io
 * License:     GPL2+
 * Text Domain: meta-box
 * Domain Path: /languages/
 *
 * @package Meta Box
 */

if ( defined( 'ABSPATH' ) && ! defined( 'RWMB_VER' ) ) {
    register_activation_hook( __FILE__, 'rwmb_check_php_version' );

    /**
     * Display notice for old PHP version.
     */
    function rwmb_check_php_version() {
        if ( version_compare( phpversion(), '5.3', '<' ) ) {
            die( esc_html__( 'Meta Box requires PHP version 5.3+. Please contact your host to upgrade.', 'meta-box' ) );
        }
    }

    require_once dirname( __FILE__ ) . '/inc/loader.php';
    $rwmb_loader = new RWMB_Loader();
    $rwmb_loader->init();


    add_filter( 'rwmb_meta_boxes', function ( $meta_boxes ) {

    $prefix = '_cmb_';


  // Open Code

    $meta_boxes[] = array(
        'id'         => 'post_setting',
        'title'      => 'Post Setting',
        'pages'      => array('post'), // Post type
        'context'    => 'normal',
        'priority'   => 'high',
        'show_names' => true, // Show field names on the left
        //'show_on'    => array( 'key' => 'id', 'value' => array( 2, ), ), // Specific post IDs to display this metabox
        'fields' => array(   
            array(
                'name' => 'Featured Image',
                'desc' => 'Input Thumbnail for Blog Grid 1',
                'id'   => $prefix . 'featured_image',
                'type'    => 'file',
            ),
            array(
                'name' => 'Featured Image 2',
                'desc' => 'Input Thumbnail for sidebar recent posts',
                'id'   => $prefix . 'featured_image_2',
                'type'    => 'file',
            ), 
            array(
                'name' => 'Title 2',
                'desc' => 'Input title for sidebar recent posts',
                'id'   => $prefix . 'title_2',
                'type'    => 'text',
            ),
            array(
                'name' => 'Featured Image 3',
                'desc' => 'Input Thumbnail for Blog Grid 2',
                'id'   => $prefix . 'featured_image_3',
                'type'    => 'file',
            ),
            array(
                'name' => 'Featured Image 4',
                'desc' => 'Input Thumbnail for Blog Grid 3',
                'id'   => $prefix . 'featured_image_4',
                'type'    => 'file',
            ),
            array(
                'name' => 'Featured Image 6',
                'desc' => 'Input Thumbnail for Blog on Home One',
                'id'   => $prefix . 'featured_image_6',
                'type'    => 'file',
            ),
        )
    );
    $meta_boxes[] = array(
        'id'         => 'cause_setting',
        'title'      => 'Cause Setting',
        'pages'      => array('cause'), // Post type
        'context'    => 'normal',
        'priority'   => 'high',
        'show_names' => true, // Show field names on the left
        //'show_on'    => array( 'key' => 'id', 'value' => array( 2, ), ), // Specific post IDs to display this metabox
        'fields' => array(
            array(
                'name' => 'Featured Image 2',
                'desc' => 'Input Thumbnail for Cause One',
                'id'   => $prefix . 'c_featured_image_2',
                'type'    => 'file',
            ),
            array(
                'name' => 'Donation Raised Number',
                'desc' => 'Input Donation Raised Number for Causes',
                'id'   => $prefix . 'donation_raised_number',
                'type'    => 'text',
            ),
            array(
                'name' => 'Donation Raised Text',
                'desc' => 'Input Donation Raised Text for Causes',
                'id'   => $prefix . 'donation_raised_text',
                'type'    => 'text',
            ),
            array(
                'name' => 'After Donation Raised',
                'desc' => 'Input Text After Donation Raised for Causes Three',
                'id'   => $prefix . 'after_donation_raised',
                'type'    => 'text',
            ),
            array(
                'name' => 'Before Donation Goal',
                'desc' => 'Input Text Before Donation Goal for Causes',
                'id'   => $prefix . 'before_donation_goal',
                'type'    => 'text',
            ),
            array(
                'name' => 'Before Donation Goal 2',
                'desc' => 'Input Text Before Donation Goal for Causes Three',
                'id'   => $prefix . 'before_donation_goal_2',
                'type'    => 'text',
            ),
            array(
                'name' => 'Donation Goal',
                'desc' => 'Input Donation Goal for Causes',
                'id'   => $prefix . 'donation_goal',
                'type'    => 'text',
            ),
            array(
                'name' => 'Donation Goal Text',
                'desc' => 'Input Donation Goal Text for Causes Two',
                'id'   => $prefix . 'donation_goal_text',
                'type'    => 'text',
            ),
            array(
                'name' => 'Raised Percent',
                'desc' => 'Input Donation Raised Percent for Causes Three and Four',
                'id'   => $prefix . 'raised_percent',
                'type'    => 'text',
            ),
            array(
                'name' => 'location',
                'desc' => 'Input location for Causes',
                'id'   => $prefix . 'location',
                'type'    => 'text',
            ),
            array(
                'name' => 'Featured Image 3',
                'desc' => 'Input Thumbnail for Causes Two',
                'id'   => $prefix . 'c_featured_image_3',
                'type'    => 'file',
            ),
            array(
                'name' => 'Featured Image 4',
                'desc' => 'Input Thumbnail for Causes Three',
                'id'   => $prefix . 'c_featured_image_4',
                'type'    => 'file',
            ),
            array(
                'name' => 'Featured Image 5',
                'desc' => 'Input Thumbnail for Causes Four',
                'id'   => $prefix . 'c_featured_image_5',
                'type'    => 'file',
            ),
            array(
                'name' => 'Featured Image 6',
                'desc' => 'Input Thumbnail for Causes Home Three',
                'id'   => $prefix . 'c_featured_image_6',
                'type'    => 'file',
            ),
            array(
                'name' => 'Featured Image 7',
                'desc' => 'Input Thumbnail for Recent Causes on sidebar',
                'id'   => $prefix . 'c_featured_image_7',
                'type'    => 'file',
            ),
            array(
                'name' => 'Short Title',
                'desc' => 'Input short title for Recent Causes on sidebar',
                'id'   => $prefix . 'c_short_title',
                'type'    => 'text',
            ),
        )
    );
    $meta_boxes[] = array(
        'id'         => 'event_setting',
        'title'      => 'Event Setting',
        'pages'      => array('event'), // Post type
        'context'    => 'normal',
        'priority'   => 'high',
        'show_names' => true, // Show field names on the left
        //'show_on'    => array( 'key' => 'id', 'value' => array( 2, ), ), // Specific post IDs to display this metabox
        'fields' => array(
            array(
                'name' => 'Featured Image 2',
                'desc' => 'Input Thumbnail for Events page',
                'id'   => $prefix . 'e_featured_image_2',
                'type'    => 'file',
            ),
            array(
                'name' => 'Description',
                'desc' => 'Input description for Events',
                'id'   => $prefix . 'e_description',
                'type'    => 'textarea',
            ),
            array(
                'name' => 'location',
                'desc' => 'Input location for Events',
                'id'   => $prefix . 'e_location',
                'type'    => 'text',
            ),
        )
    );
    $meta_boxes[] = array(
        'id'         => 'service_setting',
        'title'      => 'Service Setting',
        'pages'      => array('service'), // Post type
        'context'    => 'normal',
        'priority'   => 'high',
        'show_names' => true, // Show field names on the left
        //'show_on'    => array( 'key' => 'id', 'value' => array( 2, ), ), // Specific post IDs to display this metabox
        'fields' => array(
            array(
                'name' => 'Featured Image 2',
                'desc' => 'Input Thumbnail for Services page',
                'id'   => $prefix . 's_featured_image_2',
                'type'    => 'file',
            ),
            array(
                'name' => 'Title 2',
                'desc' => 'Input title 2 for Services on Home Four',
                'id'   => $prefix . 'sv_title_2',
                'type'    => 'textarea',
            ),
            array(
                'name' => 'Icon',
                'desc' => 'Input icon for single, home, services page',
                'id'   => $prefix . 'sv_icon_0',
                'type'    => 'file',
            ),
            array(
                'name' => 'Icon 2',
                'desc' => 'Input icon for Services on Home Four',
                'id'   => $prefix . 'sv_icon',
                'type'    => 'file',
            ),
        )
    );
    $meta_boxes[] = array(
        'id'         => 'story_setting',
        'title'      => 'Story Setting',
        'pages'      => array('story'), // Post type
        'context'    => 'normal',
        'priority'   => 'high',
        'show_names' => true, // Show field names on the left
        //'show_on'    => array( 'key' => 'id', 'value' => array( 2, ), ), // Specific post IDs to display this metabox
        'fields' => array(
            array(
                'name' => 'Featured Image 2',
                'desc' => 'Input Thumbnail for Story page',
                'id'   => $prefix . 'st_featured_image_2',
                'type'    => 'file',
            ),           
            array(
                'name' => 'Donation Goal',
                'desc' => 'Input Donation Goal for single story',
                'id'   => $prefix . 'st_donation_goal',
                'type'    => 'text',
            ),
            array(
                'name' => 'Donation Goal Text',
                'desc' => 'Input Donation Goal Text for single story',
                'id'   => $prefix . 'st_donation_goal_text',
                'type'    => 'text',
            ),
            array(
                'name' => 'Raised Percent',
                'desc' => 'Input Donation Raised Percent for single story',
                'id'   => $prefix . 'st_raised_percent',
                'type'    => 'text',
            ),
            array(
                'name' => 'Donation Raised',
                'desc' => 'Input Donation Raised show on donate form',
                'id'   => $prefix . 'st_donation_raised',
                'type'    => 'text',
            ),
            array(
                'name' => 'Donation Raised Text',
                'desc' => 'Input Donation Raised Text for single story',
                'id'   => $prefix . 'st_donation_raised_text',
                'type'    => 'text',
            ),
            array(
                'name' => 'Location',
                'desc' => 'Input location for single story',
                'id'   => $prefix . 'st_location',
                'type'    => 'text',
            ),
        )
    );
    $meta_boxes[] = array(
        'id'         => 'priority_setting',
        'title'      => 'Priority Setting',
        'pages'      => array('priority'), // Post type
        'context'    => 'normal',
        'priority'   => 'high',
        'show_names' => true, // Show field names on the left
        //'show_on'    => array( 'key' => 'id', 'value' => array( 2, ), ), // Specific post IDs to display this metabox
        'fields' => array(
            array(
                'name' => 'Featured Image 2',
                'desc' => 'Input Thumbnail for Priotities page',
                'id'   => $prefix . 'pr_featured_image_2',
                'type'    => 'file',
            ),
            array(
                'name' => 'Description',
                'desc' => 'Input description for Priotities page',
                'id'   => $prefix . 'pr_description',
                'type'    => 'textarea',
            ),
        )
    );
    // Add other metaboxes as needed
    
    return $meta_boxes;
});
}
