<?php
    /**
     * ReduxFramework Sample Config File
     * For full documentation, please visit: http://docs.reduxframework.com/
     */

    if ( ! class_exists( 'Redux' ) ) {
        return;
    }


    // This is your option name where all the Redux data is stored.
    $opt_name = "redux_demo";

    // This line is only for altering the demo. Can be easily removed.
    $opt_name = apply_filters( 'redux_demo/opt_name', $opt_name );

    /*
     *
     * --> Used within different fields. Simply examples. Search for ACTUAL DECLARATION for field examples
     *
     */

    $sampleHTML = '';
    if ( file_exists( dirname( __FILE__ ) . '/info-html.html' ) ) {
        Redux_Functions::initWpFilesystem();

        global $wp_filesystem;

        $sampleHTML = $wp_filesystem->get_contents( dirname( __FILE__ ) . '/info-html.html' );
    }

    // Background Patterns Reader
    $sample_patterns_path = ReduxFramework::$_dir . '../sample/patterns/';
    $sample_patterns_url  = ReduxFramework::$_url . '../sample/patterns/';
    $sample_patterns      = array();
    
    if ( is_dir( $sample_patterns_path ) ) {

        if ( $sample_patterns_dir = opendir( $sample_patterns_path ) ) {
            $sample_patterns = array();

            while ( ( $sample_patterns_file = readdir( $sample_patterns_dir ) ) !== false ) {

                if ( stristr( $sample_patterns_file, '.png' ) !== false || stristr( $sample_patterns_file, '.jpg' ) !== false ) {
                    $name              = explode( '.', $sample_patterns_file );
                    $name              = str_replace( '.' . end( $name ), '', $sample_patterns_file );
                    $sample_patterns[] = array(
                        'alt' => $name,
                        'img' => $sample_patterns_url . $sample_patterns_file
                    );
                }
            }
        }
    }

    /**
     * ---> SET ARGUMENTS
     * All the possible arguments for Redux.
     * For full documentation on arguments, please refer to: https://github.com/ReduxFramework/ReduxFramework/wiki/Arguments
     * */

    $theme = wp_get_theme(); // For use with some settings. Not necessary.

    $args = array(
        // TYPICAL -> Change these values as you need/desire
        'opt_name'             => $opt_name,
        // This is where your data is stored in the database and also becomes your global variable name.
        'display_name'         => $theme->get( 'Name' ),
        // Name that appears at the top of your panel
        'display_version'      => $theme->get( 'Version' ),
        // Version that appears at the top of your panel
        'menu_type'            => 'menu',
        //Specify if the admin menu should appear or not. Options: menu or submenu (Under appearance only)
        'allow_sub_menu'       => true,
        // Show the sections below the admin menu item or not
        'menu_title'           => __( 'Charitxa Options', 'redux-framework-demo' ),
        'page_title'           => __( 'Charitxa Options', 'redux-framework-demo' ),
        // You will need to generate a Google API key to use this feature.
        // Please visit: https://developers.google.com/fonts/docs/developer_api#Auth
        'google_api_key'       => '',
        // Set it you want google fonts to update weekly. A google_api_key value is required.
        'google_update_weekly' => false,
        // Must be defined to add google fonts to the typography module
        'async_typography'     => false,
        // Use a asynchronous font on the front end or font string
        //'disable_google_fonts_link' => true,                    // Disable this in case you want to create your own google fonts loader
        'admin_bar'            => true,
        // Show the panel pages on the admin bar
        'admin_bar_icon'       => 'dashicons-portfolio',
        // Choose an icon for the admin bar menu
        'admin_bar_priority'   => 50,
        // Choose an priority for the admin bar menu
        'global_variable'      => '',
        // Set a different name for your global variable other than the opt_name
        'dev_mode'             => true,
        // Show the time the page took to load, etc
        'update_notice'        => true,
        // If dev_mode is enabled, will notify developer of updated versions available in the GitHub Repo
        'customizer'           => true,
        // Enable basic customizer support
        //'open_expanded'     => true,                    // Allow you to start the panel in an expanded way initially.
        //'disable_save_warn' => true,                    // Disable the save warning when a user changes a field

        // OPTIONAL -> Give you extra features
        'page_priority'        => null,
        // Order where the menu appears in the admin area. If there is any conflict, something will not show. Warning.
        'page_parent'          => 'themes.php',
        // For a full list of options, visit: http://codex.wordpress.org/Function_Reference/add_submenu_page#Parameters
        'page_permissions'     => 'manage_options',
        // permissions needed to access the options panel.
        'menu_icon'            => '',
        // Specify a custom URL to an icon
        'last_tab'             => '',
        // Force your panel to always open to a specific tab (by id)
        'page_icon'            => 'icon-themes',
        // Icon displayed in the admin panel next to your menu_title
        'page_slug'            => 'redux_demo',
        // Page slug used to denote the panel, will be based off page title then menu title then opt_name if not provided
        'save_defaults'        => true,
        // On load save the defaults to DB before user clicks save or not
        'default_show'         => false,
        // If true, shows the default value next to each field that is not the default value.
        'default_mark'         => '',
        // What to print by the field's title if the value shown is default. Suggested: *
        'show_import_export'   => true,
        // Shows the Import/Export panel when not used as a field.

        // CAREFUL -> These options are for advanced use only
        'transient_time'       => 60 * MINUTE_IN_SECONDS,
        'output'               => true,
        // Global shut-off for dynamic CSS output by the framework. Will also disable google fonts output
        'output_tag'           => true,
        // Allows dynamic CSS to be generated for customizer and google fonts, but stops the dynamic CSS from going to the head
        // 'footer_credit'     => '',                   // Disable the footer credit of Redux. Please leave if you can help it.

        // FUTURE -> Not in use yet, but reserved or partially implemented. Use at your own risk.
        'database'             => '',
        // possible: options, theme_mods, theme_mods_expanded, transient. Not fully functional, warning!
        'use_cdn'              => true,
        // If you prefer not to use the CDN for Select2, Ace Editor, and others, you may download the Redux Vendor Support plugin yourself and run locally or embed it in your code.

        // HINTS
        'hints'                => array(
            'icon'          => 'el el-question-sign',
            'icon_position' => 'right',
            'icon_color'    => 'lightgray',
            'icon_size'     => 'normal',
            'tip_style'     => array(
                'color'   => 'red',
                'shadow'  => true,
                'rounded' => false,
                'style'   => '',
            ),
            'tip_position'  => array(
                'my' => 'top left',
                'at' => 'bottom right',
            ),
            'tip_effect'    => array(
                'show' => array(
                    'effect'   => 'slide',
                    'duration' => '500',
                    'event'    => 'mouseover',
                ),
                'hide' => array(
                    'effect'   => 'slide',
                    'duration' => '500',
                    'event'    => 'click mouseleave',
                ),
            ),
        )
    );

    // ADMIN BAR LINKS -> Setup custom links in the admin bar menu as external items.
    $args['admin_bar_links'][] = array(
        'id'    => 'redux-docs',
        'href'  => 'http://docs.reduxframework.com/',
        'title' => __( 'Documentation', 'redux-framework-demo' ),
    );

    $args['admin_bar_links'][] = array(
        //'id'    => 'redux-support',
        'href'  => 'https://github.com/ReduxFramework/redux-framework/issues',
        'title' => __( 'Support', 'redux-framework-demo' ),
    );

    $args['admin_bar_links'][] = array(
        'id'    => 'redux-extensions',
        'href'  => 'reduxframework.com/extensions',
        'title' => __( 'Extensions', 'redux-framework-demo' ),
    );

    // SOCIAL ICONS -> Setup custom links in the footer for quick links in your panel footer icons.
    $args['share_icons'][] = array(
        'url'   => 'https://github.com/ReduxFramework/ReduxFramework',
        'title' => 'Visit us on GitHub',
        'icon'  => 'el el-github'
        //'img'   => '', // You can use icon OR img. IMG needs to be a full URL.
    );
    $args['share_icons'][] = array(
        'url'   => 'https://www.facebook.com/pages/Redux-Framework/243141545850368',
        'title' => 'Like us on Facebook',
        'icon'  => 'el el-facebook'
    );
    $args['share_icons'][] = array(
        'url'   => 'http://twitter.com/reduxframework',
        'title' => 'Follow us on Twitter',
        'icon'  => 'el el-twitter'
    );
    $args['share_icons'][] = array(
        'url'   => 'http://www.linkedin.com/company/redux-framework',
        'title' => 'Find us on LinkedIn',
        'icon'  => 'el el-linkedin'
    );

    // Panel Intro text -> before the form
    if ( ! isset( $args['global_variable'] ) || $args['global_variable'] !== false ) {
        if ( ! empty( $args['global_variable'] ) ) {
            $v = $args['global_variable'];
        } else {
            $v = str_replace( '-', '_', $args['opt_name'] );
        }
        $args['intro_text'] = sprintf( __( '<p>Did you know that Redux sets a global variable for you? To access any of your saved options from within your code you can use your global variable: <strong>$%1$s</strong></p>', 'redux-framework-demo' ), $v );
    } else {
        $args['intro_text'] = __( '<p>This text is displayed above the options panel. It isn\'t required, but more info is always better! The intro_text field accepts all HTML.</p>', 'redux-framework-demo' );
    }

    // Add content after the form.
    $args['footer_text'] = __( '', 'redux-framework-demo' );

    Redux::setArgs( $opt_name, $args );

    /*
     * ---> END ARGUMENTS
     */


    /*
     * ---> START HELP TABS
     */

    $tabs = array(
        array(
            'id'      => 'redux-help-tab-1',
            'title'   => __( 'Theme Information 1', 'redux-framework-demo' ),
            'content' => __( '<p>This is the tab content, HTML is allowed.</p>', 'redux-framework-demo' )
        ),
        array(
            'id'      => 'redux-help-tab-2',
            'title'   => __( 'Theme Information 2', 'redux-framework-demo' ),
            'content' => __( '<p>This is the tab content, HTML is allowed.</p>', 'redux-framework-demo' )
        )
    );
    Redux::setHelpTab( $opt_name, $tabs );

    // Set the help sidebar
    $content = __( '<p>This is the sidebar content, HTML is allowed.</p>', 'redux-framework-demo' );
    Redux::setHelpSidebar( $opt_name, $content );


    /*
     * <--- END HELP TABS
     */


    /*
     *
     * ---> START SECTIONS
     *
     */

    /*

        As of Redux 3.5+, there is an extensive API. This API can be used in a mix/match mode allowing for


     */

    // -> START Basic Fields
    // Open Code
            Redux::setSection( $opt_name, array(
                'icon' => 'el-icon-picture',
                'title' => __('Logo Settings', 'charitxa'),
                'fields' => array(                  
                    array(
                        'id' => 'logo',
                        'type' => 'media',
                        'url' => true,
                        'title' => __('Logo Upload', 'charitxa'),
                        'compiler' => 'true',
                        //'mode' => false, // Can be set to false to allow any media type, or can also be set to any mime type.
                        'desc' => __('', 'charitxa'),
                        'subtitle' => __('Upload your logo.', 'charitxa'),
                        'default' => ''
                    ),
                    array(
                        'id' => 'logo_white',
                        'type' => 'media',
                        'url' => true,
                        'title' => __('Logo White Upload', 'charitxa'),
                        'compiler' => 'true',
                        //'mode' => false, // Can be set to false to allow any media type, or can also be set to any mime type.
                        'desc' => __('', 'charitxa'),
                        'subtitle' => __('Upload your logo.', 'charitxa'),
                        'default' => ''
                    ),
                    array(
                        'id' => 'logo_two',
                        'type' => 'media',
                        'url' => true,
                        'title' => __('Logo Two Upload', 'charitxa'),
                        'compiler' => 'true',
                        //'mode' => false, // Can be set to false to allow any media type, or can also be set to any mime type.
                        'desc' => __('', 'charitxa'),
                        'subtitle' => __('Upload your logo.', 'charitxa'),
                        'default' => ''
                    ),
                    array(
                        'id' => 'logo_three',
                        'type' => 'media',
                        'url' => true,
                        'title' => __('Logo Three Upload', 'charitxa'),
                        'compiler' => 'true',
                        //'mode' => false, // Can be set to false to allow any media type, or can also be set to any mime type.
                        'desc' => __('', 'charitxa'),
                        'subtitle' => __('Upload your logo.', 'charitxa'),
                        'default' => ''
                    ),
                    array(
                        'id' => 'logo_four',
                        'type' => 'media',
                        'url' => true,
                        'title' => __('Logo Four Upload', 'charitxa'),
                        'compiler' => 'true',
                        //'mode' => false, // Can be set to false to allow any media type, or can also be set to any mime type.
                        'desc' => __('', 'charitxa'),
                        'subtitle' => __('Upload your logo.', 'charitxa'),
                        'default' => ''
                    ),
                    array(
                        'id' => 'logo_four_footer',
                        'type' => 'media',
                        'url' => true,
                        'title' => __('Logo Four Footer Upload', 'charitxa'),
                        'compiler' => 'true',
                        //'mode' => false, // Can be set to false to allow any media type, or can also be set to any mime type.
                        'desc' => __('', 'charitxa'),
                        'subtitle' => __('Upload your logo.', 'charitxa'),
                        'default' => ''
                    ),
                )
            ));
            Redux::setSection( $opt_name, array(
                'icon' => 'el-icon-picture',
                'title' => __('Header Settings', 'charitxa'),
                'fields' => array(   
                    array(
                        'id' => 'select_style',
                        'type' => 'select',
                        'title' => __('Select Style', 'charitxa'),
                        'subtitle' => __('Select Header Style', 'charitxa'),
                        'options'  => array(
                            '1' => 'Style 1',
                            '2' => 'Style 2',
                            '3' => 'Style 3',
                            '4' => 'Style 4'
                        ),
                        'default'  => '1', 
                    ),                
                    array(
                        'id' => 'top_left_text',
                        'type' => 'textarea',
                        'title' => __('Top Left Text', 'charitxa'),
                        'subtitle' => __('Input text', 'charitxa'),
                        'desc' => __('', 'charitxa'),
                        'default' => 'Donation Update: <b> $101,389</b> USD raised of <b> $100,000 </b> goal'
                    ),
                    array(
                        'id' => 'shop_now',
                        'type' => 'text',
                        'title' => __('Shop Now Button', 'charitxa'),
                        'subtitle' => __('Input text', 'charitxa'),
                        'desc' => __('', 'charitxa'),
                        'default' => 'Shop Now'
                    ),
                    array(
                        'id' => 'cart_icon',
                        'type' => 'text',
                        'title' => __('Cart Icon', 'charitxa'),
                        'subtitle' => __('Input cart icon', 'charitxa'),
                        'desc' => __('', 'charitxa'),
                        'default' => 'fas fa-shopping-cart'
                    ),
                    array(
                        'id' => 'link_shop_now',
                        'type' => 'text',
                        'title' => __('Link Shop', 'charitxa'),
                        'subtitle' => __('Input link', 'charitxa'),
                        'desc' => __('', 'charitxa'),
                        'default' => 'http://localhost/charitxa/?page_id=246'
                    ),
                    array(
                        'id' => 'become_volunteer',
                        'type' => 'text',
                        'title' => __('Become Volunteer Button', 'charitxa'),
                        'subtitle' => __('Input text', 'charitxa'),
                        'desc' => __('', 'charitxa'),
                        'default' => 'Become Volunteer'
                    ),
                    array(
                        'id' => 'help_icon',
                        'type' => 'text',
                        'title' => __('Help Icon', 'charitxa'),
                        'subtitle' => __('Input help icon', 'charitxa'),
                        'desc' => __('', 'charitxa'),
                        'default' => 'fal fa-hands-helping'
                    ),
                    array(
                        'id' => 'link_become_volunteer',
                        'type' => 'text',
                        'title' => __('Link Become Volunteer', 'charitxa'),
                        'subtitle' => __('Input link', 'charitxa'),
                        'desc' => __('', 'charitxa'),
                        'default' => 'http://localhost/charitxa/?page_id=238'
                    ),
                    array(
                        'id' => 'give_now',
                        'type' => 'text',
                        'title' => __('Give Now Button', 'charitxa'),
                        'subtitle' => __('Input text', 'charitxa'),
                        'desc' => __('', 'charitxa'),
                        'default' => 'Give Now'
                    ),
                    array(
                        'id' => 'h_donate_now',
                        'type' => 'text',
                        'title' => __('Doante Now Button', 'charitxa'),
                        'subtitle' => __('Input text', 'charitxa'),
                        'desc' => __('', 'charitxa'),
                        'default' => 'Donate Now'
                    ),
                    array(
                        'id' => 'shopping_bag_icon',
                        'type' => 'text',
                        'title' => __('Shopping Bag Icon', 'charitxa'),
                        'subtitle' => __('Input shopping bag icon', 'charitxa'),
                        'desc' => __('', 'charitxa'),
                        'default' => 'fas fa-shopping-bag'
                    ),
                    array(
                        'id' => 'shopping_bag_link',
                        'type' => 'text',
                        'title' => __('Link Shopping Bag', 'charitxa'),
                        'subtitle' => __('Input link', 'charitxa'),
                        'desc' => __('', 'charitxa'),
                        'default' => 'http://localhost/charitxa/?page_id=247'
                    ),
                    array(
                        'id' => 'get_involved',
                        'type' => 'text',
                        'title' => __('Get Involved Button', 'charitxa'),
                        'subtitle' => __('Input text', 'charitxa'),
                        'desc' => __('', 'charitxa'),
                        'default' => 'Get Involved'
                    ),
                    array(
                        'id' => 'get_involved_link',
                        'type' => 'text',
                        'title' => __('Link Get Involved', 'charitxa'),
                        'subtitle' => __('Input link', 'charitxa'),
                        'desc' => __('', 'charitxa'),
                        'default' => 'http://localhost/charitxa/?page_id=238'
                    ),
                    array(
                        'id' => 'social_1',
                        'type' => 'text',
                        'title' => __('Social 1 Icon', 'bidzen'),
                        'subtitle' => __('Social 1 Icon', 'bidzen'),
                        'default' => 'fab fa-facebook-f',
                    ), 
                    array(
                        'id' => 'link_social_1',
                        'type' => 'text',
                        'title' => __('Link Social 1', 'bidzen'),
                        'subtitle' => __('Link Social 1', 'bidzen'),
                        'default' => 'https://facebook.com',
                    ), 
                    array(
                        'id' => 'social_2',
                        'type' => 'text',
                        'title' => __('Social 2 Icon', 'bidzen'),
                        'subtitle' => __('Social 2 Icon', 'bidzen'),
                        'default' => 'fab fa-youtube',
                    ), 
                    array(
                        'id' => 'link_social_2',
                        'type' => 'text',
                        'title' => __('Link Social 2', 'bidzen'),
                        'subtitle' => __('Link Social 2', 'bidzen'),
                        'default' => 'https://youtube.com',
                    ), 
                    array(
                        'id' => 'social_3',
                        'type' => 'text',
                        'title' => __('Social 3 Icon', 'bidzen'),
                        'subtitle' => __('Social 3 Icon', 'bidzen'),
                        'default' => 'fab fa-instagram',
                    ), 
                    array(
                        'id' => 'link_social_3',
                        'type' => 'text',
                        'title' => __('Link Social 3', 'bidzen'),
                        'subtitle' => __('Link Social 3', 'bidzen'),
                        'default' => 'https://instagram.com',
                    ), 
                    array(
                        'id' => 'social_4',
                        'type' => 'text',
                        'title' => __('Social 4 Icon', 'bidzen'),
                        'subtitle' => __('Social 4 Icon', 'bidzen'),
                        'default' => 'fab fa-linkedin-in',
                    ), 
                    array(
                        'id' => 'link_social_4',
                        'type' => 'text',
                        'title' => __('Link Social 4', 'bidzen'),
                        'subtitle' => __('Link Social 4', 'bidzen'),
                        'default' => 'https://linkedin.com',
                    ),
                    array(
                        'id' => 'menu_1',
                        'type' => 'text',
                        'title' => __('Menu 1', 'charitxa'),
                        'subtitle' => __('Input text', 'charitxa'),
                        'desc' => __('', 'charitxa'),
                        'default' => 'About'
                    ),
                    array(
                        'id' => 'link_menu_1',
                        'type' => 'text',
                        'title' => __('Link Menu 1', 'charitxa'),
                        'subtitle' => __('Input link', 'charitxa'),
                        'desc' => __('', 'charitxa'),
                        'default' => 'http://localhost/charitxa/?page_id=236'
                    ),
                    array(
                        'id' => 'menu_2',
                        'type' => 'text',
                        'title' => __('Menu 2', 'charitxa'),
                        'subtitle' => __('Input text', 'charitxa'),
                        'desc' => __('', 'charitxa'),
                        'default' => 'Contact'
                    ),
                    array(
                        'id' => 'link_menu_2',
                        'type' => 'text',
                        'title' => __('Link Menu 2', 'charitxa'),
                        'subtitle' => __('Input link', 'charitxa'),
                        'desc' => __('', 'charitxa'),
                        'default' => 'http://localhost/charitxa/?page_id=238'
                    ),
                    array(
                        'id' => 'menu_3',
                        'type' => 'text',
                        'title' => __('Menu 3', 'charitxa'),
                        'subtitle' => __('Input text', 'charitxa'),
                        'desc' => __('', 'charitxa'),
                        'default' => 'Our Events'
                    ),
                    array(
                        'id' => 'link_menu_3',
                        'type' => 'text',
                        'title' => __('Link Menu 3', 'charitxa'),
                        'subtitle' => __('Input link', 'charitxa'),
                        'desc' => __('', 'charitxa'),
                        'default' => 'http://localhost/charitxa/?page_id=155'
                    ),
                )
            ));
            Redux::setSection( $opt_name, array(
                'icon' => 'el-icon-list',
                'title' => __('Blog Settings', 'charitxa'),
                'fields' => array(
                    array(
                        'id' => 'blog_home_text',
                        'type' => 'text',
                        'title' => __('Home Text', 'charitxa'),
                        'subtitle' => __('Input home text', 'charitxa'),
                        'desc' => __('', 'charitxa'),
                        'default' => 'Home'
                    ),                   
                    array(
                        'id' => 'blog_background',
                        'type' => 'media',
                        'url' => true,
                        'title' => __('Blog Background Image', 'charitxa'),
                        'compiler' => 'true',
                        //'mode' => false, // Can be set to false to allow any media type, or can also be set to any mime type.
                        'desc' => __('', 'charitxa'),
                        'subtitle' => __('Upload your Image Background', 'charitxa'),
                        'default' => ''
                    ),
                    array(
                        'id' => 'blog_title',
                        'type' => 'text',
                        'title' => __('Blog title', 'charitxa'),
                        'subtitle' => __('Input Blog title', 'charitxa'),
                        'desc' => __('', 'charitxa'),
                        'default' => 'Latest Blog'
                    ),
                    array(
                        'id' => 'blog_grid_1_background',
                        'type' => 'media',
                        'url' => true,
                        'title' => __('Blog Grid 1 Background Image', 'charitxa'),
                        'compiler' => 'true',
                        //'mode' => false, // Can be set to false to allow any media type, or can also be set to any mime type.
                        'desc' => __('', 'charitxa'),
                        'subtitle' => __('Upload your Image Background', 'charitxa'),
                        'default' => ''
                    ),
                    array(
                        'id' => 'blog_grid_1_title',
                        'type' => 'text',
                        'title' => __('Blog grid 1 title', 'charitxa'),
                        'subtitle' => __('Input blog grid title', 'charitxa'),
                        'desc' => __('', 'charitxa'),
                        'default' => 'Latest Blog'
                    ),
                    array(
                        'id' => 'blog_grid_2_background',
                        'type' => 'media',
                        'url' => true,
                        'title' => __('Blog Grid 2 Background Image', 'charitxa'),
                        'compiler' => 'true',
                        //'mode' => false, // Can be set to false to allow any media type, or can also be set to any mime type.
                        'desc' => __('', 'charitxa'),
                        'subtitle' => __('Upload your Image Background', 'charitxa'),
                        'default' => ''
                    ),
                    array(
                        'id' => 'blog_grid_2_title',
                        'type' => 'text',
                        'title' => __('Blog grid 2 title', 'charitxa'),
                        'subtitle' => __('Input blog grid title', 'charitxa'),
                        'desc' => __('', 'charitxa'),
                        'default' => 'Latest Blog'
                    ),                
                    array(
                        'id' => 'list_number',
                        'type' => 'text',
                        'title' => __('Blog List posts per page', 'charitxa'),
                        'subtitle' => __('Input number', 'charitxa'),
                        'desc' => __('', 'charitxa'),
                        'default' => '4'
                    ),
                    array(
                        'id' => 'grid_number',
                        'type' => 'text',
                        'title' => __('Blog grid posts per page', 'charitxa'),
                        'subtitle' => __('Input number', 'charitxa'),
                        'desc' => __('', 'charitxa'),
                        'default' => '6'
                    ),
                    array(
                        'id' => 'grid_3_number',
                        'type' => 'text',
                        'title' => __('Blog grid three posts per page', 'charitxa'),
                        'subtitle' => __('Input number', 'charitxa'),
                        'desc' => __('', 'charitxa'),
                        'default' => '3'
                    ),
                    array(
                        'id' => 'blog_excerpt',
                        'type' => 'text',
                        'title' => __('Blog custom excerpt length', 'charitxa'),
                        'subtitle' => __('Input Blog custom excerpt length', 'charitxa'),
                        'desc' => __('', 'charitxa'),
                        'default' => '30'
                    ),
                    array(
                        'id' => 'blog_excerpt_2',
                        'type' => 'text',
                        'title' => __('Blog grid custom excerpt length', 'charitxa'),
                        'subtitle' => __('Input Blog grid custom excerpt length', 'charitxa'),
                        'desc' => __('', 'charitxa'),
                        'default' => '10'
                    ),
                    array(
                        'id' => 'read_more',
                        'type' => 'text',
                        'title' => __('Button Text For Post', 'charitxa'),
                        'subtitle' => __('Input Button Text', 'charitxa'),
                        'desc' => __('', 'charitxa'),
                        'default' => 'Read More'
                    ),
                    array(
                        'id' => 'by',
                        'type' => 'text',
                        'title' => __('Text Before Author Name', 'charitxa'),
                        'subtitle' => __('Input Text', 'charitxa'),
                        'desc' => __('', 'charitxa'),
                        'default' => 'By:'
                    ),
                    array(
                        'id' => 'share',
                        'type' => 'text',
                        'title' => __('Share text', 'charitxa'),
                        'subtitle' => __('Input Text', 'charitxa'),
                        'desc' => __('', 'charitxa'),
                        'default' => 'Share:'
                    ),
                    array(
                        'id' => 'blog_tags',
                        'type' => 'text',
                        'title' => __('Blog Tags', 'charitxa'),
                        'subtitle' => __('Input blog tags', 'charitxa'),
                        'desc' => __('', 'charitxa'),
                        'default' => 'Tags: '
                    ),
                ) 
            )); 
            Redux::setSection( $opt_name, array(
                'icon' => 'el-icon-list',
                'title' => __('Priority Settings', 'charitxa'),
                'fields' => array(
                    array(
                        'id' => 'pr_by',
                        'type' => 'text',
                        'title' => __('Text Before Author Name', 'charitxa'),
                        'subtitle' => __('Input Text', 'charitxa'),
                        'desc' => __('', 'charitxa'),
                        'default' => 'By:'
                    ),
                    array(
                        'id' => 'pr_share',
                        'type' => 'text',
                        'title' => __('Share text', 'charitxa'),
                        'subtitle' => __('Input Text', 'charitxa'),
                        'desc' => __('', 'charitxa'),
                        'default' => 'Share:'
                    ),
                    array(
                        'id' => 'pr_types',
                        'type' => 'text',
                        'title' => __('Types Text', 'charitxa'),
                        'subtitle' => __('Input text', 'charitxa'),
                        'desc' => __('', 'charitxa'),
                        'default' => 'Types'
                    ),
                ) 
            )); 
            Redux::setSection( $opt_name, array(
                'icon' => 'el-icon-list',
                'title' => __('Cause Settings', 'charitxa'),
                'fields' => array(
                    array(
                        'id' => 'cause_1_background',
                        'type' => 'media',
                        'url' => true,
                        'title' => __('Cause 1 Background Image', 'charitxa'),
                        'compiler' => 'true',
                        //'mode' => false, // Can be set to false to allow any media type, or can also be set to any mime type.
                        'desc' => __('', 'charitxa'),
                        'subtitle' => __('Upload your Image Background', 'charitxa'),
                        'default' => ''
                    ),
                    array(
                        'id' => 'cause_1_title',
                        'type' => 'text',
                        'title' => __('Cause 1 title', 'charitxa'),
                        'subtitle' => __('Input Cause title', 'charitxa'),
                        'desc' => __('', 'charitxa'),
                        'default' => 'Our Causes'
                    ),
                    array(
                        'id' => 'cause_home_text',
                        'type' => 'text',
                        'title' => __('Cause Home Text', 'charitxa'),
                        'subtitle' => __('Input home text', 'charitxa'),
                        'desc' => __('', 'charitxa'),
                        'default' => 'Home'
                    ),
                    array(
                        'id' => 'cause_number',
                        'type' => 'text',
                        'title' => __('Cause posts per page', 'charitxa'),
                        'subtitle' => __('Input number', 'charitxa'),
                        'desc' => __('', 'charitxa'),
                        'default' => '6'
                    ),
                    array(
                        'id' => 'cause_2_background',
                        'type' => 'media',
                        'url' => true,
                        'title' => __('Cause 2 Background Image', 'charitxa'),
                        'compiler' => 'true',
                        //'mode' => false, // Can be set to false to allow any media type, or can also be set to any mime type.
                        'desc' => __('', 'charitxa'),
                        'subtitle' => __('Upload your Image Background', 'charitxa'),
                        'default' => ''
                    ),
                    array(
                        'id' => 'cause_2_title',
                        'type' => 'text',
                        'title' => __('Cause 2 title', 'charitxa'),
                        'subtitle' => __('Input Cause title', 'charitxa'),
                        'desc' => __('', 'charitxa'),
                        'default' => 'Our Causes'
                    ),
                    array(
                        'id' => 'cause_excerpt',
                        'type' => 'text',
                        'title' => __('Cause custom excerpt length', 'charitxa'),
                        'subtitle' => __('Input cause custom excerpt length', 'charitxa'),
                        'desc' => __('', 'charitxa'),
                        'default' => '20'
                    ),
                    array(
                        'id' => 'cause_3_background',
                        'type' => 'media',
                        'url' => true,
                        'title' => __('Cause 3 Background Image', 'charitxa'),
                        'compiler' => 'true',
                        //'mode' => false, // Can be set to false to allow any media type, or can also be set to any mime type.
                        'desc' => __('', 'charitxa'),
                        'subtitle' => __('Upload your Image Background', 'charitxa'),
                        'default' => ''
                    ),
                    array(
                        'id' => 'cause_3_title',
                        'type' => 'text',
                        'title' => __('Cause 3 title', 'charitxa'),
                        'subtitle' => __('Input Cause title', 'charitxa'),
                        'desc' => __('', 'charitxa'),
                        'default' => 'Our Causes'
                    ),
                    array(
                        'id' => 'cause_4_background',
                        'type' => 'media',
                        'url' => true,
                        'title' => __('Cause 4 Background Image', 'charitxa'),
                        'compiler' => 'true',
                        //'mode' => false, // Can be set to false to allow any media type, or can also be set to any mime type.
                        'desc' => __('', 'charitxa'),
                        'subtitle' => __('Upload your Image Background', 'charitxa'),
                        'default' => ''
                    ),
                    array(
                        'id' => 'cause_4_title',
                        'type' => 'text',
                        'title' => __('Cause 4 title', 'charitxa'),
                        'subtitle' => __('Input Cause title', 'charitxa'),
                        'desc' => __('', 'charitxa'),
                        'default' => 'Our Causes'
                    ),
                    array(
                        'id' => 'donate_now',
                        'type' => 'text',
                        'title' => __('Donate Now Button', 'charitxa'),
                        'subtitle' => __('Input Text', 'charitxa'),
                        'desc' => __('', 'charitxa'),
                        'default' => 'Donate Now'
                    ),
                    array(
                        'id' => 'c_by',
                        'type' => 'text',
                        'title' => __('Text Before Author Name', 'charitxa'),
                        'subtitle' => __('Input Text', 'charitxa'),
                        'desc' => __('', 'charitxa'),
                        'default' => 'By:'
                    ),
                    array(
                        'id' => 'c_share',
                        'type' => 'text',
                        'title' => __('Share text', 'charitxa'),
                        'subtitle' => __('Input Text', 'charitxa'),
                        'desc' => __('', 'charitxa'),
                        'default' => 'Share:'
                    ),
                    array(
                        'id' => 'c_types',
                        'type' => 'text',
                        'title' => __('Types Text', 'charitxa'),
                        'subtitle' => __('Input text', 'charitxa'),
                        'desc' => __('', 'charitxa'),
                        'default' => 'Types: '
                    ),
                ) 
            )); 
            Redux::setSection( $opt_name, array(
                'icon' => 'el-icon-list',
                'title' => __('Event Settings', 'charitxa'),
                'fields' => array(
                    array(
                        'id' => 'event_home_text',
                        'type' => 'text',
                        'title' => __('Home Text', 'charitxa'),
                        'subtitle' => __('Input home text', 'charitxa'),
                        'desc' => __('', 'charitxa'),
                        'default' => 'Home'
                    ),
                    array(
                        'id' => 'event_background',
                        'type' => 'media',
                        'url' => true,
                        'title' => __('Event Background Image', 'charitxa'),
                        'compiler' => 'true',
                        //'mode' => false, // Can be set to false to allow any media type, or can also be set to any mime type.
                        'desc' => __('', 'charitxa'),
                        'subtitle' => __('Upload your Image Background', 'charitxa'),
                        'default' => ''
                    ),
                    array(
                        'id' => 'event_title',
                        'type' => 'text',
                        'title' => __('Event title', 'charitxa'),
                        'subtitle' => __('Input event title', 'charitxa'),
                        'desc' => __('', 'charitxa'),
                        'default' => 'Our Events'
                    ),
                    array(
                        'id' => 'event_number',
                        'type' => 'text',
                        'title' => __('Event posts per page', 'charitxa'),
                        'subtitle' => __('Input number', 'charitxa'),
                        'desc' => __('', 'charitxa'),
                        'default' => '5'
                    ),
                    array(
                        'id' => 'e_by',
                        'type' => 'text',
                        'title' => __('Text Before Author Name', 'charitxa'),
                        'subtitle' => __('Input Text', 'charitxa'),
                        'desc' => __('', 'charitxa'),
                        'default' => 'By:'
                    ),
                    array(
                        'id' => 'e_share',
                        'type' => 'text',
                        'title' => __('Share text', 'charitxa'),
                        'subtitle' => __('Input Text', 'charitxa'),
                        'desc' => __('', 'charitxa'),
                        'default' => 'Share:'
                    ),
                    array(
                        'id' => 'e_types',
                        'type' => 'text',
                        'title' => __('Types Text', 'charitxa'),
                        'subtitle' => __('Input text', 'charitxa'),
                        'desc' => __('', 'charitxa'),
                        'default' => 'Types'
                    ),
                ) 
            )); 
            Redux::setSection( $opt_name, array(
                'icon' => 'el-icon-list',
                'title' => __('Service Settings', 'charitxa'),
                'fields' => array(
                    array(
                        'id' => 'service_detail_background',
                        'type' => 'media',
                        'url' => true,
                        'title' => __('Service Details Background Image', 'charitxa'),
                        'compiler' => 'true',
                        //'mode' => false, // Can be set to false to allow any media type, or can also be set to any mime type.
                        'desc' => __('', 'charitxa'),
                        'subtitle' => __('Upload your Image Background', 'charitxa'),
                        'default' => ''
                    ),
                    array(
                        'id' => 'service_detail_title',
                        'type' => 'text',
                        'title' => __('Service detail title', 'charitxa'),
                        'subtitle' => __('Input service title', 'charitxa'),
                        'desc' => __('', 'charitxa'),
                        'default' => 'Service Details'
                    ),
                    array(
                        'id' => 'service_home_text',
                        'type' => 'text',
                        'title' => __('Home Text', 'charitxa'),
                        'subtitle' => __('Input home text', 'charitxa'),
                        'desc' => __('', 'charitxa'),
                        'default' => 'Home'
                    ),
                    array(
                        'id' => 'serice_background',
                        'type' => 'media',
                        'url' => true,
                        'title' => __('Service Background Image', 'charitxa'),
                        'compiler' => 'true',
                        //'mode' => false, // Can be set to false to allow any media type, or can also be set to any mime type.
                        'desc' => __('', 'charitxa'),
                        'subtitle' => __('Upload your Image Background', 'charitxa'),
                        'default' => ''
                    ),
                    array(
                        'id' => 'serice_title',
                        'type' => 'text',
                        'title' => __('Service title', 'charitxa'),
                        'subtitle' => __('Input event title', 'charitxa'),
                        'desc' => __('', 'charitxa'),
                        'default' => 'Our Events'
                    ),
                    array(
                        'id' => 'service_excerpt',
                        'type' => 'text',
                        'title' => __('Service custom excerpt length', 'charitxa'),
                        'subtitle' => __('Input Service custom excerpt length', 'charitxa'),
                        'desc' => __('', 'charitxa'),
                        'default' => '10'
                    ),
                    array(
                        'id' => 'service_number',
                        'type' => 'text',
                        'title' => __('Service posts per page', 'charitxa'),
                        'subtitle' => __('Input number', 'charitxa'),
                        'desc' => __('', 'charitxa'),
                        'default' => '5'
                    ),
                    array(
                        'id' => 'sv_share',
                        'type' => 'text',
                        'title' => __('Share text', 'charitxa'),
                        'subtitle' => __('Input Text', 'charitxa'),
                        'desc' => __('', 'charitxa'),
                        'default' => 'Share:'
                    ),
                    array(
                        'id' => 'sv_types',
                        'type' => 'text',
                        'title' => __('Types text', 'charitxa'),
                        'subtitle' => __('Input text', 'charitxa'),
                        'desc' => __('', 'charitxa'),
                        'default' => 'Types: '
                    ),
                    array(
                        'id' => 'join_us_button',
                        'type' => 'text',
                        'title' => __('Join Us Button', 'charitxa'),
                        'subtitle' => __('Input text', 'charitxa'),
                        'desc' => __('', 'charitxa'),
                        'default' => 'Join Us Now'
                    ),
                    array(
                        'id' => 'join_us_link_button',
                        'type' => 'text',
                        'title' => __('Join Us Link Button', 'charitxa'),
                        'subtitle' => __('Input link', 'charitxa'),
                        'desc' => __('', 'charitxa'),
                        'default' => 'http://localhost/charitxa/?page_id=238'
                    ),
                ) 
            )); 
            Redux::setSection( $opt_name, array(
                'icon' => 'el-icon-list',
                'title' => __('Story Settings', 'charitxa'),
                'fields' => array(
                    array(
                        'id' => 'story_detail_background',
                        'type' => 'media',
                        'url' => true,
                        'title' => __('Story Details Background Image', 'charitxa'),
                        'compiler' => 'true',
                        //'mode' => false, // Can be set to false to allow any media type, or can also be set to any mime type.
                        'desc' => __('', 'charitxa'),
                        'subtitle' => __('Upload your Image Background', 'charitxa'),
                        'default' => ''
                    ),
                    array(
                        'id' => 'story_detail_title',
                        'type' => 'text',
                        'title' => __('Story detail title', 'charitxa'),
                        'subtitle' => __('Input story title', 'charitxa'),
                        'desc' => __('', 'charitxa'),
                        'default' => 'Story Details'
                    ),
                    array(
                        'id' => 'story_home_text',
                        'type' => 'text',
                        'title' => __('Home Text', 'charitxa'),
                        'subtitle' => __('Input home text', 'charitxa'),
                        'desc' => __('', 'charitxa'),
                        'default' => 'Home'
                    ),
                    array(
                        'id' => 'story_background',
                        'type' => 'media',
                        'url' => true,
                        'title' => __('Story Background Image', 'charitxa'),
                        'compiler' => 'true',
                        //'mode' => false, // Can be set to false to allow any media type, or can also be set to any mime type.
                        'desc' => __('', 'charitxa'),
                        'subtitle' => __('Upload your Image Background', 'charitxa'),
                        'default' => ''
                    ),
                    array(
                        'id' => 'story_title',
                        'type' => 'text',
                        'title' => __('Story title', 'charitxa'),
                        'subtitle' => __('Input event title', 'charitxa'),
                        'desc' => __('', 'charitxa'),
                        'default' => 'Our Stories'
                    ),
                    array(
                        'id' => 'story_excerpt',
                        'type' => 'text',
                        'title' => __('Story custom excerpt length', 'charitxa'),
                        'subtitle' => __('Input Story custom excerpt length', 'charitxa'),
                        'desc' => __('', 'charitxa'),
                        'default' => '10'
                    ),
                    array(
                        'id' => 'story_number',
                        'type' => 'text',
                        'title' => __('Story posts per page', 'charitxa'),
                        'subtitle' => __('Input number', 'charitxa'),
                        'desc' => __('', 'charitxa'),
                        'default' => '6'
                    ),
                    array(
                        'id' => 'st_donate_now',
                        'type' => 'text',
                        'title' => __('Button Donate Now', 'charitxa'),
                        'subtitle' => __('Input Text', 'charitxa'),
                        'desc' => __('', 'charitxa'),
                        'default' => 'Donate Now'
                    ),
                    array(
                        'id' => 'st_by',
                        'type' => 'text',
                        'title' => __('Text Before Author Name', 'charitxa'),
                        'subtitle' => __('Input Text', 'charitxa'),
                        'desc' => __('', 'charitxa'),
                        'default' => 'By:'
                    ),
                    array(
                        'id' => 'st_share',
                        'type' => 'text',
                        'title' => __('Share text', 'charitxa'),
                        'subtitle' => __('Input Text', 'charitxa'),
                        'desc' => __('', 'charitxa'),
                        'default' => 'Share:'
                    ),
                    array(
                        'id' => 'st_types',
                        'type' => 'text',
                        'title' => __('Types text', 'charitxa'),
                        'subtitle' => __('Input text', 'charitxa'),
                        'desc' => __('', 'charitxa'),
                        'default' => 'Types: '
                    ),
                ) 
            )); 
            Redux::setSection( $opt_name, array(
                'icon' => ' el-icon-graph',
                'title' => __('404 Settings', 'charitxa'),
                'fields' => array( 
                    array(
                        'id' => '404_banner',
                        'type' => 'media',
                        'url' => true,
                        'title' => __('404 Banner Image', 'charitxa'),
                        'compiler' => 'true',
                        //'mode' => false, // Can be set to false to allow any media type, or can also be set to any mime type.
                        'desc' => __('', 'charitxa'),
                        'subtitle' => __('Upload your Image Background', 'charitxa'),
                        'default' => ''
                    ),
                    array(
                        'id' => 'error_title',
                        'type' => 'text',
                        'title' => __('404 Title', 'charitxa'),
                        'subtitle' => __('Input 404 title', 'charitxa'),
                        'desc' => __('', 'charitxa'),
                        'default' => '404 error'
                    ),
                    array(
                        'id' => 'error_home_text',
                        'type' => 'text',
                        'title' => __('404 home text', 'charitxa'),
                        'subtitle' => __('Input home text', 'charitxa'),
                        'desc' => __('', 'charitxa'),
                        'default' => 'Home'
                    ),
                    array(
                        'id' => '404_background',
                        'type' => 'media',
                        'url' => true,
                        'title' => __('404 Background Image', 'charitxa'),
                        'compiler' => 'true',
                        //'mode' => false, // Can be set to false to allow any media type, or can also be set to any mime type.
                        'desc' => __('', 'charitxa'),
                        'subtitle' => __('Upload your Image Background', 'charitxa'),
                        'default' => ''
                    ),
                    array(
                        'id' => '404_image',
                        'type' => 'media',
                        'url' => true,
                        'title' => __('404 Image', 'charitxa'),
                        'compiler' => 'true',
                        //'mode' => false, // Can be set to false to allow any media type, or can also be set to any mime type.
                        'desc' => __('', 'charitxa'),
                        'subtitle' => __('Upload your Image Background', 'charitxa'),
                        'default' => ''
                    ),
                    array(
                        'id' => '404_desc',
                        'type' => 'textarea',
                        'title' => __('404 description', 'charitxa'),
                        'subtitle' => __('Input 404 description', 'charitxa'),
                        'desc' => __('', 'charitxa'),
                        'default' => 'OOPPS! THE PAGE YOU WERE LOOKING FOR, COULD NOT BE FOUND.'
                    ),
                    array(
                        'id' => '404_text',
                        'type' => 'textarea',
                        'title' => __('404 text', 'charitxa'),
                        'subtitle' => __('Input 404 text', 'charitxa'),
                        'desc' => __('', 'charitxa'),
                        'default' => 'Aenean sollicitudin, lorem quis bibendum auctor, nisi elit conseq uat ipsum, bibendu ravida nibh vel nec sagittis sem nibh id elit.'
                    ),                      
                    array(
                        'id' => '404_button',
                        'type' => 'text',
                        'title' => __('404 Button', 'charitxa'),
                        'subtitle' => __('Input 404 Button', 'charitxa'),
                        'desc' => __('', 'charitxa'),
                        'default' => 'Back To Home'
                    ),             
                )
            ));
            Redux::setSection( $opt_name, array(
                'icon' => 'el-icon-credit-card',
                'title' => __('Footer Setting', 'charitxa'),
                'fields' => array(
                    array(
                        'id' => 'f_select_style',
                        'type' => 'select',
                        'title' => __('Select Style', 'charitxa'),
                        'subtitle' => __('Select Footer Style', 'charitxa'),
                        'options'  => array(
                            '1' => 'Style 1',
                            '2' => 'Style 2',
                            '3' => 'Style 3',
                            '4' => 'Style 4'
                        ),
                        'default'  => '1', 
                    ),  
                )
            ));
            Redux::setSection( $opt_name, array(
                'icon' => 'el-icon-credit-card',
                'title' => __('Footer One Options', 'charitxa'),
                'fields' => array(
                    array(
                        'id' => 'footer_background',
                        'type' => 'media',
                        'url' => true,
                        'title' => __('Background Image', 'charitxa'),
                        'compiler' => 'true',
                        //'mode' => false, // Can be set to false to allow any media type, or can also be set to any mime type.
                        'desc' => __('', 'charitxa'),
                        'subtitle' => __('Upload your Image Background', 'charitxa'),
                        'default' => ''
                    ),
                    array(
                        'id' => 'footer_text',
                        'type' => 'editor',
                        'title' => __('Footer Text', 'charitxa'),
                        'subtitle' => __('Copyright Text', 'charitxa'),
                        'default' => 'Copyright © 2024, Charitxa All Rights Reserved.',
                    ),
                    array(
                        'id' => 'f_menu_1',
                        'type' => 'text',
                        'title' => __('Menu 1', 'charitxa'),
                        'subtitle' => __('Input text', 'charitxa'),
                        'desc' => __('', 'charitxa'),
                        'default' => 'Site Map'
                    ),
                    array(
                        'id' => 'f_link_menu_1',
                        'type' => 'text',
                        'title' => __('Link Menu 1', 'charitxa'),
                        'subtitle' => __('Input link', 'charitxa'),
                        'desc' => __('', 'charitxa'),
                        'default' => 'http://localhost/charitxa/?page_id=238'
                    ),
                    array(
                        'id' => 'f_menu_2',
                        'type' => 'text',
                        'title' => __('Menu 2', 'charitxa'),
                        'subtitle' => __('Input text', 'charitxa'),
                        'desc' => __('', 'charitxa'),
                        'default' => 'Privacy policy'
                    ),
                    array(
                        'id' => 'f_link_menu_2',
                        'type' => 'text',
                        'title' => __('Link Menu 2', 'charitxa'),
                        'subtitle' => __('Input link', 'charitxa'),
                        'desc' => __('', 'charitxa'),
                        'default' => 'http://localhost/charitxa/?page_id=236'
                    ),
                    array(
                        'id' => 'f_menu_3',
                        'type' => 'text',
                        'title' => __('Menu 3', 'charitxa'),
                        'subtitle' => __('Input text', 'charitxa'),
                        'desc' => __('', 'charitxa'),
                        'default' => 'Terms & Conditions'
                    ),
                    array(
                        'id' => 'f_link_menu_3',
                        'type' => 'text',
                        'title' => __('Link Menu 3', 'charitxa'),
                        'subtitle' => __('Input link', 'charitxa'),
                        'desc' => __('', 'charitxa'),
                        'default' => 'http://localhost/charitxa/?page_id=217'
                    ),  
                )
            ));
            Redux::setSection( $opt_name, array(
                'icon' => 'el-icon-credit-card',
                'title' => __('Footer Two Options', 'charitxa'),
                'fields' => array(
                    array(
                        'id' => 'f2_footer_background',
                        'type' => 'media',
                        'url' => true,
                        'title' => __('Background Image', 'charitxa'),
                        'compiler' => 'true',
                        //'mode' => false, // Can be set to false to allow any media type, or can also be set to any mime type.
                        'desc' => __('', 'charitxa'),
                        'subtitle' => __('Upload your Image Background', 'charitxa'),
                        'default' => ''
                    ),
                    array(
                        'id' => 'f2_footer_text',
                        'type' => 'editor',
                        'title' => __('Footer Text', 'charitxa'),
                        'subtitle' => __('Copyright Text', 'charitxa'),
                        'default' => 'Copyright © 2024, Charitxa All Rights Reserved.',
                    ),
                    array(
                        'id' => 'f2_menu_1',
                        'type' => 'text',
                        'title' => __('Menu 1', 'charitxa'),
                        'subtitle' => __('Input text', 'charitxa'),
                        'desc' => __('', 'charitxa'),
                        'default' => 'Site Map'
                    ),
                    array(
                        'id' => 'f2_link_menu_1',
                        'type' => 'text',
                        'title' => __('Link Menu 1', 'charitxa'),
                        'subtitle' => __('Input link', 'charitxa'),
                        'desc' => __('', 'charitxa'),
                        'default' => 'http://localhost/charitxa/?page_id=238'
                    ),
                    array(
                        'id' => 'f2_menu_2',
                        'type' => 'text',
                        'title' => __('Menu 2', 'charitxa'),
                        'subtitle' => __('Input text', 'charitxa'),
                        'desc' => __('', 'charitxa'),
                        'default' => 'Privacy policy'
                    ),
                    array(
                        'id' => 'f2_link_menu_2',
                        'type' => 'text',
                        'title' => __('Link Menu 2', 'charitxa'),
                        'subtitle' => __('Input link', 'charitxa'),
                        'desc' => __('', 'charitxa'),
                        'default' => 'http://localhost/charitxa/?page_id=236'
                    ),
                    array(
                        'id' => 'f2_menu_3',
                        'type' => 'text',
                        'title' => __('Menu 3', 'charitxa'),
                        'subtitle' => __('Input text', 'charitxa'),
                        'desc' => __('', 'charitxa'),
                        'default' => 'Terms & Conditions'
                    ),
                    array(
                        'id' => 'f2_link_menu_3',
                        'type' => 'text',
                        'title' => __('Link Menu 3', 'charitxa'),
                        'subtitle' => __('Input link', 'charitxa'),
                        'desc' => __('', 'charitxa'),
                        'default' => 'http://localhost/charitxa/?page_id=217'
                    ),  
                )
            ));
            Redux::setSection( $opt_name, array(
                'icon' => 'el-icon-credit-card',
                'title' => __('Footer Three Options', 'charitxa'),
                'fields' => array(
                    array(
                        'id' => 'f3_footer_background',
                        'type' => 'media',
                        'url' => true,
                        'title' => __('Background Image', 'charitxa'),
                        'compiler' => 'true',
                        //'mode' => false, // Can be set to false to allow any media type, or can also be set to any mime type.
                        'desc' => __('', 'charitxa'),
                        'subtitle' => __('Upload your Image Background', 'charitxa'),
                        'default' => ''
                    ),
                    array(
                        'id' => 'f3_footer_text',
                        'type' => 'editor',
                        'title' => __('Footer Text', 'charitxa'),
                        'subtitle' => __('Copyright Text', 'charitxa'),
                        'default' => 'Copyright © 2024, Charitxa All Rights Reserved.',
                    ),
                    array(
                        'id' => 'before_phone',
                        'type' => 'text',
                        'title' => __('Text Before Phone Number', 'charitxa'),
                        'subtitle' => __('Input text', 'charitxa'),
                        'desc' => __('', 'charitxa'),
                        'default' => 'For any inquiries call the hotline: '
                    ),
                    array(
                        'id' => 'f3_phone',
                        'type' => 'text',
                        'title' => __('Phone Number', 'charitxa'),
                        'subtitle' => __('Input phone number', 'charitxa'),
                        'desc' => __('', 'charitxa'),
                        'default' => '+1(123)1234567'
                    ),
                     
                )
            ));
            Redux::setSection( $opt_name, array(
                'icon' => 'el-icon-credit-card',
                'title' => __('Footer Four Options', 'charitxa'),
                'fields' => array(
                    array(
                        'id' => 'f4_footer_background',
                        'type' => 'media',
                        'url' => true,
                        'title' => __('Background Image', 'charitxa'),
                        'compiler' => 'true',
                        //'mode' => false, // Can be set to false to allow any media type, or can also be set to any mime type.
                        'desc' => __('', 'charitxa'),
                        'subtitle' => __('Upload your Image Background', 'charitxa'),
                        'default' => ''
                    ),
                    array(
                        'id' => 'f4_footer_text',
                        'type' => 'editor',
                        'title' => __('Footer Text', 'charitxa'),
                        'subtitle' => __('Copyright Text', 'charitxa'),
                        'default' => 'Copyright © 2024, Charitxa All Rights Reserved.',
                    ),
                    array(
                        'id' => 'f4_phone',
                        'type' => 'text',
                        'title' => __('Phone Number', 'charitxa'),
                        'subtitle' => __('Input phone number', 'charitxa'),
                        'desc' => __('', 'charitxa'),
                        'default' => '0900 7860 1'
                    ),
                    array(
                        'id' => 'f4_email',
                        'type' => 'text',
                        'title' => __('Email', 'charitxa'),
                        'subtitle' => __('Input email', 'charitxa'),
                        'desc' => __('', 'charitxa'),
                        'default' => 'admin@domain.com '
                    ),
                    array(
                        'id' => 'f4_social_1',
                        'type' => 'text',
                        'title' => __('Social 1 Icon', 'bidzen'),
                        'subtitle' => __('Social 1 Icon', 'bidzen'),
                        'default' => 'fab fa-facebook-f',
                    ), 
                    array(
                        'id' => 'f4_link_social_1',
                        'type' => 'text',
                        'title' => __('Link Social 1', 'bidzen'),
                        'subtitle' => __('Link Social 1', 'bidzen'),
                        'default' => 'https://facebook.com',
                    ), 
                    array(
                        'id' => 'f4_social_2',
                        'type' => 'text',
                        'title' => __('Social 2 Icon', 'bidzen'),
                        'subtitle' => __('Social 2 Icon', 'bidzen'),
                        'default' => 'fab fa-youtube',
                    ), 
                    array(
                        'id' => 'f4_link_social_2',
                        'type' => 'text',
                        'title' => __('Link Social 2', 'bidzen'),
                        'subtitle' => __('Link Social 2', 'bidzen'),
                        'default' => 'https://youtube.com',
                    ), 
                    array(
                        'id' => 'f4_social_3',
                        'type' => 'text',
                        'title' => __('Social 3 Icon', 'bidzen'),
                        'subtitle' => __('Social 3 Icon', 'bidzen'),
                        'default' => 'fab fa-instagram',
                    ), 
                    array(
                        'id' => 'f4_link_social_3',
                        'type' => 'text',
                        'title' => __('Link Social 3', 'bidzen'),
                        'subtitle' => __('Link Social 3', 'bidzen'),
                        'default' => 'https://instagram.com',
                    ), 
                    array(
                        'id' => 'f4_social_4',
                        'type' => 'text',
                        'title' => __('Social 4 Icon', 'bidzen'),
                        'subtitle' => __('Social 4 Icon', 'bidzen'),
                        'default' => 'fab fa-linkedin-in',
                    ), 
                    array(
                        'id' => 'f4_link_social_4',
                        'type' => 'text',
                        'title' => __('Link Social 4', 'bidzen'),
                        'subtitle' => __('Link Social 4', 'bidzen'),
                        'default' => 'https://linkedin.com',
                    ),                 
                )
            ));
            Redux::setSection( $opt_name, array(
                'icon' => 'el-icon-website',
                'title' => __('Styling Options', 'charitxa'),
                'fields' => array(
                    array(
                        'id' => 'chosen-color',
                        'type' => 'checkbox',
                        'title' => __('Enable edit color', 'charitxa'),
                        'subtitle' => '',
                        'desc' => '',
                        'default' => '0'// 1 = on | 0 = off
                    ),
                    array(
                        'id' => 'main-theme-color',
                        'type' => 'color',
                        'title' => __('Theme Main Color', 'charitxa'),
                        'subtitle' => __('Pick the main color for the theme (default: #e31937).', 'charitxa'),
                        'default' => '#e31937',
                        'validate' => 'color',
                    ),  
                    array(
                        'id' => 'base-theme-color',
                        'type' => 'color',
                        'title' => __('Theme Base Color', 'charitxa'),
                        'subtitle' => __('Pick the base color for the theme (default: #666666).', 'charitxa'),
                        'default' => '#666666',
                        'validate' => 'color',
                    ), 
                    array(
                        'id' => 'heading-theme-color',
                        'type' => 'color',
                        'title' => __('Theme Heading Color', 'charitxa'),
                        'subtitle' => __('Pick the theme heading color for the theme (default: #333333).', 'charitxa'),
                        'default' => '#333333',
                        'validate' => 'color',
                    ), 
                    array(
                        'id' => 'secondary-theme-color',
                        'type' => 'color',
                        'title' => __('Theme Secondary Color', 'charitxa'),
                        'subtitle' => __('Pick the theme secondary color for the theme (default: #082151).', 'charitxa'),
                        'default' => '#082151',
                        'validate' => 'color',
                    ), 
                    array(
                        'id' => 'yellow-theme-color',
                        'type' => 'color',
                        'title' => __('Theme Yellow Color', 'charitxa'),
                        'subtitle' => __('Pick the theme yellow color for the theme (default: #ffde69).', 'charitxa'),
                        'default' => '#ffde69',
                        'validate' => 'color',
                    ),
                    array(
                        'id' => 'light-theme-color',
                        'type' => 'color',
                        'title' => __('Theme Light Color', 'charitxa'),
                        'subtitle' => __('Pick the theme light color for the theme (default: #f4f4f4).', 'charitxa'),
                        'default' => '#f4f4f4',
                        'validate' => 'color',
                    ),
                    array(
                        'id' => 'border-theme-color',
                        'type' => 'color',
                        'title' => __('Theme Border Color', 'charitxa'),
                        'subtitle' => __('Pick the theme border color for the theme (default: #e5e5e5).', 'charitxa'),
                        'default' => '#e5e5e5',
                        'validate' => 'color',
                    ),
                )
            ));
    // End Code
    

    if ( file_exists( dirname( __FILE__ ) . '/../README.md' ) ) {
        $section = array(
            'icon'   => 'el el-list-alt',
            'title'  => __( 'Documentation', 'redux-framework-demo' ),
            'fields' => array(
                array(
                    'id'       => '17',
                    'type'     => 'raw',
                    'markdown' => true,
                    'content_path' => dirname( __FILE__ ) . '/../README.md', // FULL PATH, not relative please
                    //'content' => 'Raw content here',
                ),
            ),
        );
        Redux::setSection( $opt_name, $section );
    }
    /*
     * <--- END SECTIONS
     */


    /*
     *
     * YOU MUST PREFIX THE FUNCTIONS BELOW AND ACTION FUNCTION CALLS OR ANY OTHER CONFIG MAY OVERRIDE YOUR CODE.
     *
     */

    /*
    *
    * --> Action hook examples
    *
    */

    // If Redux is running as a plugin, this will remove the demo notice and links
    //add_action( 'redux/loaded', 'remove_demo' );

    // Function to test the compiler hook and demo CSS output.
    // Above 10 is a priority, but 2 in necessary to include the dynamically generated CSS to be sent to the function.
    //add_filter('redux/options/' . $opt_name . '/compiler', 'compiler_action', 10, 3);

    // Change the arguments after they've been declared, but before the panel is created
    //add_filter('redux/options/' . $opt_name . '/args', 'change_arguments' );

    // Change the default value of a field after it's been set, but before it's been useds
    //add_filter('redux/options/' . $opt_name . '/defaults', 'change_defaults' );

    // Dynamically add a section. Can be also used to modify sections/fields
    //add_filter('redux/options/' . $opt_name . '/sections', 'dynamic_section');

    /**
     * This is a test function that will let you see when the compiler hook occurs.
     * It only runs if a field    set with compiler=>true is changed.
     * */
    if ( ! function_exists( 'compiler_action' ) ) {
        function compiler_action( $options, $css, $changed_values ) {
            echo '<h1>The compiler hook has run!</h1>';
            echo "<pre>";
            print_r( $changed_values ); // Values that have changed since the last save
            echo "</pre>";
            //print_r($options); //Option values
            //print_r($css); // Compiler selector CSS values  compiler => array( CSS SELECTORS )
        }
    }

    /**
     * Custom function for the callback validation referenced above
     * */
    if ( ! function_exists( 'redux_validate_callback_function' ) ) {
        function redux_validate_callback_function( $field, $value, $existing_value ) {
            $error   = false;
            $warning = false;

            //do your validation
            if ( $value == 1 ) {
                $error = true;
                $value = $existing_value;
            } elseif ( $value == 2 ) {
                $warning = true;
                $value   = $existing_value;
            }

            $return['value'] = $value;

            if ( $error == true ) {
                $field['msg']    = 'your custom error message';
                $return['error'] = $field;
            }

            if ( $warning == true ) {
                $field['msg']      = 'your custom warning message';
                $return['warning'] = $field;
            }

            return $return;
        }
    }

    /**
     * Custom function for the callback referenced above
     */
    if ( ! function_exists( 'redux_my_custom_field' ) ) {
        function redux_my_custom_field( $field, $value ) {
            print_r( $field );
            echo '<br/>';
            print_r( $value );
        }
    }

    /**
     * Custom function for filtering the sections array. Good for child themes to override or add to the sections.
     * Simply include this function in the child themes functions.php file.
     * NOTE: the defined constants for URLs, and directories will NOT be available at this point in a child theme,
     * so you must use get_template_directory_uri() if you want to use any of the built in icons
     * */
    if ( ! function_exists( 'dynamic_section' ) ) {
        function dynamic_section( $sections ) {
            //$sections = array();
            $sections[] = array(
                'title'  => __( 'Section via hook', 'redux-framework-demo' ),
                'desc'   => __( '<p class="description">This is a section created by adding a filter to the sections array. Can be used by child themes to add/remove sections from the options.</p>', 'redux-framework-demo' ),
                'icon'   => 'el el-paper-clip',
                // Leave this as a blank section, no options just some intro text set above.
                'fields' => array()
            );

            return $sections;
        }
    }

    /**
     * Filter hook for filtering the args. Good for child themes to override or add to the args array. Can also be used in other functions.
     * */
    if ( ! function_exists( 'change_arguments' ) ) {
        function change_arguments( $args ) {
            //$args['dev_mode'] = true;

            return $args;
        }
    }

    /**
     * Filter hook for filtering the default value of any given field. Very useful in development mode.
     * */
    if ( ! function_exists( 'change_defaults' ) ) {
        function change_defaults( $defaults ) {
            $defaults['str_replace'] = 'Testing filter hook!';

            return $defaults;
        }
    }

    /**
     * Removes the demo link and the notice of integrated demo from the redux-framework plugin
     */
    if ( ! function_exists( 'remove_demo' ) ) {
        function remove_demo() {
            // Used to hide the demo mode link from the plugin page. Only used when Redux is a plugin.
            if ( class_exists( 'ReduxFrameworkPlugin' ) ) {
                remove_filter( 'plugin_row_meta', array(
                    ReduxFrameworkPlugin::instance(),
                    'plugin_metalinks'
                ), null, 2 );

                // Used to hide the activation notice informing users of the demo panel. Only used when Redux is a plugin.
                remove_action( 'admin_notices', array( ReduxFrameworkPlugin::instance(), 'admin_notices' ) );
            }
        }
    }

