<?php
namespace BdevsElementor\Widget;

use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;
use Elementor\Scheme_Typography;
use Elementor\Group_Control_Border;
use Elementor\Group_Control_Box_Shadow;

/**
 * Bdevs Elementor Widget.
 *
 * Elementor widget that inserts an embbedable content into the page, from any given URL.
 *
 * @since 1.0.0
 */
class BdevsBanner4 extends \Elementor\Widget_Base {

    /**
     * Get widget name.
     *
     * Retrieve Bdevs Elementor widget name.
     *
     * @since 1.0.0
     * @access public
     *
     * @return string Widget name.
     */
    public function get_name() {
        return 'bdevs-banner-4';
    }

    /**
     * Get widget title.
     *
     * Retrieve Bdevs Elementor widget title.
     *
     * @since 1.0.0
     * @access public
     *
     * @return string Widget title.
     */
    public function get_title() {
        return __( 'Banner 4', 'bdevs-elementor' );
    }

    /**
     * Get widget icon.
     *
     * Retrieve Bdevs About widget icon.
     *
     * @since 1.0.0
     * @access public
     *
     * @return string Widget icon.
     */
    public function get_icon() {
        return 'eicon-banner';
    }

    /**
     * Get widget categories.
     *
     * Retrieve the list of categories the Bdevs About widget belongs to.
     *
     * @since 1.0.0
     * @access public
     *
     * @return array Widget categories.
     */
    public function get_categories() {
        return [ 'bdevs-elementor' ];
    }

    public function get_keywords() {
        return [ 'banner 4' ];
    }

    public function get_script_depends() {
        return [ 'bdevs-elementor'];
    }

    // BDT Position
    protected function element_pack_position() {
        $position_options = [
            ''              => esc_html__('Default', 'bdevs-elementor'),
            'top-left'      => esc_html__('Top Left', 'bdevs-elementor') ,
            'top-center'    => esc_html__('Top Center', 'bdevs-elementor') ,
            'top-right'     => esc_html__('Top Right', 'bdevs-elementor') ,
            'center'        => esc_html__('Center', 'bdevs-elementor') ,
            'center-left'   => esc_html__('Center Left', 'bdevs-elementor') ,
            'center-right'  => esc_html__('Center Right', 'bdevs-elementor') ,
            'bottom-left'   => esc_html__('Bottom Left', 'bdevs-elementor') ,
            'bottom-center' => esc_html__('Bottom Center', 'bdevs-elementor') ,
            'bottom-right'  => esc_html__('Bottom Right', 'bdevs-elementor') ,
        ];

        return $position_options;
    }

    protected function _register_controls() {
        
        $this->start_controls_section(
            'section_content_heading',
            [
                'label' => esc_html__( 'Banner 4', 'bdevs-elementor' ),
            ]   
        );
        $this->add_control(
            'background_image',
            [
                'label'   => esc_html__( 'Background Image:', 'bdevs-elementor' ),
                'type'    => Controls_Manager::MEDIA,
                'dynamic' => [ 'active' => true ],
                'description' => esc_html__( 'Add image from here', 'bdevs-elementor' ),
            ]
        );
        $this->add_control(
            'icon',
            [
                'label'       => __( 'Icon:', 'bdevs-elementor' ),
                'type'        => Controls_Manager::TEXT,
                'placeholder' => __( 'Enter your icon', 'bdevs-elementor' ),
                'default'     => __( 'fa-heartbeat', 'bdevs-elementor' ),
                'label_block' => true,
            ]
        );
        $this->add_control(
            'subheading',
            [
                'label'       => __( 'Subheading:', 'bdevs-elementor' ),
                'type'        => Controls_Manager::TEXT,
                'placeholder' => __( 'Enter your subheading', 'bdevs-elementor' ),
                'default'     => __( 'Let us help you to', 'bdevs-elementor' ),
                'label_block' => true,
            ]
        ); 
        $this->add_control(
            'heading',
            [
                'label'       => __( 'Heading:', 'bdevs-elementor' ),
                'type'        => Controls_Manager::TEXT,
                'placeholder' => __( 'Enter your heading', 'bdevs-elementor' ),
                'default'     => __( 'Save Your Life.', 'bdevs-elementor' ),
                'label_block' => true,
            ]
        ); 
        $this->add_control(
            'description',
            [
                'label'       => __( 'Description:', 'bdevs-elementor' ),
                'type'        => Controls_Manager::TEXTAREA,
                'placeholder' => __( 'Enter your description', 'bdevs-elementor' ),
                'default'     => __( 'We’ve been honored to work with and support many innovative and passionate organizations' ),
                'label_block' => true,
            ]
        ); 
        $this->add_control(
            'tabs_button',
            [
                'label' => esc_html__( 'Buttons:', 'bdevs-elementor' ),
                'type' => Controls_Manager::REPEATER,
                'fields' => [
                    [
                        'name'        => 'button_style',
                        'label'     => esc_html__( 'Button Style', 'bdevs-elementor' ),
                        'type'      => Controls_Manager::SELECT,
                        'dynamic' => [ 'active' => true ],
                        'options'   => [
                            '1'  => esc_html__( 'Link To', 'bdevs-elementor' ),
                            '2'  => esc_html__( 'Donate Form', 'bdevs-elementor' ),
                        ],
                        'default'   => '1',
                    ],
                    [
                        'name'        => 'link_button',
                        'label'       => esc_html__( 'Link Button:', 'bdevs-elementor' ),
                        'type'        => Controls_Manager::TEXT,
                        'dynamic'     => [ 'active' => true ],
                        'default'     => esc_html__( '#' , 'bdevs-elementor' ),
                        'label_block' => true,
                        'condition'   => [
                            'button_style' => '1',
                        ]
                    ],
                    [
                        'name'        => 'button',
                        'label'       => esc_html__( 'Button:', 'bdevs-elementor' ),
                        'type'        => Controls_Manager::TEXT,
                        'dynamic'     => [ 'active' => true ],
                        'default'     => esc_html__( 'Donate Now' , 'bdevs-elementor' ),
                        'label_block' => true,
                    ],
                ],
            ]
        );
        $this->end_controls_section();
        $this->start_controls_section(
            'section_content_features',
            [
                'label' => esc_html__( 'Features', 'bdevs-elementor' ),
            ]   
        );
        $this->add_control(
            'tabs2',
            [
                'label' => esc_html__( 'Items', 'bdevs-elementor' ),
                'type' => Controls_Manager::REPEATER,
                'fields' => [
                    [
                        'name'    => 'feature_image',
                        'label'   => esc_html__( 'Image:', 'bdevs-elementor' ),
                        'type'    => Controls_Manager::MEDIA,
                        'default'     => esc_html__( '' , 'bdevs-elementor' ),
                        'dynamic' => [ 'active' => true ],
                    ],
                    [
                        'name'        => 'title',
                        'label'       => esc_html__( 'Title:', 'bdevs-elementor' ),
                        'type'        => Controls_Manager::TEXT,
                        'dynamic'     => [ 'active' => true ],
                        'default'     => esc_html__( 'Our Stories' , 'bdevs-elementor' ),
                        'label_block' => true,
                    ],
                    [
                        'name'        => 'link_button',
                        'label'       => esc_html__( 'Link Button:', 'bdevs-elementor' ),
                        'type'        => Controls_Manager::TEXT,
                        'dynamic'     => [ 'active' => true ],
                        'default'     => esc_html__( '#' , 'bdevs-elementor' ),
                        'label_block' => true,
                    ],
                    [
                        'name'        => 'button',
                        'label'       => esc_html__( 'Button:', 'bdevs-elementor' ),
                        'type'        => Controls_Manager::TEXT,
                        'dynamic'     => [ 'active' => true ],
                        'default'     => esc_html__( 'Read more' , 'bdevs-elementor' ),
                        'label_block' => true,
                    ],
                ],
            ]
        );
        $this->end_controls_section();
        /** 
        *   Layout section 
        **/
        $this->start_controls_section(
            'section_content_layout',
            [
                'label' => esc_html__( 'Layout', 'bdevs-elementor' ),
            ]
        );

        $this->add_responsive_control(
            'align',
            [
                'label'   => esc_html__( 'Alignment', 'bdevs-elementor' ),
                'type'    => Controls_Manager::CHOOSE,
                'options' => [
                    'left' => [
                        'title' => esc_html__( 'Left', 'bdevs-elementor' ),
                        'icon'  => 'fa fa-align-left',
                    ],
                    'center' => [
                        'title' => esc_html__( 'Center', 'bdevs-elementor' ),
                        'icon'  => 'fa fa-align-center',
                    ],
                    'right' => [
                        'title' => esc_html__( 'Right', 'bdevs-elementor' ),
                        'icon'  => 'fa fa-align-right',
                    ],
                    'justify' => [
                        'title' => esc_html__( 'Justified', 'bdevs-elementor' ),
                        'icon'  => 'fa fa-align-justify',
                    ],
                ],
                'prefix_class' => 'elementor%s-align-',
                'description'  => 'Use align to match position',
                'default'      => 'left',
            ]
        );
        $this->end_controls_section();

    }
    public function render() {
    $settings  = $this->get_settings_for_display();
    extract($settings); 
    ?> 
    <!-- Hero Section Start -->
    <?php if(isset($settings['background_image']['url']) && $settings['background_image']['url'] != ''){?>
    <section class="hero-area-four bgs-cover pt-200 rpt-110" style="background-image: url(<?php echo wp_kses_post($settings['background_image']['url']);?>)">
    <?php } else { ?>
    <section class="hero-area-four bgs-cover pt-200 rpt-110">
    <?php } ?>
        <div class="container">
            <div class="row">
                <div class="col-xl-9 col-lg-10">
                    <div class="hero-four-content wow fadeInUp delay-0-2s">
                        <?php if(isset($settings['icon']) && $settings['icon'] != ''){?>
                        <div class="icon">
                            <i class="far <?php print wp_kses_post($settings['icon']); ?>"></i>
                        </div>
                        <?php } ?>
                        <div class="content text-white">                           
                            <?php if(isset($settings['subheading']) && $settings['subheading'] != ''){?>
                            <span class="sub-title mb-5"><?php print wp_kses_post($settings['subheading']); ?></span>
                            <?php } ?>
                            <?php if(isset($settings['heading']) && $settings['heading'] != ''){?>
                            <h1><?php print wp_kses_post($settings['heading']); ?></h1>
                            <?php } ?>
                            <?php if(isset($settings['description']) && $settings['description'] != ''){?>
                            <p><?php print wp_kses_post($settings['description']); ?></p>
                            <?php } ?>
                            <div class="hero-btns pt-15">
                                <?php foreach ( $settings['tabs_button'] as $item ) :  ?>
                                <?php if( wp_kses_post($item['button_style']) == '2'): ?>
                                <a href="#" class="theme-btn style-three" data-bs-toggle="modal" data-bs-target="#donateModal">
                                    <span class="btn-text normal"><?php print wp_kses_post($item['button']); ?></span>
                                    <span class="btn-text hover"><?php print wp_kses_post($item['button']); ?></span>
                                </a>
                                <?php elseif( wp_kses_post($item['button_style']) == '1'): ?>
                                <a href="<?php print wp_kses_post($item['link_button']); ?>" class="theme-btn">
                                    <span class="btn-text normal"><?php print wp_kses_post($item['button']); ?></span>
                                    <span class="btn-text hover"><?php print wp_kses_post($item['button']); ?></span>
                                </a>
                                <?php endif; ?>
                                <?php endforeach; ?>  
                            </div>
                        </div>
                    </div>
                </div>
            </div>
        </div>
        <div class="container container-1435">
            <div class="row justify-content-end">
                <div class="col-xl-8 col-lg-10">
                    <div class="feature-three-wrap">
                        <div class="row no-gap justify-content-center">
                            <?php 
                            $i=0;
                            foreach ( $settings['tabs2'] as $item2 ) :   
                            ?>
                            <div class="col-lg-4 col-sm-6">
                                <div class="feature-item-three wow fadeInUp delay-0-<?php echo  $i; ?>s">
                                    <?php if(isset($item2['feature_image']['url']) && $item2['feature_image']['url'] != ''){?>
                                    <div class="image">
                                        <a href="<?php print wp_kses_post($item2['link_button']); ?>"><img src="<?php echo wp_kses_post($item2['feature_image']['url']); ?>" alt="Feature"></a>
                                    </div>
                                    <?php } ?>
                                    <div class="content">
                                        <?php if(isset($item2['title']) && $item2['title'] != ''){?>
                                        <h5><a href="<?php print wp_kses_post($item2['link_button']); ?>"><?php print wp_kses_post($item2['title']); ?></a></h5>
                                        <?php } ?>
                                        <?php if(isset($item2['link_button']) && $item2['link_button'] != ''){?>
                                        <a href="<?php print wp_kses_post($item2['link_button']); ?>" class="read-more"><?php print wp_kses_post($item2['button']); ?> <i class="far fa-chevron-double-right"></i></a>
                                        <?php } ?>
                                    </div>
                                </div>
                            </div>
                            <?php $i = $i+2; ?>
                            <?php endforeach; ?>
                        </div>
                    </div>
                </div>
            </div>
        </div>
    </section>
    <!-- Hero Section End -->
    <?php
    }

}

