<?php
namespace BdevsElementor\Widget;

use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;
use Elementor\Scheme_Typography;
use Elementor\Group_Control_Border;
use Elementor\Group_Control_Box_Shadow;

/**
 * Bdevs Elementor Widget.
 *
 * Elementor widget that inserts an embbedable content into the page, from any given URL.
 *
 * @since 1.0.0
 */
class BdevsBlog extends \Elementor\Widget_Base {

    /**
     * Get widget name.
     *
     * Retrieve Bdevs Elementor widget name.
     *
     * @since 1.0.0
     * @access public
     *
     * @return string Widget name.
     */
    public function get_name() {
        return 'bdevs-blog';
    }

    /**
     * Get widget title.
     *
     * Retrieve Bdevs Elementor widget title.
     *
     * @since 1.0.0
     * @access public
     *
     * @return string Widget title.
     */
    public function get_title() {
        return __( 'Blog', 'bdevs-elementor' );
    }

    /**
     * Get widget icon.
     *
     * Retrieve Bdevs About widget icon.
     *
     * @since 1.0.0
     * @access public
     *
     * @return string Widget icon.
     */
    public function get_icon() {
        return 'eicon-post-list';
    }

    /**
     * Get widget categories.
     *
     * Retrieve the list of categories the Bdevs About widget belongs to.
     *
     * @since 1.0.0
     * @access public
     *
     * @return array Widget categories.
     */
    public function get_categories() {
        return [ 'bdevs-elementor' ];
    }

    public function get_keywords() {
        return [ 'blog' ];
    }

    public function get_script_depends() {
        return [ 'bdevs-elementor'];
    }

    // BDT Position
    protected function element_pack_position() {
        $position_options = [
            ''              => esc_html__('Default', 'bdevs-elementor'),
            'top-left'      => esc_html__('Top Left', 'bdevs-elementor') ,
            'top-center'    => esc_html__('Top Center', 'bdevs-elementor') ,
            'top-right'     => esc_html__('Top Right', 'bdevs-elementor') ,
            'center'        => esc_html__('Center', 'bdevs-elementor') ,
            'center-left'   => esc_html__('Center Left', 'bdevs-elementor') ,
            'center-right'  => esc_html__('Center Right', 'bdevs-elementor') ,
            'bottom-left'   => esc_html__('Bottom Left', 'bdevs-elementor') ,
            'bottom-center' => esc_html__('Bottom Center', 'bdevs-elementor') ,
            'bottom-right'  => esc_html__('Bottom Right', 'bdevs-elementor') ,
        ];

        return $position_options;
    }

    protected function _register_controls() {
        $this->start_controls_section(
            'section_content_heading',
            [
                'label' => esc_html__( 'Blog', 'bdevs-elementor' ),
            ]   
        ); 
        $this->add_control(
            'choose_style',
            [
                'label'     => esc_html__( 'Choose Style', 'bdevs-elementor' ),
                'type'      => Controls_Manager::SELECT,
                'options'   => [
                    'style_1'  => esc_html__( 'Style 1', 'bdevs-elementor' ),
                    'style_2'  => esc_html__( 'Style 2', 'bdevs-elementor' ),
                    'style_3'  => esc_html__( 'Style 3', 'bdevs-elementor' ),
                    'style_4'  => esc_html__( 'Style 4', 'bdevs-elementor' ),
                    'style_5'  => esc_html__( 'Style 5', 'bdevs-elementor' ),
                    'style_6'  => esc_html__( 'Style 6', 'bdevs-elementor' ),
                    'style_7'  => esc_html__( 'Style 7', 'bdevs-elementor' ),
                ],
                'default'   => 'style_1',
            ]
        );
        $this->add_control(
            'background_image',
            [
                'label'   => esc_html__( 'Background Image:', 'bdevs-elementor' ),
                'type'    => Controls_Manager::MEDIA,
                'dynamic' => [ 'active' => true ],
                'description' => esc_html__( 'Add image from here', 'bdevs-elementor' ),
                'condition'   => [
                    'choose_style' => ['style_7']
                ]
            ]
        );
        $this->add_control(
            'heading',
            [
                'label'       => __( 'Heading:', 'bdevs-elementor' ),
                'type'        => Controls_Manager::TEXT,
                'placeholder' => __( 'Enter your heading', 'bdevs-elementor' ),
                'default'     => __( 'Making Headlines', 'bdevs-elementor' ),
                'label_block' => true,
                'condition'   => [
                    'choose_style' => ['style_1', 'style_2','style_5','style_6','style_7']
                ]
            ]
        ); 
        $this->add_control(
            'tabs',
            [
                'label' => esc_html__( 'Heading:', 'bdevs-elementor' ),
                'type' => Controls_Manager::REPEATER,
                'fields' => [
                    [
                        'name'        => 'heading_style',
                        'label'     => esc_html__( 'Heading Style:', 'bdevs-elementor' ),
                        'type'      => Controls_Manager::SELECT,
                        'dynamic' => [ 'active' => true ],
                        'options'   => [
                            '1'  => esc_html__( 'Normal', 'bdevs-elementor' ),
                            '2'  => esc_html__( 'Color', 'bdevs-elementor' ),
                        ],
                        'default'   => '1',
                    ],
                    [
                        'name'        => 'text',
                        'label'       => esc_html__( 'Text:', 'bdevs-elementor' ),
                        'type'        => Controls_Manager::TEXTAREA,
                        'dynamic'     => [ 'active' => true ],
                        'default'     => esc_html__( 'Be the first to know about specials, events &' , 'bdevs-elementor' ),
                        'label_block' => true,
                    ],                   
                ],
                'condition'   => [
                    'choose_style' => ['style_3','style_4']
                ]
            ]
        );
        $this->add_control(
            'description',
            [
                'label'       => __( 'Description:', 'bdevs-elementor' ),
                'type'        => Controls_Manager::TEXTAREA,
                'placeholder' => __( 'Enter your description', 'bdevs-elementor' ),
                'default'     => __( 'adipisicing elit Rem autem voluptatem obcaecati', 'bdevs-elementor' ),
                'label_block' => true,
            ]
        );
        $this->add_control(
            'drop_image',
            [
                'label'   => esc_html__( 'Drop Image:', 'bdevs-elementor' ),
                'type'    => Controls_Manager::MEDIA,
                'dynamic' => [ 'active' => true ],
                'description' => esc_html__( 'Add image from here', 'bdevs-elementor' ),
                'condition'   => [
                    'choose_style' => ['style_1', 'style_2','style_5','style_6','style_7']
                ]
            ]
        ); 
        $this->add_control(
            'posts_per_page',
            [
                'label'       => __( 'Posts Per Page:', 'bdevs-elementor' ),
                'type'        => Controls_Manager::TEXT,
                'placeholder' => __( 'Enter your posts per page', 'bdevs-elementor' ),
                'default'     => __( '2', 'bdevs-elementor' ),
                'label_block' => true,
            ]
        );
        $this->add_control(
            'sortby',
            [
                'label'     => esc_html__( 'Sort', 'bdevs-elementor' ),
                'type'      => Controls_Manager::SELECT,
                'options'   => [
                    'sortby_style_1'  => esc_html__( 'Newest', 'bdevs-elementor' ),
                    'sortby_style_2'  => esc_html__( 'Oldest', 'bdevs-elementor' ),
                ],
                'default'   => 'sortby_style_1',
            ]
        );
        $this->add_control(
            'before_button',
            [
                'label'       => __( 'Before Button:', 'bdevs-elementor' ),
                'type'        => Controls_Manager::TEXT,
                'placeholder' => __( 'Enter your text', 'bdevs-elementor' ),
                'default'     => __( 'Want to see our News', 'bdevs-elementor' ),
                'label_block' => true,
                'condition'   => [
                    'choose_style' => ['style_1','style_2','style_3']
                ]
            ]
        );
        $this->add_control(
            'link_button',
            [
                'label'       => __( 'Link Button:', 'bdevs-elementor' ),
                'type'        => Controls_Manager::TEXT,
                'placeholder' => __( 'Enter link button', 'bdevs-elementor' ),
                'default'     => __( '#' ),
                'label_block' => true,
            ]
        );
        $this->add_control(
            'button',
            [
                'label'       => __( 'Button:', 'bdevs-elementor' ),
                'type'        => Controls_Manager::TEXT,
                'placeholder' => __( 'Enter button', 'bdevs-elementor' ),
                'default'     => __( 'Click here to View More' ),
                'label_block' => true,
            ]
        );
        $this->end_controls_section();

        /** 
        *   Layout section 
        **/
        $this->start_controls_section(
            'section_content_layout',
            [
                'label' => esc_html__( 'Layout', 'bdevs-elementor' ),
            ]
        );

        $this->add_responsive_control(
            'align',
            [
                'label'   => esc_html__( 'Alignment', 'bdevs-elementor' ),
                'type'    => Controls_Manager::CHOOSE,
                'options' => [
                    'left' => [
                        'title' => esc_html__( 'Left', 'bdevs-elementor' ),
                        'icon'  => 'fa fa-align-left',
                    ],
                    'center' => [
                        'title' => esc_html__( 'Center', 'bdevs-elementor' ),
                        'icon'  => 'fa fa-align-center',
                    ],
                    'right' => [
                        'title' => esc_html__( 'Right', 'bdevs-elementor' ),
                        'icon'  => 'fa fa-align-right',
                    ],
                    'justify' => [
                        'title' => esc_html__( 'Justified', 'bdevs-elementor' ),
                        'icon'  => 'fa fa-align-justify',
                    ],
                ],
                'prefix_class' => 'elementor%s-align-',
                'description'  => 'Use align to match position',
                'default'      => 'left',
            ]
        );
        $this->add_control(
            'show_heading',
            [
                'label'   => esc_html__( 'Show Heading', 'bdevs-elementor' ),
                'type'    => Controls_Manager::SWITCHER,
                'default' => 'yes',
            ]
        );
        $this->end_controls_section();
    }

    public function render() {
        $settings  = $this->get_settings_for_display();
        extract($settings); 
        if ($settings['sortby']=='sortby_style_1') {
            $sortby = 'DESC';
        }
        if ($settings['sortby']=='sortby_style_2') {
            $sortby = 'ASC';
        }
        ?>
        <?php $style = $settings['choose_style'];?>
        <?php if( $style == 'style_1' ): ?>   
        <!-- Blog Area start -->
        <section class="blog-area py-115 rpt-85 rel z-1">
            <div class="container">
                <?php if ( $settings['show_heading'] ) : ?>
                <div class="section-title text-center mb-15 wow fadeInUp delay-0-2s">
                   <?php if(isset($settings['heading']) && $settings['heading'] != ''){?>
                    <h2><?php print wp_kses_post($settings['heading']); ?></h2>
                    <?php } ?>
                    <?php if(isset($settings['description']) && $settings['description'] != ''){?>
                    <p><?php print wp_kses_post($settings['description']); ?></p>
                    <?php } ?>
                   <span class="line"></span>
                   <?php if(isset($settings['drop_image']['url']) && $settings['drop_image']['url'] != ''){?>
                   <img class="drops" src="<?php echo wp_kses_post($settings['drop_image']['url']);?>" alt="Drops">
                   <?php } ?>
                </div>
                <?php endif; ?>
                <div class="row justify-content-center">
                     <?php
                    $posts_per_page = $settings['posts_per_page'];
                    $wp_query = new \WP_Query(array('posts_per_page' => $posts_per_page,'post_type' => 'post',  'orderby' => 'ID', 'order' => $sortby));     
                    $args = new \WP_Query(array(   
                                'post_type' => 'post', 
                            )); 
                    $i=0;
                    while ($wp_query -> have_posts()) : $wp_query -> the_post(); 
                    ?>
                    <?php $featured_image_6 = get_post_meta(get_the_ID(),'_cmb_featured_image_6', true); ?>
                    <div class="col-lg-6">
                        <div class="blog-item wow fadeInUp delay-0-3s">
                            <?php if(isset($featured_image_6) && $featured_image_6 != '') { ?>
                            <div class="image">
                                <a href="<?php the_permalink();?>"><img src="<?php echo wp_get_attachment_url($featured_image_6);?>" alt="Blog"></a>
                            </div>
                            <?php } ?>
                            <div class="content">
                                <div class="blog-admin">
                                   <?php echo get_avatar(get_the_author_meta('user_email'),$size='30', $default='http://0.gravatar.com/avatar/ad516503a11cd5ca435acc9bb6523536?s=120' );?> <span class="before-author"><?php if(isset($charitxa_redux_demo['by'])){?>
                                        <?php echo wp_specialchars_decode(esc_attr($charitxa_redux_demo['by']));?>
                                        <?php }else{?>
                                        <?php echo esc_html__( 'By:', 'charitxa' ); } ?></span> <?php the_author_posts_link(); ?>
                                </div>
                                <h5><a href="<?php the_permalink();?>"><?php the_title(); ?></a></h5>
                                <ul class="blog-meta">
                                    <li><i class="fas fa-calendar-alt"></i> <?php the_time(get_option( 'date_format' ));?></li>
                                    <li><i class="fas fa-comment-alt-dots"></i> <?php comments_number( esc_html__('0 Comments', 'charitxa'), esc_html__('1 Comment', 'charitxa'), esc_html__('% Comments', 'charitxa') ); ?></li>
                                </ul>
                            </div>
                        </div>
                    </div>
                    <?php endwhile; ?>
                </div>
                <?php if(isset($settings['link_button']) && $settings['link_button'] != ''){?>
                <div class="more-btn-with-text text-center pt-10 wow fadeInUp delay-0-2s">
                    <i><?php print wp_kses_post($settings['before_button']); ?> <a href="<?php print wp_kses_post($settings['link_button']); ?>"><?php print wp_kses_post($settings['button']); ?></a></i>
                </div>
                <?php } ?>
            </div>
        </section>
        <!-- Blog Area end -->
        <?php elseif( $style == 'style_2' ): ?>
        <!-- Blog Area start -->
        <section class="blog-area-two py-110 rpt-85 rel z-1">
            <div class="container">
                <?php if ( $settings['show_heading'] ) : ?>
                <div class="section-title text-center mb-15 wow fadeInUp delay-0-2s">
                   <?php if(isset($settings['heading']) && $settings['heading'] != ''){?>
                    <h2><?php print wp_kses_post($settings['heading']); ?></h2>
                    <?php } ?>
                    <?php if(isset($settings['description']) && $settings['description'] != ''){?>
                    <p><?php print wp_kses_post($settings['description']); ?></p>
                    <?php } ?>
                    <span class="line"></span>
                    <?php if(isset($settings['drop_image']['url']) && $settings['drop_image']['url'] != ''){?>
                    <img class="drops" src="<?php echo wp_kses_post($settings['drop_image']['url']);?>" alt="Drops">
                    <?php } ?>
                </div>
                <?php endif; ?>
                <div class="row align-items-center">
                    <?php
                    $posts_per_page = $settings['posts_per_page'];
                    $wp_query = new \WP_Query(array('posts_per_page' => $posts_per_page,'post_type' => 'post',  'orderby' => 'ID', 'order' => $sortby));     
                    $args = new \WP_Query(array(   
                                'post_type' => 'post', 
                            )); 
                    $i=0;
                    while ($wp_query -> have_posts()) : $wp_query -> the_post();                     
                    $i++;
                    $featured_image_4 = get_post_meta(get_the_ID(),'_cmb_featured_image_4', true);
                    ?> 
                    <?php if($i%3==1) { ?>
                    <div class="col-lg-7">
                        <div class="blog-item-two big-item wow fadeInUp delay-0-3s">
                            <?php if(isset($featured_image_4) && $featured_image_4 != '') { ?>
                            <div class="image br-30">
                                <a href="<?php the_permalink();?>"><img src="<?php echo wp_get_attachment_url($featured_image_4);?>" alt="Blog"></a>
                            </div>
                            <?php } ?>
                            <div class="content">
                                <div class="blog-admin">
                                   <?php echo get_avatar(get_the_author_meta('user_email'),$size='120', $default='http://0.gravatar.com/avatar/ad516503a11cd5ca435acc9bb6523536?s=120' );?> <span class="before-author"><?php if(isset($charitxa_redux_demo['by'])){?>
                                        <?php echo wp_specialchars_decode(esc_attr($charitxa_redux_demo['by']));?>
                                        <?php }else{?>
                                        <?php echo esc_html__( 'By:', 'charitxa' ); } ?></span> <?php the_author_posts_link(); ?>
                                </div>
                                <h5><a href="<?php the_permalink();?>"><?php the_title(); ?></a></h5>
                                <p><?php echo esc_attr(charitxa_excerpt(30));?></p>
                                <ul class="blog-meta">
                                    <li><i class="fas fa-calendar-alt"></i> <?php the_time(get_option( 'date_format' ));?></li>
                                    <li><i class="fas fa-comment-alt-dots"></i> <?php comments_number( esc_html__('0 Comments', 'charitxa'), esc_html__('1 Comment', 'charitxa'), esc_html__('% Comments', 'charitxa') ); ?></li>
                                </ul>
                            </div>
                        </div>
                    </div>
                    <?php } elseif($i%3!=1) { ?>
                    <?php if($i%3==2) { ?>
                    <div class="col-lg-5">
                        <div class="blog-item-two wow fadeInUp delay-0-5s">
                            <?php if(isset($featured_image_4) && $featured_image_4 != '') { ?>
                            <div class="image br-30">
                                <a href="<?php the_permalink();?>"><img src="<?php echo wp_get_attachment_url($featured_image_4);?>" alt="Blog"></a>
                            </div>
                            <?php } ?>
                            <div class="content">
                                <div class="blog-admin">
                                   <?php echo get_avatar(get_the_author_meta('user_email'),$size='120', $default='http://0.gravatar.com/avatar/ad516503a11cd5ca435acc9bb6523536?s=120' );?> <span class="before-author"><?php if(isset($charitxa_redux_demo['by'])){?>
                                        <?php echo wp_specialchars_decode(esc_attr($charitxa_redux_demo['by']));?>
                                        <?php }else{?>
                                        <?php echo esc_html__( 'By:', 'charitxa' ); } ?></span> <?php the_author_posts_link(); ?>
                                </div>
                                <h5><a href="<?php the_permalink();?>"><?php the_title(); ?></a></h5>
                                <ul class="blog-meta">
                                    <li><i class="fas fa-calendar-alt"></i> <?php the_time(get_option( 'date_format' ));?></li>
                                    <li><i class="fas fa-comment-alt-dots"></i> <?php comments_number( esc_html__('0 Comments', 'charitxa'), esc_html__('1 Comment', 'charitxa'), esc_html__('% Comments', 'charitxa') ); ?></li>
                                </ul>
                            </div>
                        </div>
                    <?php } elseif($i%3==0) { ?>
                        <div class="blog-item-two wow fadeInUp delay-0-5s">
                            <?php if(isset($featured_image_4) && $featured_image_4 != '') { ?>
                            <div class="image br-30">
                                <a href="<?php the_permalink();?>"><img src="<?php echo wp_get_attachment_url($featured_image_4);?>" alt="Blog"></a>
                            </div>
                            <?php } ?>
                            <div class="content">
                                <div class="blog-admin">
                                   <?php echo get_avatar(get_the_author_meta('user_email'),$size='120', $default='http://0.gravatar.com/avatar/ad516503a11cd5ca435acc9bb6523536?s=120' );?> <span class="before-author"><?php if(isset($charitxa_redux_demo['by'])){?>
                                        <?php echo wp_specialchars_decode(esc_attr($charitxa_redux_demo['by']));?>
                                        <?php }else{?>
                                        <?php echo esc_html__( 'By:', 'charitxa' ); } ?></span> <?php the_author_posts_link(); ?>
                                </div>
                                <h5><a href="<?php the_permalink();?>"><?php the_title(); ?></a></h5>
                                <ul class="blog-meta">
                                    <li><i class="fas fa-calendar-alt"></i> <?php the_time(get_option( 'date_format' ));?></li>
                                    <li><i class="fas fa-comment-alt-dots"></i> <?php comments_number( esc_html__('0 Comments', 'charitxa'), esc_html__('1 Comment', 'charitxa'), esc_html__('% Comments', 'charitxa') ); ?></li>
                                </ul> 
                            </div>
                        </div>
                    </div>
                    <?php } ?>
                    <?php } ?>
                    <?php endwhile; ?> 
                </div>
                <?php if(isset($settings['link_button']) && $settings['link_button'] != ''){?>
                <div class="more-btn-with-text text-center pt-70 rpt-40 wow fadeInUp delay-0-2s">
                    <i><?php print wp_kses_post($settings['before_button']); ?> <a href="<?php print wp_kses_post($settings['link_button']); ?>"><?php print wp_kses_post($settings['button']); ?></a></i>
                </div>
                <?php } ?>
            </div>
        </section>
        <!-- Blog Area end -->
        <?php elseif( $style == 'style_3' ): ?>
        <!-- Blog Area Three start -->
        <section class="blog-area-three py-115">
            <div class="container">
                <?php if ( $settings['show_heading'] ) : ?>
                <div class="section-title text-center mb-15 wow fadeInUp delay-0-2s">
                   <h2><?php foreach ( $settings['tabs'] as $item ) :  ?>
                    <?php if( wp_kses_post($item['heading_style']) == '1'): ?>
                    <?php print wp_kses_post($item['text']); ?>
                    <?php elseif( wp_kses_post($item['heading_style']) == '2'): ?>
                    <span><?php print wp_kses_post($item['text']); ?></span>  
                    <?php endif; ?> 
                    <?php endforeach; ?></h2>
                   <?php if(isset($settings['description']) && $settings['description'] != ''){?>
                    <p><?php print wp_kses_post($settings['description']); ?></p>
                    <?php } ?>
                   <span class="line"></span>
                </div>
                <?php endif; ?>
                <div class="row justify-content-center">
                    <?php
                    $posts_per_page = $settings['posts_per_page'];
                    $wp_query = new \WP_Query(array('posts_per_page' => $posts_per_page,'post_type' => 'post',  'orderby' => 'ID', 'order' => $sortby));     
                    $args = new \WP_Query(array(   
                                'post_type' => 'post', 
                            )); 
                    while ($wp_query -> have_posts()) : $wp_query -> the_post();                     
                    $featured_image_3 = get_post_meta(get_the_ID(),'_cmb_featured_image_3', true);
                    ?> 
                    <div class="col-xl-4 col-md-6">
                        <div class="blog-three-item wow fadeInUp delay-0-2s">
                            <?php if(isset($featured_image_3) && $featured_image_3 != '') { ?>
                            <div class="image">
                                <a href="<?php the_permalink();?>"><img src="<?php echo wp_get_attachment_url($featured_image_3);?>" alt="Blog"></a>
                            </div>
                            <?php } ?>
                            <div class="content">
                                <h5><a href="<?php the_permalink();?>"><?php the_title(); ?></a></h5>
                                 <ul class="blog-meta">
                                    <li><i class="fas fa-calendar-alt"></i> <?php the_time(get_option( 'date_format' ));?></li>
                                    <li><i class="fas fa-comment-alt-dots"></i> <?php comments_number( esc_html__('0 Comments', 'charitxa'), esc_html__('1 Comment', 'charitxa'), esc_html__('% Comments', 'charitxa') ); ?></li>
                                </ul>
                                <p><?php echo esc_attr(charitxa_excerpt_2(10));?></p>
                                <div class="blog-admin">
                                   <?php echo get_avatar(get_the_author_meta('user_email'),$size='120', $default='http://0.gravatar.com/avatar/ad516503a11cd5ca435acc9bb6523536?s=120' );?> <span class="before-author"><?php if(isset($charitxa_redux_demo['by'])){?>
                                        <?php echo wp_specialchars_decode(esc_attr($charitxa_redux_demo['by']));?>
                                        <?php }else{?>
                                        <?php echo esc_html__( 'By:', 'charitxa' ); } ?></span> <span><?php the_author_posts_link(); ?></span>
                                </div>
                            </div>
                        </div>
                    </div>
                    <?php endwhile; ?> 
                </div>
                <?php if(isset($settings['link_button']) && $settings['link_button'] != ''){?>
                <div class="more-btn-with-text text-center pt-5 wow fadeInUp delay-0-2s">
                    <i><?php print wp_kses_post($settings['before_button']); ?> <a href="<?php print wp_kses_post($settings['link_button']); ?>"><?php print wp_kses_post($settings['button']); ?></a></i>
                </div>
                <?php } ?>
            </div>
        </section>
        <!-- Blog Area Three end -->
        <?php elseif( $style == 'style_4' ): ?>
        <!-- Blog Area Four start -->
        <section class="blog-area-four py-105">
            <div class="container">
                <?php if ( $settings['show_heading'] ) : ?>
                <div class="section-title text-center mb-15 wow fadeInUp delay-0-2s">
                   <h2><?php foreach ( $settings['tabs'] as $item ) :  ?>
                    <?php if( wp_kses_post($item['heading_style']) == '1'): ?>
                    <?php print wp_kses_post($item['text']); ?>
                    <?php elseif( wp_kses_post($item['heading_style']) == '2'): ?>
                    <span><?php print wp_kses_post($item['text']); ?></span>  
                    <?php endif; ?> 
                    <?php endforeach; ?></h2>
                    <?php if(isset($settings['description']) && $settings['description'] != ''){?>
                    <p><?php print wp_kses_post($settings['description']); ?></p>
                    <?php } ?>
                   <span class="line"></span>
                </div>
                <?php endif; ?>
                <div class="row justify-content-center">
                    <?php
                    $posts_per_page = $settings['posts_per_page'];
                    $wp_query = new \WP_Query(array('posts_per_page' => $posts_per_page,'post_type' => 'post',  'orderby' => 'ID', 'order' => $sortby));     
                    $args = new \WP_Query(array(   
                                'post_type' => 'post', 
                            )); 
                    while ($wp_query -> have_posts()) : $wp_query -> the_post();                     
                    $featured_image = get_post_meta(get_the_ID(),'_cmb_featured_image', true);
                    ?> 
                    <div class="col-xl-4 col-md-6">
                        <div class="blog-four-item wow fadeInUp delay-0-2s">
                            <?php if(isset($featured_image) && $featured_image != '') { ?>
                            <div class="image">
                                <a href="<?php the_permalink();?>"><img src="<?php echo wp_get_attachment_url($featured_image);?>" alt="Blog"></a>
                            </div>
                            <?php } ?>
                            <div class="content">
                                <ul class="blog-meta">
                                    <li>By <?php the_author_posts_link(); ?></li>
                                    <li><?php comments_number( esc_html__('0 Comments', 'charitxa'), esc_html__('1 Comment', 'charitxa'), esc_html__('% Comments', 'charitxa') ); ?></li>
                                </ul>
                                <h5><a href="<?php the_permalink();?>"><?php the_title(); ?></a></h5>
                                <a class="date" href="<?php the_permalink();?>"><?php the_time(get_option( 'date_format' ));?></a>
                            </div>
                        </div>
                    </div>
                    <?php endwhile; ?> 
                </div>
                <?php if(isset($settings['link_button']) && $settings['link_button'] != ''){?>
                <div class="more-btn text-center pt-20 wow fadeInUp delay-0-2s">
                    <a href="<?php print wp_kses_post($settings['link_button']); ?>" class="theme-btn">
                        <span class="btn-text normal"><?php print wp_kses_post($settings['button']); ?></span>
                        <span class="btn-text hover"><?php print wp_kses_post($settings['button']); ?></span>
                    </a>
                </div>
                <?php } ?>
            </div>
        </section>
        <!-- Blog Area Four end -->
        <?php elseif( $style == 'style_5' ): ?>
        <!-- Recent Post Area start -->
        <section class="recent-post-area pt-105 pb-110 rel z-1 bgs-cover">
            <div class="container">
                <?php if ( $settings['show_heading'] ) : ?>
                <div class="section-title style-three mb-30 wow fadeInUp delay-0-2s">
                    <div class="title rel mb-15">
                       <?php if(isset($settings['heading']) && $settings['heading'] != ''){?>
                        <h3><?php print wp_kses_post($settings['heading']); ?></h3>
                        <?php } ?>
                       <?php if(isset($settings['drop_image']['url']) && $settings['drop_image']['url'] != ''){?>
                        <img class="drops" src="<?php echo wp_kses_post($settings['drop_image']['url']);?>" alt="Drops">
                        <?php } ?>
                    </div>
                    <?php if(isset($settings['description']) && $settings['description'] != ''){?>
                    <div class="text">  
                        <p><?php print wp_kses_post($settings['description']); ?></p>   
                       <span class="line"></span>
                    </div>
                    <?php } ?>
               </div>
               <?php endif; ?>
                <div class="row align-items-center">
                    <?php
                        $posts_per_page = $settings['posts_per_page'];
                        $wp_query = new \WP_Query(array('posts_per_page' => $posts_per_page,'post_type' => 'post',  'orderby' => 'ID', 'order' => $sortby));     
                        $args = new \WP_Query(array(   
                                    'post_type' => 'post', 
                                )); 
                        $i=0;
                        while ($wp_query -> have_posts()) : $wp_query -> the_post();  
                        $i++;
                        $featured_image_4 = get_post_meta(get_the_ID(),'_cmb_featured_image_4', true);
                    ?> 
                    <?php if($i%3!=0) { ?>
                    <?php if($i%3==1) { ?>
                    <div class="col-lg-5">
                        <div class="blog-item-two wow fadeInUp delay-0-3s">
                            <?php if(isset($featured_image_4) && $featured_image_4 != '') { ?>
                            <div class="image br-30">
                                <a href="<?php the_permalink();?>"><img src="<?php echo wp_get_attachment_url($featured_image_4);?>" alt="Blog"></a>
                            </div>
                            <?php } ?>
                            <div class="content">
                                <div class="blog-admin">
                                   <?php echo get_avatar(get_the_author_meta('user_email'),$size='120', $default='http://0.gravatar.com/avatar/ad516503a11cd5ca435acc9bb6523536?s=120' );?> <span class="before-author"><?php if(isset($charitxa_redux_demo['by'])){?>
                                                <?php echo wp_specialchars_decode(esc_attr($charitxa_redux_demo['by']));?>
                                                <?php }else{?>
                                                <?php echo esc_html__( 'By:', 'charitxa' ); } ?></span> <?php the_author_posts_link(); ?>
                                </div>
                                <h5><a href="<?php the_permalink();?>"><?php the_title(); ?></a></h5>
                                <ul class="blog-meta">
                                    <li><i class="fas fa-calendar-alt"></i> <?php the_time(get_option( 'date_format' ));?></li>
                                    <li><i class="fas fa-comment-alt-dots"></i> <?php comments_number( esc_html__('0 Comments', 'charitxa'), esc_html__('1 Comment', 'charitxa'), esc_html__('% Comments', 'charitxa') ); ?></li>
                                </ul>
                            </div>
                        </div>
                    <?php } elseif($i%3==2) { ?>
                        <div class="blog-item-two wow fadeInUp delay-0-4s">
                            <?php if(isset($featured_image_4) && $featured_image_4 != '') { ?>
                            <div class="image br-30">
                                <a href="<?php the_permalink();?>"><img src="<?php echo wp_get_attachment_url($featured_image_4);?>" alt="Blog"></a>
                            </div>
                            <?php } ?>
                            <div class="content">
                                <div class="blog-admin">
                                   <?php echo get_avatar(get_the_author_meta('user_email'),$size='120', $default='http://0.gravatar.com/avatar/ad516503a11cd5ca435acc9bb6523536?s=120' );?> <span class="before-author"><?php if(isset($charitxa_redux_demo['by'])){?>
                                                <?php echo wp_specialchars_decode(esc_attr($charitxa_redux_demo['by']));?>
                                                <?php }else{?>
                                                <?php echo esc_html__( 'By:', 'charitxa' ); } ?></span> <?php the_author_posts_link(); ?>
                                </div>
                                <h5><a href="<?php the_permalink();?>"><?php the_title(); ?></a></h5>
                                <ul class="blog-meta">
                                    <li><i class="fas fa-calendar-alt"></i> <?php the_time(get_option( 'date_format' ));?></li>
                                    <li><i class="fas fa-comment-alt-dots"></i> <?php comments_number( esc_html__('0 Comments', 'charitxa'), esc_html__('1 Comment', 'charitxa'), esc_html__('% Comments', 'charitxa') ); ?></li>
                                </ul>
                            </div>
                        </div>
                    </div>
                    <?php } ?>
                    <?php } elseif($i%3==0) { ?>
                    <div class="col-lg-7">
                        <div class="blog-item-two big-item wow fadeInUp delay-0-5s">
                            <?php if(isset($featured_image_4) && $featured_image_4 != '') { ?>
                            <div class="image br-30">
                                <a href="<?php the_permalink();?>"><img src="<?php echo wp_get_attachment_url($featured_image_4);?>" alt="Blog"></a>
                            </div>
                            <?php } ?>
                            <div class="content">
                                <div class="blog-admin">
                                   <?php echo get_avatar(get_the_author_meta('user_email'),$size='120', $default='http://0.gravatar.com/avatar/ad516503a11cd5ca435acc9bb6523536?s=120' );?> <span class="before-author"><?php if(isset($charitxa_redux_demo['by'])){?>
                                                <?php echo wp_specialchars_decode(esc_attr($charitxa_redux_demo['by']));?>
                                                <?php }else{?>
                                                <?php echo esc_html__( 'By:', 'charitxa' ); } ?></span> <?php the_author_posts_link(); ?>
                                </div>
                                <h5><a href="<?php the_permalink();?>"><?php the_title(); ?></a></h5>
                                <p><?php echo esc_attr(charitxa_excerpt(30));?></p>
                                <ul class="blog-meta">
                                    <li><i class="fas fa-calendar-alt"></i> <?php the_time(get_option( 'date_format' ));?></li>
                                    <li><i class="fas fa-comment-alt-dots"></i> <?php comments_number( esc_html__('0 Comments', 'charitxa'), esc_html__('1 Comment', 'charitxa'), esc_html__('% Comments', 'charitxa') ); ?></li>
                                </ul>
                            </div>
                        </div>
                    </div>
                    <?php } ?>
                    <?php endwhile; ?>  
                </div>
            </div>
        </section>
        <!-- Recent Post Area end -->
        <?php elseif( $style == 'style_6' ): ?>
        <!-- Top Trandings Area start -->
        <section class="top-tranding-blog py-105 rel z-1 bgs-cover">
            <div class="container">
                <?php if ( $settings['show_heading'] ) : ?>
                <div class="section-title style-three mb-30 wow fadeInUp delay-0-2s">
                    <div class="title rel mb-15">
                        <?php if(isset($settings['heading']) && $settings['heading'] != ''){?>
                        <h3><?php print wp_kses_post($settings['heading']); ?></h3>
                        <?php } ?>
                        <?php if(isset($settings['drop_image']['url']) && $settings['drop_image']['url'] != ''){?>
                        <img class="drops" src="<?php echo wp_kses_post($settings['drop_image']['url']);?>" alt="Drops">
                        <?php } ?>
                    </div>
                    <div class="text">
                        <?php if(isset($settings['description']) && $settings['description'] != ''){?>
                        <p><?php print wp_kses_post($settings['description']); ?></p>
                        <?php } ?>
                        <span class="line"></span>
                    </div>
                </div>
                <?php endif; ?>
                <div class="row align-items-center">
                    <?php
                        $posts_per_page = $settings['posts_per_page'];
                        $wp_query = new \WP_Query(array('posts_per_page' => $posts_per_page,'post_type' => 'post',  'orderby' => 'ID', 'order' => $sortby));     
                        $args = new \WP_Query(array(   
                                    'post_type' => 'post', 
                                )); 
                        $i=0;
                        while ($wp_query -> have_posts()) : $wp_query -> the_post();                     
                        $i++;
                        $featured_image_4 = get_post_meta(get_the_ID(),'_cmb_featured_image_4', true);
                    ?> 
                    <?php if($i%3==1) { ?>
                    <div class="col-lg-7">
                        <div class="blog-item-two big-item wow fadeInUp delay-0-3s">
                            <?php if(isset($featured_image_4) && $featured_image_4 != '') { ?>
                            <div class="image br-30">
                                <a href="<?php the_permalink();?>"><img src="<?php echo wp_get_attachment_url($featured_image_4);?>" alt="Blog"></a>
                            </div>
                            <?php } ?>
                            <div class="content">
                                <div class="blog-admin">
                                   <?php echo get_avatar(get_the_author_meta('user_email'),$size='120', $default='http://0.gravatar.com/avatar/ad516503a11cd5ca435acc9bb6523536?s=120' );?> <span class="before-author"><?php if(isset($charitxa_redux_demo['by'])){?>
                                                <?php echo wp_specialchars_decode(esc_attr($charitxa_redux_demo['by']));?>
                                                <?php }else{?>
                                                <?php echo esc_html__( 'By:', 'charitxa' ); } ?></span> <?php the_author_posts_link(); ?>
                                </div>
                                <h5><a href="<?php the_permalink();?>"><?php the_title(); ?></a></h5>
                                <p><?php echo esc_attr(charitxa_excerpt(30));?></p>
                                <ul class="blog-meta">
                                    <li><i class="fas fa-calendar-alt"></i> <?php the_time(get_option( 'date_format' ));?></li>
                                    <li><i class="fas fa-comment-alt-dots"></i> <?php comments_number( esc_html__('0 Comments', 'charitxa'), esc_html__('1 Comment', 'charitxa'), esc_html__('% Comments', 'charitxa') ); ?></li>
                                </ul>
                            </div>
                        </div>
                    </div>
                    <?php } elseif($i%3!=1) { ?>
                    <?php if($i%3==2) { ?>
                    <div class="col-lg-5">
                        <div class="blog-item-two wow fadeInUp delay-0-5s">
                            <?php if(isset($featured_image_4) && $featured_image_4 != '') { ?>
                            <div class="image br-30">
                                <a href="<?php the_permalink();?>"><img src="<?php echo wp_get_attachment_url($featured_image_4);?>" alt="Blog"></a>
                            </div>
                            <?php } ?>
                            <div class="content">
                                <div class="blog-admin">
                                   <?php echo get_avatar(get_the_author_meta('user_email'),$size='120', $default='http://0.gravatar.com/avatar/ad516503a11cd5ca435acc9bb6523536?s=120' );?> <span class="before-author"><?php if(isset($charitxa_redux_demo['by'])){?>
                                                <?php echo wp_specialchars_decode(esc_attr($charitxa_redux_demo['by']));?>
                                                <?php }else{?>
                                                <?php echo esc_html__( 'By:', 'charitxa' ); } ?></span> <?php the_author_posts_link(); ?>
                                </div>
                                <h5><a href="<?php the_permalink();?>"><?php the_title(); ?></a></h5>
                                <ul class="blog-meta">
                                    <li><i class="fas fa-calendar-alt"></i> <?php the_time(get_option( 'date_format' ));?></li>
                                    <li><i class="fas fa-comment-alt-dots"></i> <?php comments_number( esc_html__('0 Comments', 'charitxa'), esc_html__('1 Comment', 'charitxa'), esc_html__('% Comments', 'charitxa') ); ?></li>
                                </ul>
                            </div>
                        </div>
                    <?php } elseif($i%3==0) { ?>
                        <div class="blog-item-two wow fadeInUp delay-0-5s">
                            <?php if(isset($featured_image_4) && $featured_image_4 != '') { ?>
                            <div class="image br-30">
                                <a href="<?php the_permalink();?>"><img src="<?php echo wp_get_attachment_url($featured_image_4);?>" alt="Blog"></a>
                            </div>
                            <?php } ?>
                            <div class="content">
                                <div class="blog-admin">
                                   <?php echo get_avatar(get_the_author_meta('user_email'),$size='120', $default='http://0.gravatar.com/avatar/ad516503a11cd5ca435acc9bb6523536?s=120' );?> <span class="before-author"><?php if(isset($charitxa_redux_demo['by'])){?>
                                                <?php echo wp_specialchars_decode(esc_attr($charitxa_redux_demo['by']));?>
                                                <?php }else{?>
                                                <?php echo esc_html__( 'By:', 'charitxa' ); } ?></span> <?php the_author_posts_link(); ?>
                                </div>
                                <h5><a href="<?php the_permalink();?>"><?php the_title(); ?></a></h5>
                                <ul class="blog-meta">
                                    <li><i class="fas fa-calendar-alt"></i> <?php the_time(get_option( 'date_format' ));?></li>
                                    <li><i class="fas fa-comment-alt-dots"></i> <?php comments_number( esc_html__('0 Comments', 'charitxa'), esc_html__('1 Comment', 'charitxa'), esc_html__('% Comments', 'charitxa') ); ?></li>
                                </ul> 
                            </div>
                        </div>
                    </div>
                    <?php } ?>
                    <?php } ?>
                    <?php endwhile; ?>  
                </div>
            </div>
        </section>
        <!-- Top Trandings Area end -->
        <?php elseif( $style == 'style_7' ): ?>
        <!-- Blog Area start -->
        <?php if(isset($settings['background_image']['url']) && $settings['background_image']['url'] != ''){?>
        <section class="featur-news pt-105 pb-60 rel z-1" style="background-image: url(<?php echo wp_kses_post($settings['background_image']['url']);?>);">
        <?php } else { ?>
        <section class="featur-news pt-105 pb-60 rel z-1">
        <?php } ?>
            <div class="container">
                <?php if ( $settings['show_heading'] ) : ?>
                <div class="section-title text-center mb-15 wow fadeInUp delay-0-2s">
                   <?php if(isset($settings['heading']) && $settings['heading'] != ''){?>
                    <h2><?php print wp_kses_post($settings['heading']); ?></h2>
                    <?php } ?>
                    <?php if(isset($settings['description']) && $settings['description'] != ''){?>
                    <p><?php print wp_kses_post($settings['description']); ?></p>
                    <?php } ?>
                    <span class="line"></span>
                    <?php if(isset($settings['drop_image']['url']) && $settings['drop_image']['url'] != ''){?>
                    <img class="drops" src="<?php echo wp_kses_post($settings['drop_image']['url']);?>" alt="Drops">
                    <?php } ?>
                </div>
                <?php endif; ?>
                <div class="row justify-content-center">
                     <?php
                    $posts_per_page = $settings['posts_per_page'];
                    $wp_query = new \WP_Query(array('posts_per_page' => $posts_per_page,'post_type' => 'post',  'orderby' => 'ID', 'order' => $sortby));     
                    $args = new \WP_Query(array(   
                                'post_type' => 'post', 
                            )); 
                    $i=0;
                    while ($wp_query -> have_posts()) : $wp_query -> the_post(); 
                    ?>
                    <?php $featured_image_6 = get_post_meta(get_the_ID(),'_cmb_featured_image_6', true); ?>
                    <div class="col-lg-6">
                        <div class="blog-item wow fadeInUp delay-0-3s">
                            <?php if(isset($featured_image_6) && $featured_image_6 != '') { ?>
                            <div class="image">
                                <a href="<?php the_permalink();?>"><img src="<?php echo wp_get_attachment_url($featured_image_6);?>" alt="Blog"></a>
                            </div>
                            <?php } ?>
                            <div class="content">
                                <div class="blog-admin">
                                   <?php echo get_avatar(get_the_author_meta('user_email'),$size='30', $default='http://0.gravatar.com/avatar/ad516503a11cd5ca435acc9bb6523536?s=120' );?> <span class="before-author"><?php if(isset($charitxa_redux_demo['by'])){?>
                                        <?php echo wp_specialchars_decode(esc_attr($charitxa_redux_demo['by']));?>
                                        <?php }else{?>
                                        <?php echo esc_html__( 'By:', 'charitxa' ); } ?></span> <?php the_author_posts_link(); ?>
                                </div>
                                <h5><a href="<?php the_permalink();?>"><?php the_title(); ?></a></h5>
                                <ul class="blog-meta">
                                    <li><i class="fas fa-calendar-alt"></i> <?php the_time(get_option( 'date_format' ));?></li>
                                    <li><i class="fas fa-comment-alt-dots"></i> <?php comments_number( esc_html__('0 Comments', 'charitxa'), esc_html__('1 Comment', 'charitxa'), esc_html__('% Comments', 'charitxa') ); ?></li>
                                </ul>
                            </div>
                        </div>
                    </div>
                    <?php endwhile; ?>
                </div>
            </div>
        </section>
        <!-- Blog Area end -->
        <?php endif; ?>
    <?php
    }
}
