<?php
namespace BdevsElementor\Widget;

use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;
use Elementor\Scheme_Typography;
use Elementor\Group_Control_Border;
use Elementor\Group_Control_Box_Shadow;

/**
 * Bdevs Elementor Widget.
 *
 * Elementor widget that inserts an embbedable content into the page, from any given URL.
 *
 * @since 1.0.0
 */
class BdevsClients extends \Elementor\Widget_Base {

	/**
	 * Get widget name.
	 *
	 * Retrieve Bdevs Elementor widget name.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'bdevs-clients';
	}

	/**
	 * Get widget title.
	 *
	 * Retrieve Bdevs Elementor widget title.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Clients', 'bdevs-elementor' );
	}

	/**
	 * Get widget icon.
	 *
	 * Retrieve Bdevs Testimonials widget icon.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-integration';
	}

	/**
	 * Get widget categories.
	 *
	 * Retrieve the list of categories the Bdevs Testimonials widget belongs to.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'bdevs-elementor' ];
	}

	public function get_keywords() {
		return [ 'clients', 'carousel' ];
	}

	public function get_script_depends() {
		return [ 'bdevs-elementor'];
	}

	// BDT Position
	protected function element_pack_position() {
	    $position_options = [
	        ''              => esc_html__('Default', 'bdevs-elementor'),
	        'top-left'      => esc_html__('Top Left', 'bdevs-elementor') ,
	        'top-center'    => esc_html__('Top Center', 'bdevs-elementor') ,
	        'top-right'     => esc_html__('Top Right', 'bdevs-elementor') ,
	        'center'        => esc_html__('Center', 'bdevs-elementor') ,
	        'center-left'   => esc_html__('Center Left', 'bdevs-elementor') ,
	        'center-right'  => esc_html__('Center Right', 'bdevs-elementor') ,
	        'bottom-left'   => esc_html__('Bottom Left', 'bdevs-elementor') ,
	        'bottom-center' => esc_html__('Bottom Center', 'bdevs-elementor') ,
	        'bottom-right'  => esc_html__('Bottom Right', 'bdevs-elementor') ,
	    ];

	    return $position_options;
	}

	protected function _register_controls() {
		$this->start_controls_section(
			'section_content_heading',
			[
				'label' => esc_html__( 'Clients', 'bdevs-elementor' ),
			]
		);
		$this->add_control(
            'choose_style',
            [
                'label'     => esc_html__( 'Choose Style', 'bdevs-elementor' ),
                'type'      => Controls_Manager::SELECT,
                'options'   => [
                    'style_1'  => esc_html__( 'Style 1', 'bdevs-elementor' ),
                    'style_2'  => esc_html__( 'Style 2', 'bdevs-elementor' ),
                ],
                'default'   => 'style_1',
            ]
        );
		$this->add_control(
            'title',
            [
                'label'       => __( 'title:', 'bdevs-elementor' ),
                'type'        => Controls_Manager::TEXT,
                'placeholder' => __( 'Enter your title', 'bdevs-elementor' ),
                'default'     => __( 'Grateful to collaborate with our partners', 'bdevs-elementor' ),
                'label_block' => true,
            ]
        );
		$this->add_control(
            'tabs',
            [
                'label' => esc_html__( 'Items', 'bdevs-elementor' ),
                'type' => Controls_Manager::REPEATER,
                'fields' => [
                    [
                        'name'    => 'client_logo',
                        'label'   => esc_html__( 'Client Logo', 'bdevs-elementor' ),
                        'type'    => Controls_Manager::MEDIA,
                        'default'     => esc_html__( '' , 'bdevs-elementor' ),
                        'dynamic' => [ 'active' => true ],
                    ],
                ],
            ]
        ); 
		$this->end_controls_section();


		$this->start_controls_section(
			'section_content_layout',
			[
				'label' => esc_html__( 'Layout', 'bdevs-elementor' ),
			]
		);

		$this->add_responsive_control(
			'align',
			[
				'label'   => esc_html__( 'Alignment', 'bdevs-elementor' ),
				'type'    => Controls_Manager::CHOOSE,
				'options' => [
					'left' => [
						'title' => esc_html__( 'Left', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-left',
					],
					'center' => [
						'title' => esc_html__( 'Center', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-center',
					],
					'right' => [
						'title' => esc_html__( 'Right', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-right',
					],
					'justify' => [
						'title' => esc_html__( 'Justified', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-justify',
					],
				],
				'prefix_class' => 'elementor%s-align-',
				'description'  => 'Use align to match position',
				'default'      => 'left',
			]
		);
		$this->end_controls_section();
	}

	public function render() {
		$settings  = $this->get_settings_for_display();
		extract($settings);?>		
		<?php $style = $settings['choose_style'];?>
    	<?php if( $style == 'style_1' ): ?>   
		<!-- Client Logo Area start -->
		<section class="client-logo-area pt-60">
		    <div class="container">
		        <div class="row justify-content-end">
		            <div class="col-lg-8">
		                <?php if(isset($settings['title']) && $settings['title'] != ''){?>
                        <h5><?php print wp_kses_post($settings['title']); ?></h5>
                        <?php } ?>
		                <div class="client-logo-wrap pt-15">
		                    <?php foreach ( $settings['tabs'] as $item ) : ?>
		                    <span class="client-logo-item" ><img src="<?php echo wp_kses_post($item['client_logo']['url']); ?>" alt="Client Logo"></span>
		                    <?php endforeach; ?> 
		                </div>
		            </div>
		        </div>
		    </div>
		</section>
		<!-- Client Logo Area end -->
		<?php elseif( $style == 'style_2' ): ?>
		<!-- Client Logo Area start -->
		<section class="logo-area-two pt-110 pb-80">
		    <div class="container">
		    	<?php if(isset($settings['title']) && $settings['title'] != ''){?>
		        <div class="section-title text-center mb-45 wow fadeInUp delay-0-2s">
		            <h5><?php print wp_kses_post($settings['title']); ?></h5>
		        </div>
		        <?php } ?>
		        <div class="row justify-content-center">
		            <?php foreach ( $settings['tabs'] as $item ) : ?>
		            <div class="col-lg-3 col-6">
		                <span class="logo-item-two wow fadeInUp delay-0-2s"><img src="<?php echo wp_kses_post($item['client_logo']['url']); ?>" alt="Client Logo"></span>
		            </div>
					<?php endforeach; ?> 
		        </div>
		    </div>
		</section>
		<!-- Client Logo Area end -->
		<?php endif; ?>
	<?php
	}

}