<?php
namespace BdevsElementor\Widget;

use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;
use Elementor\Scheme_Typography;
use Elementor\Group_Control_Border;
use Elementor\Group_Control_Box_Shadow;

/**
 * Bdevs Elementor Widget.
 *
 * Elementor widget that inserts an embbedable content into the page, from any given URL.
 *
 * @since 1.0.0
 */
class BdevsContact extends \Elementor\Widget_Base {

    /**
     * Get widget name.
     *
     * Retrieve Bdevs Elementor widget name.
     *
     * @since 1.0.0
     * @access public
     *
     * @return string Widget name.
     */
    public function get_name() {
        return 'bdevs-contact';
    }

    /**
     * Get widget title.
     *
     * Retrieve Bdevs Elementor widget title.
     *
     * @since 1.0.0
     * @access public
     *
     * @return string Widget title.
     */
    public function get_title() {
        return __( 'Contact', 'bdevs-elementor' );
    }

    /**
     * Get widget icon.
     *
     * Retrieve Bdevs About widget icon.
     *
     * @since 1.0.0
     * @access public
     *
     * @return string Widget icon.
     */
    public function get_icon() {
        return 'eicon-headphones';
    }

    /**
     * Get widget categories.
     *
     * Retrieve the list of categories the Bdevs About widget belongs to.
     *
     * @since 1.0.0
     * @access public
     *
     * @return array Widget categories.
     */
    public function get_categories() {
        return [ 'bdevs-elementor' ];
    }

    public function get_keywords() {
        return [ 'contact' ];
    }

    public function get_script_depends() {
        return [ 'bdevs-elementor'];
    }

    // BDT Position
    protected function element_pack_position() {
        $position_options = [
            ''              => esc_html__('Default', 'bdevs-elementor'),
            'top-left'      => esc_html__('Top Left', 'bdevs-elementor') ,
            'top-center'    => esc_html__('Top Center', 'bdevs-elementor') ,
            'top-right'     => esc_html__('Top Right', 'bdevs-elementor') ,
            'center'        => esc_html__('Center', 'bdevs-elementor') ,
            'center-left'   => esc_html__('Center Left', 'bdevs-elementor') ,
            'center-right'  => esc_html__('Center Right', 'bdevs-elementor') ,
            'bottom-left'   => esc_html__('Bottom Left', 'bdevs-elementor') ,
            'bottom-center' => esc_html__('Bottom Center', 'bdevs-elementor') ,
            'bottom-right'  => esc_html__('Bottom Right', 'bdevs-elementor') ,
        ];

        return $position_options;
    }

    protected function _register_controls() {
        
        $this->start_controls_section(
            'section_content_heading',
            [
                'label' => esc_html__( 'Contact', 'bdevs-elementor' ),
            ]   
        );
        $this->add_control(
            'heading',
            [
                'label'       => __( 'Heading:', 'bdevs-elementor' ),
                'type'        => Controls_Manager::TEXT,
                'placeholder' => __( 'Enter your heading', 'bdevs-elementor' ),
                'default'     => __( 'Get In Touch:', 'bdevs-elementor' ),
                'label_block' => true,
            ]
        );
        $this->add_control(
            'description',
            [
                'label'       => __( 'Description:', 'bdevs-elementor' ),
                'type'        => Controls_Manager::TEXTAREA,
                'placeholder' => __( 'Enter your description', 'bdevs-elementor' ),
                'default'     => __( 'We are at your disposal 7 days a week!', 'bdevs-elementor' ),
                'label_block' => true,
            ]
        );
     	$this->add_control(
            'tabs',
            [
                'label' => esc_html__( 'Information:', 'bdevs-elementor' ),
                'type' => Controls_Manager::REPEATER,
                'fields' => [
                    [
                        'name'        => 'choose_style',
                        'label'     => esc_html__( 'Choose Style', 'bdevs-elementor' ),
                        'type'      => Controls_Manager::SELECT,
                        'dynamic' => [ 'active' => true ],
                        'options'   => [
                            '1'  => esc_html__( 'Text', 'bdevs-elementor' ),
                            '2'  => esc_html__( 'Email', 'bdevs-elementor' ),
                            '3'  => esc_html__( 'Phone', 'bdevs-elementor' ),
                            '4'  => esc_html__( 'Link To', 'bdevs-elementor' ),
                        ],
                        'default'   => '1',
                    ],
                    [
                        'name'        => 'title',
                        'label'       => esc_html__( 'Title:', 'bdevs-elementor' ),
                        'type'        => Controls_Manager::TEXT,
                        'dynamic'     => [ 'active' => true ],
                        'default'     => esc_html__( 'Address:' , 'bdevs-elementor' ),
                        'label_block' => true,
                    ],
                    [
                        'name'        => 'link_to',
                        'label'       => esc_html__( 'Link:', 'bdevs-elementor' ),
                        'type'        => Controls_Manager::TEXT,
                        'dynamic'     => [ 'active' => true ],
                        'default'     => esc_html__( '#' , 'bdevs-elementor' ),
                        'label_block' => true,
                        'condition'   =>[
                            'choose_style' =>['4'],
                        ]
                    ],
                    [
                        'name'        => 'detail',
                        'label'       => esc_html__( 'Detail:', 'bdevs-elementor' ),
                        'type'        => Controls_Manager::TEXTAREA,
                        'dynamic'     => [ 'active' => true ],
                        'default'     => esc_html__( '121 King Street Melbourne, Victoria 3000 Australia' , 'bdevs-elementor' ),
                        'label_block' => true,
                    ],
                ],
            ]
        );
        $this->add_control(
            'shortcode',
            [
                'label'   => esc_html__( 'Shortcode:', 'bdevs-elementor' ),
                'type'    => Controls_Manager::TEXT,
                'dynamic' => [ 'active' => true ],
                'default'       => __('Contact Shortcode here', 'bdevs-elementor'),
                'description' => esc_html__( 'Add Your shortcode here', 'bdevs-elementor' ),
                'label_block' => true,
            ]
        );
        $this->add_control(
            'logo_title',
            [
                'label'       => __( 'Logo Title:', 'bdevs-elementor' ),
                'type'        => Controls_Manager::TEXT,
                'placeholder' => __( 'Enter your logo title', 'bdevs-elementor' ),
                'default'     => __( 'Grateful to collaborate with our partners', 'bdevs-elementor' ),
                'label_block' => true,
            ]
        );
        $this->add_control(
            'tabs2',
            [
                'label' => esc_html__( 'Items', 'bdevs-elementor' ),
                'type' => Controls_Manager::REPEATER,
                'fields' => [
                    [
                        'name'    => 'client_logo',
                        'label'   => esc_html__( 'Client Logo', 'bdevs-elementor' ),
                        'type'    => Controls_Manager::MEDIA,
                        'default'     => esc_html__( '' , 'bdevs-elementor' ),
                        'dynamic' => [ 'active' => true ],
                    ],
                ],
            ]
        ); 
        $this->end_controls_section();

        /** 
        *   Layout section 
        **/
        $this->start_controls_section(
            'section_content_layout',
            [
                'label' => esc_html__( 'Layout', 'bdevs-elementor' ),
            ]
        );

        $this->add_responsive_control(
            'align',
            [
                'label'   => esc_html__( 'Alignment', 'bdevs-elementor' ),
                'type'    => Controls_Manager::CHOOSE,
                'options' => [
                    'left' => [
                        'title' => esc_html__( 'Left', 'bdevs-elementor' ),
                        'icon'  => 'fa fa-align-left',
                    ],
                    'center' => [
                        'title' => esc_html__( 'Center', 'bdevs-elementor' ),
                        'icon'  => 'fa fa-align-center',
                    ],
                    'right' => [
                        'title' => esc_html__( 'Right', 'bdevs-elementor' ),
                        'icon'  => 'fa fa-align-right',
                    ],
                    'justify' => [
                        'title' => esc_html__( 'Justified', 'bdevs-elementor' ),
                        'icon'  => 'fa fa-align-justify',
                    ],
                ],
                'prefix_class' => 'elementor%s-align-',
                'description'  => 'Use align to match position',
                'default'      => 'left',
            ]
        ); 
        $this->end_controls_section();

    }

    public function render() {
        $settings  = $this->get_settings_for_display();
        extract($settings); 
        ?>
        <!-- Contact Us Page Area start -->
        <section class="contact-us-page pb-110">
            <div class="container">
                <div class="row">
                    <div class="col-lg-6 order-lg-2">
                        <div class="get-in-touch br-30 bgc-yellow p-60 mb-100 rmb-55 wow fadeInUp delay-0-3s">
                            <?php if(isset($settings['heading']) && $settings['heading'] != ''){?>
                            <h4><?php print wp_kses_post($settings['heading']); ?></h4>
                            <?php } ?>
                            <?php if(isset($settings['description']) && $settings['description'] != ''){?>
                            <p><?php print wp_kses_post($settings['description']); ?></p>
                            <?php } ?>
                            <div class="row justify-content-between mt-40">
                                <?php
                                $i=0;
                                foreach ( $settings['tabs'] as $item ) :  
                                $i++;                                  
                                ?>
                                <?php if ($i%3==1) { ?>
                                <div class="col-sm-5">
                                    <div class="info-item mb-30">
                                        <?php if(isset($item['title']) && $item['title'] != ''){?>
                                        <h6><?php print wp_kses_post($item['title']); ?></h6>
                                        <?php } ?>
                                        <?php if( wp_kses_post($item['choose_style']) == '1'): ?>
                                        <i><?php print wp_kses_post($item['detail']); ?></i>
                                        <?php elseif( wp_kses_post($item['choose_style']) == '2'): ?>
                                        <b><i><a href="mailto:<?php print wp_kses_post($item['detail']); ?>"><?php print wp_kses_post($item['detail']); ?></a></i></b>
                                        <?php elseif( wp_kses_post($item['choose_style']) == '3'): ?>
                                        <b><i><a href="tel:<?php print wp_kses_post($item['detail']); ?>"><?php print wp_kses_post($item['detail']); ?></a></i></b>
                                        <?php elseif( wp_kses_post($item['choose_style']) == '4'): ?>
                                        <b><i><a href="<?php print wp_kses_post($item['link_to']); ?>"><?php print wp_kses_post($item['detail']); ?></a></i></b>
                                        <?php endif; ?>
                                    </div>
                                </div>
                                <?php } elseif ($i%3==2) { ?>
                                <div class="col-sm-6">
                                    <div class="info-item">
                                        <?php if(isset($item['title']) && $item['title'] != ''){?>
                                        <h6><?php print wp_kses_post($item['title']); ?></h6>
                                        <?php } ?>
                                        <?php if( wp_kses_post($item['choose_style']) == '1'): ?>
                                        <i><?php print wp_kses_post($item['detail']); ?></i>
                                        <?php elseif( wp_kses_post($item['choose_style']) == '2'): ?>
                                        <b><i><a href="mailto:<?php print wp_kses_post($item['detail']); ?>"><?php print wp_kses_post($item['detail']); ?></a></i></b>
                                        <?php elseif( wp_kses_post($item['choose_style']) == '3'): ?>
                                        <b><i><a href="tel:<?php print wp_kses_post($item['detail']); ?>"><?php print wp_kses_post($item['detail']); ?></a></i></b>
                                        <?php elseif( wp_kses_post($item['choose_style']) == '4'): ?>
                                        <b><i><a href="<?php print wp_kses_post($item['link_to']); ?>"><?php print wp_kses_post($item['detail']); ?></a></i></b>
                                        <?php endif; ?>
                                    </div>
                                    <?php } elseif ($i%3==0) { ?>
                                    <div class="info-item">
                                        <?php if(isset($item['title']) && $item['title'] != ''){?>
                                        <h6><?php print wp_kses_post($item['title']); ?></h6>
                                        <?php } ?>
                                        <?php if( wp_kses_post($item['choose_style']) == '1'): ?>
                                        <i><?php print wp_kses_post($item['detail']); ?></i>
                                        <?php elseif( wp_kses_post($item['choose_style']) == '2'): ?>
                                        <b><i><a href="mailto:<?php print wp_kses_post($item['detail']); ?>"><?php print wp_kses_post($item['detail']); ?></a></i></b>
                                        <?php elseif( wp_kses_post($item['choose_style']) == '3'): ?>
                                        <b><i><a href="tel:<?php print wp_kses_post($item['detail']); ?>"><?php print wp_kses_post($item['detail']); ?></a></i></b>
                                        <?php elseif( wp_kses_post($item['choose_style']) == '4'): ?>
                                        <b><i><a href="<?php print wp_kses_post($item['link_to']); ?>"><?php print wp_kses_post($item['detail']); ?></a></i></b>
                                        <?php endif; ?>
                                    </div>
                                </div>
                                <?php } ?>
                                <?php endforeach; ?>
                            </div>
                        </div>
                        <div class="partner-logo-part wow fadeInUp delay-0-5s">
                            <?php if(isset($settings['logo_title']) && $settings['logo_title'] != ''){?>
                            <h5><?php print wp_kses_post($settings['logo_title']); ?></h5>
                            <?php } ?>
                            <div class="row justify-content-center mt-30">
                                <?php foreach ( $settings['tabs2'] as $item2 ) : ?>
                                <div class="col-6">
                                    <span class="logo-item-two" ><img src="<?php echo wp_kses_post($item2['client_logo']['url']); ?>" alt="Client Logo"></span>
                                </div>    
                                <?php endforeach; ?> 
                            </div>
                        </div>
                    </div>
                    <div class="col-lg-6">
                        <?php print do_shortcode(html_entity_decode( $settings['shortcode'] )); ?>
                    </div>
                </div>
            </div>
        </section>
        <!-- Contact Us Page Area end -->  
    <?php
    }
}


