<?php
namespace BdevsElementor\Widget;

use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;
use Elementor\Scheme_Typography;
use Elementor\Group_Control_Border;
use Elementor\Group_Control_Box_Shadow;

/**
 * Bdevs Elementor Widget.
 *
 * Elementor widget that inserts an embbedable content into the page, from any given URL.
 *
 * @since 1.0.0
 */
class BdevsCounter2 extends \Elementor\Widget_Base {

    /**
     * Get widget name.
     *
     * Retrieve Bdevs Elementor widget name.
     *
     * @since 1.0.0
     * @access public
     *
     * @return string Widget name.
     */
    public function get_name() {
        return 'bdevs-counter-2';
    }

    /**
     * Get widget title.
     *
     * Retrieve Bdevs Elementor widget title.
     *
     * @since 1.0.0
     * @access public
     *
     * @return string Widget title.
     */
    public function get_title() {
        return __( 'Counter 2', 'bdevs-elementor' );
    }

    /**
     * Get widget icon.
     *
     * Retrieve Bdevs Blog widget icon.
     *
     * @since 1.0.0
     * @access public
     *
     * @return string Widget icon.
     */
    public function get_icon() {
        return 'eicon-counter';
    }

    /**
     * Get widget categories.
     *
     * Retrieve the list of categories the Bdevs Blog widget belongs to.
     *
     * @since 1.0.0
     * @access public
     *
     * @return array Widget categories.
     */
    public function get_categories() {
        return [ 'bdevs-elementor' ];
    }

    public function get_keywords() {
        return [ 'counter 2' ];
    }

    public function get_script_depends() {
        return [ 'bdevs-elementor'];
    }

    // BDT Position
    protected function element_pack_position() {
        $position_options = [
            ''              => esc_html__('Default', 'bdevs-elementor'),
            'top-left'      => esc_html__('Top Left', 'bdevs-elementor') ,
            'top-center'    => esc_html__('Top Center', 'bdevs-elementor') ,
            'top-right'     => esc_html__('Top Right', 'bdevs-elementor') ,
            'center'        => esc_html__('Center', 'bdevs-elementor') ,
            'center-left'   => esc_html__('Center Left', 'bdevs-elementor') ,
            'center-right'  => esc_html__('Center Right', 'bdevs-elementor') ,
            'bottom-left'   => esc_html__('Bottom Left', 'bdevs-elementor') ,
            'bottom-center' => esc_html__('Bottom Center', 'bdevs-elementor') ,
            'bottom-right'  => esc_html__('Bottom Right', 'bdevs-elementor') ,
        ];

        return $position_options;
    }

    protected function _register_controls() {

        $this->start_controls_section(
            'section_content_heading',
            [
                'label' => esc_html__( 'Counter 2', 'bdevs-elementor' ),
            ]
        ); 
        $this->add_control(
            'choose_style',
            [
                'label'     => esc_html__( 'Choose Style', 'bdevs-elementor' ),
                'type'      => Controls_Manager::SELECT,
                'options'   => [
                    'style_1'  => esc_html__( 'Style 1', 'bdevs-elementor' ),
                    'style_2'  => esc_html__( 'Style 2', 'bdevs-elementor' ),
                ],
                'default'   => 'style_1',
            ]
        );
        $this->add_control(
            'subheading',
            [
                'label'       => __( 'Subheading:', 'bdevs-elementor' ),
                'type'        => Controls_Manager::TEXT,
                'placeholder' => __( 'Enter your subheading', 'bdevs-elementor' ),
                'default'     => __( 'Building a Better World through Activist Projects', 'bdevs-elementor' ),
                'label_block' => true,
            ]
        ); 
        $this->add_control(
            'tabs',
            [
                'label' => esc_html__( 'Heading:', 'bdevs-elementor' ),
                'type' => Controls_Manager::REPEATER,
                'fields' => [
                    [
                        'name'        => 'heading_style',
                        'label'     => esc_html__( 'Heading Style:', 'bdevs-elementor' ),
                        'type'      => Controls_Manager::SELECT,
                        'dynamic' => [ 'active' => true ],
                        'options'   => [
                            '1'  => esc_html__( 'Normal', 'bdevs-elementor' ),
                            '2'  => esc_html__( 'Color', 'bdevs-elementor' ),
                        ],
                        'default'   => '1',
                    ],
                    [
                        'name'        => 'text',
                        'label'       => esc_html__( 'Text:', 'bdevs-elementor' ),
                        'type'        => Controls_Manager::TEXTAREA,
                        'dynamic'     => [ 'active' => true ],
                        'default'     => esc_html__( 'We’re leading a ' , 'bdevs-elementor' ),
                        'label_block' => true,
                    ],  
                    [
                        'name'    => 'background_text',
                        'label'   => esc_html__( 'Background Image', 'bdevs-elementor' ),
                        'type'    => Controls_Manager::MEDIA,
                        'default'     => esc_html__( '' , 'bdevs-elementor' ),
                        'dynamic' => [ 'active' => true ],
                        'condition' => [
                            'heading_style' => '2',
                        ]
                    ],                 
                ],
            ]
        ); 
        $this->add_control(
            'tabs2',
            [
                'label' => esc_html__( 'Items', 'bdevs-elementor' ),
                'type' => Controls_Manager::REPEATER,
                'fields' => [
                    [
                        'name'        => 'title',
                        'label'       => esc_html__( 'Title:', 'bdevs-elementor' ),
                        'type'        => Controls_Manager::TEXTAREA,
                        'dynamic'     => [ 'active' => true ],
                        'default'     => esc_html__( 'people reached across the world in the last year' , 'bdevs-elementor' ),
                        'label_block' => true,
                    ],
                    [
                        'name'        => 'count_from',
                        'label'       => esc_html__( 'Count From:', 'bdevs-elementor' ),
                        'type'        => Controls_Manager::TEXT,
                        'dynamic'     => [ 'active' => true ],
                        'default'     => esc_html__( '0' , 'bdevs-elementor' ),
                        'label_block' => true,
                    ],
                    [
                        'name'        => 'count_to',
                        'label'       => esc_html__( 'Count To:', 'bdevs-elementor' ),
                        'type'        => Controls_Manager::TEXT,
                        'dynamic'     => [ 'active' => true ],
                        'default'     => esc_html__( '50' , 'bdevs-elementor' ),
                        'label_block' => true,
                    ],                    
                    [
                        'name'        => 'after_number',
                        'label'     => esc_html__( 'After Number:', 'bdevs-elementor' ),
                        'type'      => Controls_Manager::SELECT,
                        'dynamic' => [ 'active' => true ],
                        'options'   => [
                            ''  => esc_html__( 'None', 'bdevs-elementor' ),
                            'k'  => esc_html__( 'K', 'bdevs-elementor' ),
                            'm'  => esc_html__( 'M', 'bdevs-elementor' ),
                            'b'  => esc_html__( 'B', 'bdevs-elementor' ),
                            't'  => esc_html__( 'T', 'bdevs-elementor' ),
                            'plus'  => esc_html__( 'Plus', 'bdevs-elementor' ),
                            'percent'  => esc_html__( 'Percent', 'bdevs-elementor' ),
                        ],
                        'default'   => '',
                    ],
                ],
            ]
        );
        $this->end_controls_section();

        $this->start_controls_section(
            'section_content_layout',
            [
                'label' => esc_html__( 'Layout', 'bdevs-elementor' ),
            ]
        );

        $this->add_responsive_control(
            'align',
            [
                'label'   => esc_html__( 'Alignment', 'bdevs-elementor' ),
                'type'    => Controls_Manager::CHOOSE,
                'options' => [
                    'left' => [
                        'title' => esc_html__( 'Left', 'bdevs-elementor' ),
                        'icon'  => 'fa fa-align-left',
                    ],
                    'center' => [
                        'title' => esc_html__( 'Center', 'bdevs-elementor' ),
                        'icon'  => 'fa fa-align-center',
                    ],
                    'right' => [
                        'title' => esc_html__( 'Right', 'bdevs-elementor' ),
                        'icon'  => 'fa fa-align-right',
                    ],
                    'justify' => [
                        'title' => esc_html__( 'Justified', 'bdevs-elementor' ),
                        'icon'  => 'fa fa-align-justify',
                    ],
                ],
                'prefix_class' => 'elementor%s-align-',
                'description'  => 'Use align to match position',
                'default'      => 'left',
            ]
        ); 
        $this->add_control(
            'show_heading',
            [
                'label'   => esc_html__( 'Show Heading', 'bdevs-elementor' ),
                'type'    => Controls_Manager::SWITCHER,
                'default' => 'yes',
            ]
        );
        $this->end_controls_section();
    }
    public function render() {
    $settings  = $this->get_settings_for_display(); 
    extract($settings); ?> 
    <?php $style = $settings['choose_style'];?>
    <?php if( $style == 'style_1' ): ?> 
    <!-- Counter Area start -->
    <section class="counter-area-three pt-120 pb-85">
        <div class="container">
            <?php if ( $settings['show_heading'] ) : ?>
            <div class="row justify-content-center">
                <div class="col-xl-7 col-lg-9">
                    <div class="section-title text-center mb-50 wow fadeInUp delay-0-2s">
                        <?php if(isset($settings['subheading']) && $settings['subheading'] != ''){?>
                        <span class="sub-title mb-15"><?php print wp_kses_post($settings['subheading']); ?></span>
                        <?php } ?>
                        <h4><?php foreach ( $settings['tabs'] as $item ) :  ?>
                        <?php if( wp_kses_post($item['heading_style']) == '1'): ?>
                        <?php print wp_kses_post($item['text']); ?>
                        <?php elseif( wp_kses_post($item['heading_style']) == '2'): ?>
                        <span><?php print wp_kses_post($item['text']); ?></span>  
                        <?php endif; ?> 
                        <?php endforeach; ?></h4>
                    </div>
                </div>
            </div>
            <?php endif; ?>
            <div class="counter-three-wrap">
                <?php foreach ( $settings['tabs2'] as $item2 ) : ?>
                <div class="counter-text-wrap counter-style-two wow fadeInUp delay-0-2s">
                    <span class="count-text <?php print wp_kses_post($item2['after_number']); ?>" data-speed="3000" data-stop="<?php print wp_kses_post($item2['count_to']); ?>"><?php print wp_kses_post($item2['count_from']); ?></span>
                    <?php if(isset($item2['title']) && $item2['title'] != ''){?>
                    <i class="counter-title"><?php print wp_kses_post($item2['title']); ?></i>
                    <?php } ?>
                </div>
                <?php endforeach; ?> 
            </div>
        </div>
    </section>
    <!-- Counter Area end -->
    <?php elseif( $style == 'style_2' ): ?>
    <!-- Counter Area start -->
    <section class="counter-area-three pt-110 pb-75">
        <div class="container">
            <?php if ( $settings['show_heading'] ) : ?>
            <div class="row justify-content-center">
                <div class="col-xl-7 col-lg-9">
                    <div class="section-title text-center mb-50 wow fadeInUp delay-0-2s">
                        <?php if(isset($settings['subheading']) && $settings['subheading'] != ''){?>
                        <span class="sub-title mb-15"><?php print wp_kses_post($settings['subheading']); ?></span>
                        <?php } ?>
                        <h4><?php foreach ( $settings['tabs'] as $item ) :  ?>
                        <?php if( wp_kses_post($item['heading_style']) == '1'): ?>
                        <?php print wp_kses_post($item['text']); ?>
                        <?php elseif( wp_kses_post($item['heading_style']) == '2'): ?>
                        <span class="bgs-100" style="background-image: url(<?php echo wp_kses_post($item['background_text']['url']); ?>);"><?php print wp_kses_post($item['text']); ?></span>  
                        <?php endif; ?> 
                        <?php endforeach; ?></h4>
                    </div>
                </div>
            </div>
            <?php endif; ?>
            <div class="counter-three-wrap color-primary">
                <?php foreach ( $settings['tabs2'] as $item2 ) : ?>
                <div class="counter-text-wrap counter-style-two wow fadeInUp delay-0-2s">
                    <span class="count-text <?php print wp_kses_post($item2['after_number']); ?>" data-speed="3000" data-stop="<?php print wp_kses_post($item2['count_to']); ?>"><?php print wp_kses_post($item2['count_from']); ?></span>
                    <?php if(isset($item2['title']) && $item2['title'] != ''){?>
                    <i class="counter-title"><?php print wp_kses_post($item2['title']); ?></i>
                    <?php } ?>
                </div>
                <?php endforeach; ?> 
            </div>
        </div>
    </section>
    <!-- Counter Area end -->
    <?php endif; ?>
    <?php if (is_admin()) { ?>
    <script type="text/javascript">
    if ($('.counter-text-wrap').length) {
            $('.counter-text-wrap').appear(function () {
                
                var $t = $(this),
                    n = $t.find(".count-text").attr("data-stop"),
                    r = parseInt($t.find(".count-text").attr("data-speed"), 10);

                if (!$t.hasClass("counted")) {
                    $t.addClass("counted");
                    $({
                        countNum: $t.find(".count-text").text()
                    }).animate({
                        countNum: n
                    }, {
                        duration: r,
                        easing: "linear",
                        step: function () {
                            $t.find(".count-text").text(Math.floor(this.countNum));
                        },
                        complete: function () {
                            $t.find(".count-text").text(this.countNum);
                        }
                    });
                }

            }, {
                accY: 0
            });
        }     
    </script>   
    <?php } ?>
    <?php
    }

}