<?php
namespace BdevsElementor\Widget;

use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;
use Elementor\Scheme_Typography;
use Elementor\Group_Control_Border;
use Elementor\Group_Control_Box_Shadow;

/**
 * Bdevs Elementor Widget.
 *
 * Elementor widget that inserts an embbedable content into the page, from any given URL.
 *
 * @since 1.0.0
 */
class BdevsDonateForm extends \Elementor\Widget_Base {

    /**
     * Get widget name.
     *
     * Retrieve Bdevs Elementor widget name.
     *
     * @since 1.0.0
     * @access public
     *
     * @return string Widget name.
     */
    public function get_name() {
        return 'bdevs-donate-form';
    }

    /**
     * Get widget title.
     *
     * Retrieve Bdevs Elementor widget title.
     *
     * @since 1.0.0
     * @access public
     *
     * @return string Widget title.
     */
    public function get_title() {
        return __( 'Donate Form', 'bdevs-elementor' );
    }

    /**
     * Get widget icon.
     *
     * Retrieve Bdevs About widget icon.
     *
     * @since 1.0.0
     * @access public
     *
     * @return string Widget icon.
     */
    public function get_icon() {
        return 'eicon-form-horizontal';
    }

    /**
     * Get widget categories.
     *
     * Retrieve the list of categories the Bdevs About widget belongs to.
     *
     * @since 1.0.0
     * @access public
     *
     * @return array Widget categories.
     */
    public function get_categories() {
        return [ 'bdevs-elementor' ];
    }

    public function get_keywords() {
        return [ 'donate form' ];
    }

    public function get_script_depends() {
        return [ 'bdevs-elementor'];
    }

    // BDT Position
    protected function element_pack_position() {
        $position_options = [
            ''              => esc_html__('Default', 'bdevs-elementor'),
            'top-left'      => esc_html__('Top Left', 'bdevs-elementor') ,
            'top-center'    => esc_html__('Top Center', 'bdevs-elementor') ,
            'top-right'     => esc_html__('Top Right', 'bdevs-elementor') ,
            'center'        => esc_html__('Center', 'bdevs-elementor') ,
            'center-left'   => esc_html__('Center Left', 'bdevs-elementor') ,
            'center-right'  => esc_html__('Center Right', 'bdevs-elementor') ,
            'bottom-left'   => esc_html__('Bottom Left', 'bdevs-elementor') ,
            'bottom-center' => esc_html__('Bottom Center', 'bdevs-elementor') ,
            'bottom-right'  => esc_html__('Bottom Right', 'bdevs-elementor') ,
        ];

        return $position_options;
    }

    protected function _register_controls() {
        
        $this->start_controls_section(
            'section_content_heading',
            [
                'label' => esc_html__( 'Donate Form', 'bdevs-elementor' ),
            ]   
        );
        $this->add_control(
            'choose_style',
            [
                'label'     => esc_html__( 'Choose Style', 'bdevs-elementor' ),
                'type'      => Controls_Manager::SELECT,
                'options'   => [
                    'style_1'  => esc_html__( 'Style 1', 'bdevs-elementor' ),
                    'style_2'  => esc_html__( 'Style 2', 'bdevs-elementor' ),
                ],
                'default'   => 'style_1',
            ]
        );
        $this->add_control(
            'background_image',
            [
                'label'   => esc_html__( 'Background Image:', 'bdevs-elementor' ),
                'type'    => Controls_Manager::MEDIA,
                'dynamic' => [ 'active' => true ],
                'description' => esc_html__( 'Add image from here', 'bdevs-elementor' ),
            ]
        );       
        $this->add_control(
            'shortcode',
            [
                'label'   => esc_html__( 'Shortcode:', 'bdevs-elementor' ),
                'type'    => Controls_Manager::TEXT,
                'dynamic' => [ 'active' => true ],
                'default'       => __('Donate Form Shortcode here', 'bdevs-elementor'),
                'description' => esc_html__( 'Add Your shortcode here', 'bdevs-elementor' ),
                'label_block' => true,
            ]
        );
        $this->add_control(
            'contribute_now',
            [
                'label'       => __( 'Contribute Now Button:', 'bdevs-elementor' ),
                'type'        => Controls_Manager::TEXT,
                'placeholder' => __( 'Enter your text', 'bdevs-elementor' ),
                'default'     => __( 'Contribute Now', 'bdevs-elementor' ),
                'label_block' => true,
            ]
        );
        $this->add_control(
            'show_less',
            [
                'label'       => __( 'Show Less Button:', 'bdevs-elementor' ),
                'type'        => Controls_Manager::TEXT,
                'placeholder' => __( 'Enter your text', 'bdevs-elementor' ),
                'default'     => __( 'Show Less', 'bdevs-elementor' ),
                'label_block' => true,
            ]
        );
        $this->end_controls_section();

        /** 
        *   Layout section 
        **/
        $this->start_controls_section(
            'section_content_layout',
            [
                'label' => esc_html__( 'Layout', 'bdevs-elementor' ),
            ]
        );

        $this->add_responsive_control(
            'align',
            [
                'label'   => esc_html__( 'Alignment', 'bdevs-elementor' ),
                'type'    => Controls_Manager::CHOOSE,
                'options' => [
                    'left' => [
                        'title' => esc_html__( 'Left', 'bdevs-elementor' ),
                        'icon'  => 'fa fa-align-left',
                    ],
                    'center' => [
                        'title' => esc_html__( 'Center', 'bdevs-elementor' ),
                        'icon'  => 'fa fa-align-center',
                    ],
                    'right' => [
                        'title' => esc_html__( 'Right', 'bdevs-elementor' ),
                        'icon'  => 'fa fa-align-right',
                    ],
                    'justify' => [
                        'title' => esc_html__( 'Justified', 'bdevs-elementor' ),
                        'icon'  => 'fa fa-align-justify',
                    ],
                ],
                'prefix_class' => 'elementor%s-align-',
                'description'  => 'Use align to match position',
                'default'      => 'left',
            ]
        ); 
        $this->end_controls_section();

    }

    public function render() {
        $settings  = $this->get_settings_for_display();
        extract($settings); 
        ?>
        <?php $style = $settings['choose_style'];?>
        <?php if( $style == 'style_1' ): ?>  
        <!-- Donate Form Area start -->
        <?php if(isset($settings['background_image']['url']) && $settings['background_image']['url'] != ''){?>
        <section class="donate-form-area py-100 bgs-cover" style="background-image: url(<?php echo wp_kses_post($settings['background_image']['url']);?>)">
        <?php } else { ?>
        <section class="donate-form-area py-100 bgs-cover">
        <?php } ?>
            <div class="container">
               <div class="row justify-content-center">
                   <div class="col-xl-9 col-lg-11 donate-area-form">
                        <?php print do_shortcode(html_entity_decode( $settings['shortcode'] )); ?>
                        <button class="loadmore-btn contri-btn"><?php print wp_kses_post($settings['contribute_now']); ?></button>
                        <button class="loadless-btn loadless-hide"><?php print wp_kses_post($settings['show_less']); ?></button>
                   </div>
               </div>
            </div>
        </section>
        <!-- Donate Form Area end -->
        <?php elseif( $style == 'style_2' ): ?>
        <!-- Donate Form Area start -->
        <?php if(isset($settings['background_image']['url']) && $settings['background_image']['url'] != ''){?>
        <section class="donate-form-area-two py-100 bgs-cover" style="background-image: url(<?php echo wp_kses_post($settings['background_image']['url']);?>)">
        <?php } else { ?>
        <section class="donate-form-area-two py-100 bgs-cover">
        <?php } ?>
            <div class="container">
               <div class="row justify-content-center wow fadeInUp delay-0-2s">
                   <div class="col-xl-9 col-lg-11 donate-area-form">
                        <?php print do_shortcode(html_entity_decode( $settings['shortcode'] )); ?>
                        <button class="loadmore-btn contri-btn"><?php print wp_kses_post($settings['contribute_now']); ?></button>
                        <button class="loadless-btn loadless-hide"><?php print wp_kses_post($settings['show_less']); ?></button>
                   </div>
               </div>
            </div>
        </section>
        <!-- Donate Form Area end -->
        <?php endif; ?>
    <?php
    }
}


