<?php
namespace BdevsElementor\Widget;

use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;
use Elementor\Scheme_Typography;
use Elementor\Group_Control_Border;
use Elementor\Group_Control_Box_Shadow;

/**
 * Bdevs Elementor Widget.
 *
 * Elementor widget that inserts an embbedable content into the page, from any given URL.
 *
 * @since 1.0.0
 */
class BdevsEventDetails1 extends \Elementor\Widget_Base {

    /**
     * Get widget name.
     *
     * Retrieve Bdevs Elementor widget name.
     *
     * @since 1.0.0
     * @access public
     *
     * @return string Widget name.
     */
    public function get_name() {
        return 'bdevs-event-details-1';
    }

    /**
     * Get widget title.
     *
     * Retrieve Bdevs Elementor widget title.
     *
     * @since 1.0.0
     * @access public
     *
     * @return string Widget title.
     */
    public function get_title() {
        return __( 'Event Details 1', 'bdevs-elementor' );
    }

    /**
     * Get widget icon.
     *
     * Retrieve Bdevs About widget icon.
     *
     * @since 1.0.0
     * @access public
     *
     * @return string Widget icon.
     */
    public function get_icon() {
        return 'eicon-text';
    }

    /**
     * Get widget categories.
     *
     * Retrieve the list of categories the Bdevs About widget belongs to.
     *
     * @since 1.0.0
     * @access public
     *
     * @return array Widget categories.
     */
    public function get_categories() {
        return [ 'bdevs-elementor' ];
    }

    public function get_keywords() {
        return [ 'event details 1' ];
    }

    public function get_script_depends() {
        return [ 'bdevs-elementor'];
    }

    // BDT Position
    protected function element_pack_position() {
        $position_options = [
            ''              => esc_html__('Default', 'bdevs-elementor'),
            'top-left'      => esc_html__('Top Left', 'bdevs-elementor') ,
            'top-center'    => esc_html__('Top Center', 'bdevs-elementor') ,
            'top-right'     => esc_html__('Top Right', 'bdevs-elementor') ,
            'center'        => esc_html__('Center', 'bdevs-elementor') ,
            'center-left'   => esc_html__('Center Left', 'bdevs-elementor') ,
            'center-right'  => esc_html__('Center Right', 'bdevs-elementor') ,
            'bottom-left'   => esc_html__('Bottom Left', 'bdevs-elementor') ,
            'bottom-center' => esc_html__('Bottom Center', 'bdevs-elementor') ,
            'bottom-right'  => esc_html__('Bottom Right', 'bdevs-elementor') ,
        ];

        return $position_options;
    }

    protected function _register_controls() {
        
        $this->start_controls_section(
            'section_content_heading',
            [
                'label' => esc_html__( 'Event Details 1', 'bdevs-elementor' ),
            ]   
        );
        $this->add_control(
            'title',
            [
                'label'       => __( 'Title:', 'bdevs-elementor' ),
                'type'        => Controls_Manager::TEXT,
                'placeholder' => __( 'Enter your title', 'bdevs-elementor' ),
                'default'     => __( 'Event Organizer:', 'bdevs-elementor' ),
                'label_block' => true,
            ]
        );
     	$this->add_control(
            'tabs',
            [
                'label' => esc_html__( 'Information:', 'bdevs-elementor' ),
                'type' => Controls_Manager::REPEATER,
                'fields' => [
                    [
                        'name'        => 'choose_style',
                        'label'     => esc_html__( 'Choose Style', 'bdevs-elementor' ),
                        'type'      => Controls_Manager::SELECT,
                        'dynamic' => [ 'active' => true ],
                        'options'   => [
                            '1'  => esc_html__( 'Text', 'bdevs-elementor' ),
                            '2'  => esc_html__( 'Email', 'bdevs-elementor' ),
                            '3'  => esc_html__( 'Phone', 'bdevs-elementor' ),
                            '4'  => esc_html__( 'Link To', 'bdevs-elementor' ),
                        ],
                        'default'   => '1',
                    ],
                    [
                        'name'        => 'title',
                        'label'       => esc_html__( 'Title:', 'bdevs-elementor' ),
                        'type'        => Controls_Manager::TEXT,
                        'dynamic'     => [ 'active' => true ],
                        'default'     => esc_html__( 'Organizer Name:' , 'bdevs-elementor' ),
                        'label_block' => true,
                    ],
                    [
                        'name'        => 'link_to',
                        'label'       => esc_html__( 'Link:', 'bdevs-elementor' ),
                        'type'        => Controls_Manager::TEXT,
                        'dynamic'     => [ 'active' => true ],
                        'default'     => esc_html__( '#' , 'bdevs-elementor' ),
                        'label_block' => true,
                        'condition'   =>[
                            'choose_style' =>['4'],
                        ]
                    ],
                    [
                        'name'        => 'detail',
                        'label'       => esc_html__( 'Detail:', 'bdevs-elementor' ),
                        'type'        => Controls_Manager::TEXTAREA,
                        'dynamic'     => [ 'active' => true ],
                        'default'     => esc_html__( 'HELEN BLUNDELL' , 'bdevs-elementor' ),
                        'label_block' => true,
                    ],
                ],
            ]
        );
        $this->end_controls_section();

        /** 
        *   Layout section 
        **/
        $this->start_controls_section(
            'section_content_layout',
            [
                'label' => esc_html__( 'Layout', 'bdevs-elementor' ),
            ]
        );

        $this->add_responsive_control(
            'align',
            [
                'label'   => esc_html__( 'Alignment', 'bdevs-elementor' ),
                'type'    => Controls_Manager::CHOOSE,
                'options' => [
                    'left' => [
                        'title' => esc_html__( 'Left', 'bdevs-elementor' ),
                        'icon'  => 'fa fa-align-left',
                    ],
                    'center' => [
                        'title' => esc_html__( 'Center', 'bdevs-elementor' ),
                        'icon'  => 'fa fa-align-center',
                    ],
                    'right' => [
                        'title' => esc_html__( 'Right', 'bdevs-elementor' ),
                        'icon'  => 'fa fa-align-right',
                    ],
                    'justify' => [
                        'title' => esc_html__( 'Justified', 'bdevs-elementor' ),
                        'icon'  => 'fa fa-align-justify',
                    ],
                ],
                'prefix_class' => 'elementor%s-align-',
                'description'  => 'Use align to match position',
                'default'      => 'left',
            ]
        ); 
        $this->end_controls_section();

    }

    public function render() {
        $settings  = $this->get_settings_for_display();
        extract($settings); 
        ?>
        <div class="event-organier br-30 bgc-lighter p-40 py-50 mb-30">
            <div class="row">
                <?php if(isset($settings['title']) && $settings['title'] != ''){?>
                <div class="col-xl-4 col-lg-6 col-md-4 col-sm-6">
                    <h5><?php print wp_kses_post($settings['title']); ?></h5>
                </div>
                <?php } ?>
                <?php
                $i=0;
                foreach ( $settings['tabs'] as $item ) :  
                $i++;                                  
                ?>
                <?php if ($i%2==1) { ?>
                <div class="col-xl-4 col-lg-6 col-md-4 col-sm-6">
                    <div class="info-item">
                        <?php if(isset($item['title']) && $item['title'] != ''){?>
                        <h6><?php print wp_kses_post($item['title']); ?></h6>
                        <?php } ?>
                        <?php if( wp_kses_post($item['choose_style']) == '1'): ?>
                        <b><?php print wp_kses_post($item['detail']); ?></b>
                        <?php elseif( wp_kses_post($item['choose_style']) == '2'): ?>
                        <b><a href="mailto:<?php print wp_kses_post($item['detail']); ?>"><?php print wp_kses_post($item['detail']); ?></a></b>
                        <?php elseif( wp_kses_post($item['choose_style']) == '3'): ?>
                        <b><a href="tel:<?php print wp_kses_post($item['detail']); ?>"><?php print wp_kses_post($item['detail']); ?></a></b>
                        <?php elseif( wp_kses_post($item['choose_style']) == '4'): ?>
                        <b><a href="<?php print wp_kses_post($item['link_to']); ?>"><?php print wp_kses_post($item['detail']); ?></a></b>
                        <?php endif; ?>
                    </div>
                    <?php } elseif ($i%2==0) { ?>
                    <div class="info-item">
                        <?php if(isset($item['title']) && $item['title'] != ''){?>
                        <h6><?php print wp_kses_post($item['title']); ?></h6>
                        <?php } ?>
                        <?php if( wp_kses_post($item['choose_style']) == '1'): ?>
                        <b><?php print wp_kses_post($item['detail']); ?></b>
                        <?php elseif( wp_kses_post($item['choose_style']) == '2'): ?>
                        <b><a href="mailto:<?php print wp_kses_post($item['detail']); ?>"><?php print wp_kses_post($item['detail']); ?></a></b>
                        <?php elseif( wp_kses_post($item['choose_style']) == '3'): ?>
                        <b><a href="tel:<?php print wp_kses_post($item['detail']); ?>"><?php print wp_kses_post($item['detail']); ?></a></b>
                        <?php elseif( wp_kses_post($item['choose_style']) == '4'): ?>
                        <b><a href="<?php print wp_kses_post($item['link_to']); ?>"><?php print wp_kses_post($item['detail']); ?></a></b>
                        <?php endif; ?>
                    </div>
                </div>
                <?php } ?>
                <?php endforeach; ?>
            </div>
        </div> 
    <?php
    }
}


