<?php
namespace BdevsElementor\Widget;

use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;
use Elementor\Scheme_Typography;
use Elementor\Group_Control_Border;
use Elementor\Group_Control_Box_Shadow;

/**
 * Bdevs Elementor Widget.
 *
 * Elementor widget that inserts an embbedable content into the page, from any given URL.
 *
 * @since 1.0.0
 */
class BdevsEvents extends \Elementor\Widget_Base {

    /**
     * Get widget name.
     *
     * Retrieve Bdevs Elementor widget name.
     *
     * @since 1.0.0
     * @access public
     *
     * @return string Widget name.
     */
    public function get_name() {
        return 'bdevs-events';
    }

    /**
     * Get widget title.
     *
     * Retrieve Bdevs Elementor widget title.
     *
     * @since 1.0.0
     * @access public
     *
     * @return string Widget title.
     */
    public function get_title() {
        return __( 'Events', 'bdevs-elementor' );
    }

    /**
     * Get widget icon.
     *
     * Retrieve Bdevs About widget icon.
     *
     * @since 1.0.0
     * @access public
     *
     * @return string Widget icon.
     */
    public function get_icon() {
        return 'eicon-gallery-grid';
    }

    /**
     * Get widget categories.
     *
     * Retrieve the list of categories the Bdevs About widget belongs to.
     *
     * @since 1.0.0
     * @access public
     *
     * @return array Widget categories.
     */
    public function get_categories() {
        return [ 'bdevs-elementor' ];
    }

    public function get_keywords() {
        return [ 'events' ];
    }

    public function get_script_depends() {
        return [ 'bdevs-elementor'];
    }

    // BDT Position
    protected function element_pack_position() {
        $position_options = [
            ''              => esc_html__('Default', 'bdevs-elementor'),
            'top-left'      => esc_html__('Top Left', 'bdevs-elementor') ,
            'top-center'    => esc_html__('Top Center', 'bdevs-elementor') ,
            'top-right'     => esc_html__('Top Right', 'bdevs-elementor') ,
            'center'        => esc_html__('Center', 'bdevs-elementor') ,
            'center-left'   => esc_html__('Center Left', 'bdevs-elementor') ,
            'center-right'  => esc_html__('Center Right', 'bdevs-elementor') ,
            'bottom-left'   => esc_html__('Bottom Left', 'bdevs-elementor') ,
            'bottom-center' => esc_html__('Bottom Center', 'bdevs-elementor') ,
            'bottom-right'  => esc_html__('Bottom Right', 'bdevs-elementor') ,
        ];

        return $position_options;
    }

    protected function _register_controls() {
        $this->start_controls_section(
            'section_content_heading',
            [
                'label' => esc_html__( 'Events', 'bdevs-elementor' ),
            ]   
        ); 
        $this->add_control(
            'tabs',
            [
                'label' => esc_html__( 'Heading:', 'bdevs-elementor' ),
                'type' => Controls_Manager::REPEATER,
                'fields' => [
                    [
                        'name'        => 'heading_style',
                        'label'     => esc_html__( 'Heading Style:', 'bdevs-elementor' ),
                        'type'      => Controls_Manager::SELECT,
                        'dynamic' => [ 'active' => true ],
                        'options'   => [
                            '1'  => esc_html__( 'Normal', 'bdevs-elementor' ),
                            '2'  => esc_html__( 'Special', 'bdevs-elementor' ),
                        ],
                        'default'   => '1',
                    ],
                    [
                        'name'        => 'text',
                        'label'       => esc_html__( 'Text:', 'bdevs-elementor' ),
                        'type'        => Controls_Manager::TEXTAREA,
                        'dynamic'     => [ 'active' => true ],
                        'default'     => esc_html__( 'Recent ' , 'bdevs-elementor' ),
                        'label_block' => true,
                    ],                   
                ],
            ]
        ); 
        $this->add_control(
            'description',
            [
                'label'       => __( 'Description:', 'bdevs-elementor' ),
                'type'        => Controls_Manager::TEXTAREA,
                'placeholder' => __( 'Enter your description', 'bdevs-elementor' ),
                'default'     => __( 'adipisicing elit Rem autem voluptatem obcaecati', 'bdevs-elementor' ),
                'label_block' => true,
            ]
        );       
        $this->add_control(
            'post_number',
            [
                'label'       => __( 'Posts Per Page:', 'bdevs-elementor' ),
                'type'        => Controls_Manager::TEXT,
                'placeholder' => __( 'Enter your posts per page', 'bdevs-elementor' ),
                'default'     => __( '3', 'bdevs-elementor' ),
                'label_block' => true,
            ]
        );
        $this->add_control(
            'sortby',
            [
                'label'     => esc_html__( 'Sort', 'bdevs-elementor' ),
                'type'      => Controls_Manager::SELECT,
                'options'   => [
                    'sortby_style_1'  => esc_html__( 'Newest', 'bdevs-elementor' ),
                    'sortby_style_2'  => esc_html__( 'Oldest', 'bdevs-elementor' ),
                ],
                'default'   => 'sortby_style_1',
            ]
        );
        $this->add_control(
            'before_button',
            [
                'label'       => __( 'Before Button:', 'bdevs-elementor' ),
                'type'        => Controls_Manager::TEXT,
                'placeholder' => __( 'Enter your text', 'bdevs-elementor' ),
                'default'     => __( 'Want to see our Recent Causes.', 'bdevs-elementor' ),
                'label_block' => true,
            ]
        );
        $this->add_control(
            'link_button',
            [
                'label'       => __( 'Link Button:', 'bdevs-elementor' ),
                'type'        => Controls_Manager::TEXT,
                'placeholder' => __( 'Enter link button', 'bdevs-elementor' ),
                'default'     => __( '#' ),
                'label_block' => true,
            ]
        );
        $this->add_control(
            'button',
            [
                'label'       => __( 'Button:', 'bdevs-elementor' ),
                'type'        => Controls_Manager::TEXT,
                'placeholder' => __( 'Enter button', 'bdevs-elementor' ),
                'default'     => __( 'Click here to View More' ),
                'label_block' => true,
            ]
        );
        $this->end_controls_section();
        /** 
        *   Layout section 
        **/
        $this->start_controls_section(
            'section_content_layout',
            [
                'label' => esc_html__( 'Layout', 'bdevs-elementor' ),
            ]
        );
        $this->add_responsive_control(
            'align',
            [
                'label'   => esc_html__( 'Alignment', 'bdevs-elementor' ),
                'type'    => Controls_Manager::CHOOSE,
                'options' => [
                    'left' => [
                        'title' => esc_html__( 'Left', 'bdevs-elementor' ),
                        'icon'  => 'fa fa-align-left',
                    ],
                    'center' => [
                        'title' => esc_html__( 'Center', 'bdevs-elementor' ),
                        'icon'  => 'fa fa-align-center',
                    ],
                    'right' => [
                        'title' => esc_html__( 'Right', 'bdevs-elementor' ),
                        'icon'  => 'fa fa-align-right',
                    ],
                    'justify' => [
                        'title' => esc_html__( 'Justified', 'bdevs-elementor' ),
                        'icon'  => 'fa fa-align-justify',
                    ],
                ],
                'prefix_class' => 'elementor%s-align-',
                'description'  => 'Use align to match position',
                'default'      => 'left',
            ]
        );
        $this->add_control(
            'show_heading',
            [
                'label'   => esc_html__( 'Show Heading', 'bdevs-elementor' ),
                'type'    => Controls_Manager::SWITCHER,
                'default' => 'yes',
            ]
        );
        $this->end_controls_section();

    }

    public function render() {
    $settings  = $this->get_settings_for_display();
    extract($settings); 
    if ($settings['sortby']=='sortby_style_1') {
        $sortby = 'DESC';
    }
    if ($settings['sortby']=='sortby_style_2') {
        $sortby = 'ASC';
    }
    ?>
    <!-- Event Area start -->
    <section class="event-area py-105">
        <div class="container">
            <?php if ( $settings['show_heading'] ) : ?>
            <div class="section-title text-center mb-15 wow fadeInUp delay-0-2s">
               <h2><?php foreach ( $settings['tabs'] as $item ) :  ?>
                    <?php if( wp_kses_post($item['heading_style']) == '1'): ?>
                    <?php print wp_kses_post($item['text']); ?>
                    <?php elseif( wp_kses_post($item['heading_style']) == '2'): ?>
                    <span><?php print wp_kses_post($item['text']); ?></span>  
                    <?php endif; ?> 
                    <?php endforeach; ?></h2>
                <?php if(isset($settings['description']) && $settings['description'] != ''){?>
                <p><?php print wp_kses_post($settings['description']); ?></p>
                <?php } ?>
               <span class="line"></span>
            </div>
            <?php endif; ?>
            <div class="row justify-content-center">
                <div class="col-xl-10">
                    <?php $post_number = $settings['post_number'];
                    $wp_query = new \WP_Query(array('posts_per_page' => $post_number,'post_type' => 'event',  'orderby' => 'ID', 'order' => $sortby));     
                    $args = new \WP_Query(array(   
                        'post_type' => 'event', 
                    )); 
                    while ($wp_query -> have_posts()) : $wp_query -> the_post(); 
                    $e_featured_image_2 = get_post_meta(get_the_ID(),'_cmb_e_featured_image_2', true);
                    $e_description = get_post_meta(get_the_ID(),'_cmb_e_description', true);
                    $e_location = get_post_meta(get_the_ID(),'_cmb_e_location', true);
                    ?>
                    <div class="event-item wow fadeInUp delay-0-3s">
                        <div class="content">
                           <div class="date">
                               <b><?php echo get_the_date( 'd' );?></b>
                               <span><?php echo get_the_date( 'M, Y' );?></span>
                           </div>
                            <ul class="admin-heart">
                               <li>
                                   <?php echo get_avatar(get_the_author_meta('user_email'),$size='30', $default='http://0.gravatar.com/avatar/ad516503a11cd5ca435acc9bb6523536?s=120' );?>
                                    <i><span class="before-author"><?php if(isset($charitxa_redux_demo['by'])){?>
                                        <?php echo wp_specialchars_decode(esc_attr($charitxa_redux_demo['by']));?>
                                        <?php }else{?>
                                        <?php echo esc_html__( 'By:', 'charitxa' ); } ?></span><?php the_author_posts_link(); ?></i>
                               </li>
                               <li>
                                   <i class="fas fa-eye"></i> <?php echo gt_get_post_view(); ?>
                               </li>
                            </ul>
                            <h5><a href="<?php the_permalink();?>"><?php the_title(); ?></a></h5>
                            <?php if(isset($e_description) && $e_description != '') { ?>
                            <p><?php echo esc_attr($e_description); ?></p>
                            <?php } ?>
                        </div>
                        <div class="image">
                            <?php if(isset($e_featured_image_2) && $e_featured_image_2 != '') { ?>
                            <a href="<?php the_permalink();?>"><img src="<?php echo wp_get_attachment_url($e_featured_image_2);?>" alt="causes"></a>
                            <?php } ?>
                            <?php if(isset($e_location) && $e_location != '') { ?>
                            <span class="location"><i class="fas fa-map-marker"></i> <?php echo esc_attr($e_location); ?></span>
                            <?php } ?>
                        </div>
                    </div>
                    <?php endwhile; ?>
                </div>
            </div>
            <?php if(isset($settings['link_button']) && $settings['link_button'] != ''){?>
            <div class="more-btn-with-text text-center pt-30 wow fadeInUp delay-0-2s">
                <i><?php print wp_kses_post($settings['before_button']); ?><a href="<?php print wp_kses_post($settings['link_button']); ?>"><?php print wp_kses_post($settings['button']); ?></a></i>
            </div>
            <?php } ?>
        </div>
    </section>
    <!-- Event Area end -->
    <?php
    }
}


