<?php
namespace BdevsElementor\Widget;

use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;
use Elementor\Scheme_Typography;
use Elementor\Group_Control_Border;
use Elementor\Group_Control_Box_Shadow;

/**
 * Bdevs Elementor Widget.
 *
 * Elementor widget that inserts an embbedable content into the page, from any given URL.
 *
 * @since 1.0.0
 */
class BdevsFeatures2 extends \Elementor\Widget_Base {

    /**
     * Get widget name.
     *
     * Retrieve Bdevs Elementor widget name.
     *
     * @since 1.0.0
     * @access public
     *
     * @return string Widget name.
     */
    public function get_name() {
        return 'bdevs-features-2';
    }

    /**
     * Get widget title.
     *
     * Retrieve Bdevs Elementor widget title.
     *
     * @since 1.0.0
     * @access public
     *
     * @return string Widget title.
     */
    public function get_title() {
        return __( 'Features 2', 'bdevs-elementor' );
    }

    /**
     * Get widget icon.
     *
     * Retrieve Bdevs About widget icon.
     *
     * @since 1.0.0
     * @access public
     *
     * @return string Widget icon.
     */
    public function get_icon() {
        return 'eicon-apps';
    }

    /**
     * Get widget categories.
     *
     * Retrieve the list of categories the Bdevs About widget belongs to.
     *
     * @since 1.0.0
     * @access public
     *
     * @return array Widget categories.
     */
    public function get_categories() {
        return [ 'bdevs-elementor' ];
    }

    public function get_keywords() {
        return [ 'features 2' ];
    }

    public function get_script_depends() {
        return [ 'bdevs-elementor'];
    }

    // BDT Position
    protected function element_pack_position() {
        $position_options = [
            ''              => esc_html__('Default', 'bdevs-elementor'),
            'top-left'      => esc_html__('Top Left', 'bdevs-elementor') ,
            'top-center'    => esc_html__('Top Center', 'bdevs-elementor') ,
            'top-right'     => esc_html__('Top Right', 'bdevs-elementor') ,
            'center'        => esc_html__('Center', 'bdevs-elementor') ,
            'center-left'   => esc_html__('Center Left', 'bdevs-elementor') ,
            'center-right'  => esc_html__('Center Right', 'bdevs-elementor') ,
            'bottom-left'   => esc_html__('Bottom Left', 'bdevs-elementor') ,
            'bottom-center' => esc_html__('Bottom Center', 'bdevs-elementor') ,
            'bottom-right'  => esc_html__('Bottom Right', 'bdevs-elementor') ,
        ];

        return $position_options;
    }

    protected function _register_controls() {
        $this->start_controls_section(
            'section_content_heading',
            [
                'label' => esc_html__( 'Features 2', 'bdevs-elementor' ),
            ]   
        );
        $this->add_control(
            'background_image',
            [
                'label'   => esc_html__( 'Background Image:', 'bdevs-elementor' ),
                'type'    => Controls_Manager::MEDIA,
                'dynamic' => [ 'active' => true ],
                'description' => esc_html__( 'Add image from here', 'bdevs-elementor' ),
            ]
        ); 
        $this->add_control(
            'tabs',
            [
                'label' => esc_html__( 'Heading:', 'bdevs-elementor' ),
                'type' => Controls_Manager::REPEATER,
                'fields' => [
                    [
                        'name'        => 'heading_style',
                        'label'     => esc_html__( 'Heading Style:', 'bdevs-elementor' ),
                        'type'      => Controls_Manager::SELECT,
                        'dynamic' => [ 'active' => true ],
                        'options'   => [
                            '1'  => esc_html__( 'Normal', 'bdevs-elementor' ),
                            '2'  => esc_html__( 'Color', 'bdevs-elementor' ),
                        ],
                        'default'   => '1',
                    ],
                    [
                        'name'        => 'text',
                        'label'       => esc_html__( 'Text:', 'bdevs-elementor' ),
                        'type'        => Controls_Manager::TEXTAREA,
                        'dynamic'     => [ 'active' => true ],
                        'default'     => esc_html__( 'Million of People Live Amongst High Levels' , 'bdevs-elementor' ),
                        'label_block' => true,
                    ],                   
                ],
            ]
        );
        $this->add_control(
            'description',
            [
                'label'       => __( 'Description:', 'bdevs-elementor' ),
                'type'        => Controls_Manager::TEXTAREA,
                'placeholder' => __( 'Enter your description', 'bdevs-elementor' ),
                'default'     => __( 'This is description' ),
                'label_block' => true,
            ]
        );
        $this->add_control(
            'tabs2',
            [
                'label' => esc_html__( 'Items', 'bdevs-elementor' ),
                'type' => Controls_Manager::REPEATER,
                'fields' => [
                    [
                        'name'        => 'mt_style',
                        'label'     => esc_html__( 'Style', 'bdevs-elementor' ),
                        'type'      => Controls_Manager::SELECT,
                        'dynamic' => [ 'active' => true ],
                        'options'   => [
                            '1'  => esc_html__( 'Normal', 'bdevs-elementor' ),
                            '2'  => esc_html__( 'Have Margin Top', 'bdevs-elementor' ),
                        ],
                        'default'   => '1',
                    ],
                    [
                        'name'    => 'background_icon',
                        'label'   => esc_html__( 'Background Icon:', 'bdevs-elementor' ),
                        'type'    => Controls_Manager::MEDIA,
                        'default'     => esc_html__( '' , 'bdevs-elementor' ),
                        'dynamic' => [ 'active' => true ],
                    ],
                    [
                        'name'    => 'icon_image',
                        'label'   => esc_html__( 'Image Icon:', 'bdevs-elementor' ),
                        'type'    => Controls_Manager::MEDIA,
                        'default'     => esc_html__( '' , 'bdevs-elementor' ),
                        'dynamic' => [ 'active' => true ],
                    ],
                    [
                        'name'        => 'title',
                        'label'       => esc_html__( 'Title:', 'bdevs-elementor' ),
                        'type'        => Controls_Manager::TEXT,
                        'dynamic'     => [ 'active' => true ],
                        'default'     => esc_html__( 'Air Quality Consulting Engineering' , 'bdevs-elementor' ),
                        'label_block' => true,
                    ], 
                ],
            ]
        );
         $this->add_control(
            'bottom_image',
            [
                'label'   => esc_html__( 'Bottom Image:', 'bdevs-elementor' ),
                'type'    => Controls_Manager::MEDIA,
                'dynamic' => [ 'active' => true ],
                'description' => esc_html__( 'Add image from here', 'bdevs-elementor' ),
            ]
        );
        $this->end_controls_section();
        /** 
        *   Layout section 
        **/
        $this->start_controls_section(
            'section_content_layout',
            [
                'label' => esc_html__( 'Layout', 'bdevs-elementor' ),
            ]
        );
        $this->add_responsive_control(
            'align',
            [
                'label'   => esc_html__( 'Alignment', 'bdevs-elementor' ),
                'type'    => Controls_Manager::CHOOSE,
                'options' => [
                    'left' => [
                        'title' => esc_html__( 'Left', 'bdevs-elementor' ),
                        'icon'  => 'fa fa-align-left',
                    ],
                    'center' => [
                        'title' => esc_html__( 'Center', 'bdevs-elementor' ),
                        'icon'  => 'fa fa-align-center',
                    ],
                    'right' => [
                        'title' => esc_html__( 'Right', 'bdevs-elementor' ),
                        'icon'  => 'fa fa-align-right',
                    ],
                    'justify' => [
                        'title' => esc_html__( 'Justified', 'bdevs-elementor' ),
                        'icon'  => 'fa fa-align-justify',
                    ],
                ],
                'prefix_class' => 'elementor%s-align-',
                'description'  => 'Use align to match position',
                'default'      => 'left',
            ]
        );
        $this->add_control(
            'show_heading',
            [
                'label'   => esc_html__( 'Show Heading', 'bdevs-elementor' ),
                'type'    => Controls_Manager::SWITCHER,
                'default' => 'yes',
            ]
        );
        $this->end_controls_section();

    }

    public function render() {
    $settings  = $this->get_settings_for_display();
    extract($settings); ?>
    <!-- Pollution Two Area start -->
    <?php if(isset($settings['background_image']['url']) && $settings['background_image']['url'] != ''){?>
    <section class="pollution-lavel-area py-120 rel z-1 bgs-cover" style="background-image: url(<?php echo wp_kses_post($settings['background_image']['url']);?>);">
    <?php } else { ?>
    <section class="pollution-lavel-area py-120 rel z-1 bgs-cover">
    <?php } ?>
        <div class="container">
            <?php if ( $settings['show_heading'] ) : ?>
            <div class="row justify-content-center">
                <div class="col-xl-8 col-lg-10">
                    <div class="pollution-lavel-content text-center mb-45 rmb-30 wow fadeInUp delay-0-2s">
                        <div class="section-title mb-25">
                            <h2><?php foreach ( $settings['tabs'] as $item ) :  ?>
                                <?php if( wp_kses_post($item['heading_style']) == '1'): ?>
                                <?php print wp_kses_post($item['text']); ?>
                                <?php elseif( wp_kses_post($item['heading_style']) == '2'): ?>
                                <span><?php print wp_kses_post($item['text']); ?></span>  
                                <?php endif; ?> 
                                <?php endforeach; ?></h2>
                            <?php if(isset($settings['description']) && $settings['description'] != ''){?>
                            <p><?php print wp_kses_post($settings['description']); ?></p>
                            <?php } ?>
                        </div>
                    </div>
                </div>
            </div>
            <?php endif; ?>
            <div class="row justify-content-center">
                <?php 
                $i=0;
                foreach ( $settings['tabs2'] as $item2 ) :   
                ?>
                <div class="col-lg-3 col-sm-6">
                    <?php if( wp_kses_post($item2['mt_style']) == '2'): ?>
                    <div class="pollution-lavel-item mt-100 wow fadeInUp delay-0-<?php echo  $i; ?>s">
                    <?php elseif( wp_kses_post($item2['mt_style']) == '1'): ?>
                    <div class="pollution-lavel-item wow fadeInUp delay-0-<?php echo  $i; ?>s">
                    <?php endif; ?>
                        <?php if(isset($item2['title']) && $item2['title'] != ''){?>
                        <h5><?php print wp_kses_post($item2['title']); ?></h5>
                        <?php } ?>
                        <?php if(isset($item2['icon_image']['url']) && $item2['icon_image']['url'] != ''){?>
                        <div class="icon" style="background-image: url(<?php echo wp_kses_post($item2['background_icon']['url']); ?>);">
                            <img src="<?php echo wp_kses_post($item2['icon_image']['url']); ?>" alt="Icon">
                        </div>
                        <?php } ?>
                    </div>
                </div>
                <?php $i = $i+1; ?>
                <?php endforeach; ?>
            </div>
            <?php if(isset($settings['bottom_image']['url']) && $settings['bottom_image']['url'] != ''){?>
            <div class="pollution-bottom-image text-center">
                <img src="<?php echo wp_kses_post($settings['bottom_image']['url']);?>" alt="Pollution">
            </div>
            <?php } ?>
        </div>
    </section>
    <!-- Pollution Two Area end -->
    <?php
    }
}


