<?php
namespace BdevsElementor\Widget;

use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;
use Elementor\Scheme_Typography;
use Elementor\Group_Control_Border;
use Elementor\Group_Control_Box_Shadow;

/**
 * Bdevs Elementor Widget.
 *
 * Elementor widget that inserts an embbedable content into the page, from any given URL.
 *
 * @since 1.0.0
 */
class BdevsFeatures3 extends \Elementor\Widget_Base {

    /**
     * Get widget name.
     *
     * Retrieve Bdevs Elementor widget name.
     *
     * @since 1.0.0
     * @access public
     *
     * @return string Widget name.
     */
    public function get_name() {
        return 'bdevs-features-3';
    }

    /**
     * Get widget title.
     *
     * Retrieve Bdevs Elementor widget title.
     *
     * @since 1.0.0
     * @access public
     *
     * @return string Widget title.
     */
    public function get_title() {
        return __( 'Features 3', 'bdevs-elementor' );
    }

    /**
     * Get widget icon.
     *
     * Retrieve Bdevs About widget icon.
     *
     * @since 1.0.0
     * @access public
     *
     * @return string Widget icon.
     */
    public function get_icon() {
        return 'eicon-posts-justified';
    }

    /**
     * Get widget categories.
     *
     * Retrieve the list of categories the Bdevs About widget belongs to.
     *
     * @since 1.0.0
     * @access public
     *
     * @return array Widget categories.
     */
    public function get_categories() {
        return [ 'bdevs-elementor' ];
    }

    public function get_keywords() {
        return [ 'features 3' ];
    }

    public function get_script_depends() {
        return [ 'bdevs-elementor'];
    }

    // BDT Position
    protected function element_pack_position() {
        $position_options = [
            ''              => esc_html__('Default', 'bdevs-elementor'),
            'top-left'      => esc_html__('Top Left', 'bdevs-elementor') ,
            'top-center'    => esc_html__('Top Center', 'bdevs-elementor') ,
            'top-right'     => esc_html__('Top Right', 'bdevs-elementor') ,
            'center'        => esc_html__('Center', 'bdevs-elementor') ,
            'center-left'   => esc_html__('Center Left', 'bdevs-elementor') ,
            'center-right'  => esc_html__('Center Right', 'bdevs-elementor') ,
            'bottom-left'   => esc_html__('Bottom Left', 'bdevs-elementor') ,
            'bottom-center' => esc_html__('Bottom Center', 'bdevs-elementor') ,
            'bottom-right'  => esc_html__('Bottom Right', 'bdevs-elementor') ,
        ];

        return $position_options;
    }

    protected function _register_controls() {
        $this->start_controls_section(
            'section_content_heading',
            [
                'label' => esc_html__( 'Features 3', 'bdevs-elementor' ),
            ]   
        );
        $this->add_control(
            'background_image',
            [
                'label'   => esc_html__( 'Background Image:', 'bdevs-elementor' ),
                'type'    => Controls_Manager::MEDIA,
                'dynamic' => [ 'active' => true ],
                'description' => esc_html__( 'Add image from here', 'bdevs-elementor' ),
            ]
        ); 
        $this->add_control(
            'subheading',
            [
                'label'       => __( 'Subheading:', 'bdevs-elementor' ),
                'type'        => Controls_Manager::TEXT,
                'placeholder' => __( 'Enter your subheading', 'bdevs-elementor' ),
                'default'     => __( 'Donate For Contribution', 'bdevs-elementor' ),
                'label_block' => true,
            ]
        );
        $this->add_control(
            'tabs',
            [
                'label' => esc_html__( 'Heading:', 'bdevs-elementor' ),
                'type' => Controls_Manager::REPEATER,
                'fields' => [
                    [
                        'name'        => 'heading_style',
                        'label'     => esc_html__( 'Heading Style:', 'bdevs-elementor' ),
                        'type'      => Controls_Manager::SELECT,
                        'dynamic' => [ 'active' => true ],
                        'options'   => [
                            '1'  => esc_html__( 'Normal', 'bdevs-elementor' ),
                            '2'  => esc_html__( 'Special', 'bdevs-elementor' ),
                        ],
                        'default'   => '1',
                    ],
                    [
                        'name'        => 'text',
                        'label'       => esc_html__( 'Text:', 'bdevs-elementor' ),
                        'type'        => Controls_Manager::TEXTAREA,
                        'dynamic'     => [ 'active' => true ],
                        'default'     => esc_html__( 'Here’s how you ' , 'bdevs-elementor' ),
                        'label_block' => true,
                    ],                   
                ],
            ]
        );
        $this->add_control(
            'description',
            [
                'label'       => __( 'Description:', 'bdevs-elementor' ),
                'type'        => Controls_Manager::TEXTAREA,
                'placeholder' => __( 'Enter your description', 'bdevs-elementor' ),
                'default'     => __( 'This is description' ),
                'label_block' => true,
            ]
        );
        $this->add_control(
            'tabs2',
            [
                'label' => esc_html__( 'Items', 'bdevs-elementor' ),
                'type' => Controls_Manager::REPEATER,
                'fields' => [
                    [
                        'name'    => 'feature_image',
                        'label'   => esc_html__( 'Image:', 'bdevs-elementor' ),
                        'type'    => Controls_Manager::MEDIA,
                        'default'     => esc_html__( '' , 'bdevs-elementor' ),
                        'dynamic' => [ 'active' => true ],
                    ],
                    [
                        'name'    => 'image_icon',
                        'label'   => esc_html__( 'Image Icon:', 'bdevs-elementor' ),
                        'type'    => Controls_Manager::MEDIA,
                        'default'     => esc_html__( '' , 'bdevs-elementor' ),
                        'dynamic' => [ 'active' => true ],
                    ],
                    [
                        'name'        => 'title',
                        'label'       => esc_html__( 'Title:', 'bdevs-elementor' ),
                        'type'        => Controls_Manager::TEXT,
                        'dynamic'     => [ 'active' => true ],
                        'default'     => esc_html__( 'Send Gifts' , 'bdevs-elementor' ),
                        'label_block' => true,
                    ],
                    [
                        'name'        => 'text',
                        'label'       => esc_html__( 'Text:', 'bdevs-elementor' ),
                        'type'        => Controls_Manager::TEXTAREA,
                        'dynamic'     => [ 'active' => true ],
                        'default'     => esc_html__( 'In the land of plenty, millions of boys & girls are going to bed hungry.' , 'bdevs-elementor' ),
                        'label_block' => true,
                    ],
                    [
                        'name'        => 'button_style',
                        'label'     => esc_html__( 'Button Style', 'bdevs-elementor' ),
                        'type'      => Controls_Manager::SELECT,
                        'dynamic' => [ 'active' => true ],
                        'options'   => [
                            '1'  => esc_html__( 'Link To', 'bdevs-elementor' ),
                            '2'  => esc_html__( 'Donate Form', 'bdevs-elementor' ),
                        ],
                        'default'   => '1',
                    ],
                    [
                        'name'        => 'link_button',
                        'label'       => esc_html__( 'Link Button:', 'bdevs-elementor' ),
                        'type'        => Controls_Manager::TEXT,
                        'dynamic'     => [ 'active' => true ],
                        'default'     => esc_html__( '#' , 'bdevs-elementor' ),
                        'label_block' => true,
                        'condition'   => [
                            'button_style' => '1',
                        ]
                    ],
                    [
                        'name'        => 'button',
                        'label'       => esc_html__( 'Button:', 'bdevs-elementor' ),
                        'type'        => Controls_Manager::TEXT,
                        'dynamic'     => [ 'active' => true ],
                        'default'     => esc_html__( 'Shop Now' , 'bdevs-elementor' ),
                        'label_block' => true,
                    ],
                ],
            ]
        );
        $this->end_controls_section();
        /** 
        *   Layout section 
        **/
        $this->start_controls_section(
            'section_content_layout',
            [
                'label' => esc_html__( 'Layout', 'bdevs-elementor' ),
            ]
        );
        $this->add_responsive_control(
            'align',
            [
                'label'   => esc_html__( 'Alignment', 'bdevs-elementor' ),
                'type'    => Controls_Manager::CHOOSE,
                'options' => [
                    'left' => [
                        'title' => esc_html__( 'Left', 'bdevs-elementor' ),
                        'icon'  => 'fa fa-align-left',
                    ],
                    'center' => [
                        'title' => esc_html__( 'Center', 'bdevs-elementor' ),
                        'icon'  => 'fa fa-align-center',
                    ],
                    'right' => [
                        'title' => esc_html__( 'Right', 'bdevs-elementor' ),
                        'icon'  => 'fa fa-align-right',
                    ],
                    'justify' => [
                        'title' => esc_html__( 'Justified', 'bdevs-elementor' ),
                        'icon'  => 'fa fa-align-justify',
                    ],
                ],
                'prefix_class' => 'elementor%s-align-',
                'description'  => 'Use align to match position',
                'default'      => 'left',
            ]
        );
        $this->add_control(
            'show_heading',
            [
                'label'   => esc_html__( 'Show Heading', 'bdevs-elementor' ),
                'type'    => Controls_Manager::SWITCHER,
                'default' => 'yes',
            ]
        );
        $this->end_controls_section();

    }

    public function render() {
    $settings  = $this->get_settings_for_display();
    extract($settings); ?>
    <!-- Features Area start -->
    <section class="features-area-three pt-120 pb-90 rpb-90 rel z-2">
        <style type="text/css">
            .features-area-three:before {
                background: url(<?php echo wp_kses_post($settings['background_image']['url']);?>) center/cover;
            }
        </style>
        <div class="container">
            <?php if ( $settings['show_heading'] ) : ?>
            <div class="row justify-content-center">
                <div class="col-xl-7 col-lg-9">
                    <div class="section-title text-center text-white mb-45 wow fadeInUp delay-0-2s">
                        <?php if(isset($settings['subheading']) && $settings['subheading'] != ''){?>
                        <span class="sub-title"><?php print wp_kses_post($settings['subheading']); ?></span>
                        <?php } ?>
                        <h2><?php foreach ( $settings['tabs'] as $item ) :  ?>
                            <?php if( wp_kses_post($item['heading_style']) == '1'): ?>
                            <?php print wp_kses_post($item['text']); ?>
                            <?php elseif( wp_kses_post($item['heading_style']) == '2'): ?>
                            <span><?php print wp_kses_post($item['text']); ?></span>  
                            <?php endif; ?> 
                            <?php endforeach; ?></h2>
                        <?php if(isset($settings['description']) && $settings['description'] != ''){?>
                        <p><?php print wp_kses_post($settings['description']); ?></p>
                        <?php } ?>
                    </div>
                </div>
            </div>
            <?php endif; ?>
            <div class="row justify-content-center">
                <?php 
                $i=0;
                foreach ( $settings['tabs2'] as $item2 ) :   
                ?>
                <?php if( wp_kses_post($item2['button_style']) == '1'): ?>
                <div class="col-lg-4 col-md-6">
                    <div class="feature-item style-two wow fadeInUp delay-0-<?php echo  $i; ?>s">
                        <?php if(isset($item2['feature_image']['url']) && $item2['feature_image']['url'] != ''){?>
                        <div class="image">
                            <a href="<?php print wp_kses_post($item2['link_button']); ?>"><img src="<?php echo wp_kses_post($item2['feature_image']['url']); ?>" alt="Feature"></a>
                        </div>
                        <?php } ?>
                        <div class="content">
                            <?php if(isset($item2['image_icon']['url']) && $item2['image_icon']['url'] != ''){?>
                            <div class="icon"><img src="<?php echo wp_kses_post($item2['image_icon']['url']); ?>" alt="Icon"></div>
                            <?php } ?>
                            <?php if(isset($item2['title']) && $item2['title'] != ''){?>
                            <h5><a href="<?php print wp_kses_post($item2['link_button']); ?>"><?php print wp_kses_post($item2['title']); ?></a></h5>
                            <?php } ?>
                            <?php if(isset($item2['text']) && $item2['text'] != ''){?>
                            <p><?php print wp_kses_post($item2['text']); ?></p>
                            <?php } ?>
                            <?php if(isset($item2['link_button']) && $item2['link_button'] != ''){?>
                            <a href="<?php print wp_kses_post($item2['link_button']); ?>" class="read-more mt-20"><?php print wp_kses_post($item2['button']); ?> <i class="far fa-chevron-double-right"></i></a>
                            <?php } ?>
                        </div>
                    </div>
                </div>
                <?php elseif( wp_kses_post($item2['button_style']) == '2'): ?>
                <div class="col-lg-4 col-md-6">
                    <div class="feature-item style-two wow fadeInUp delay-0-6s">
                        <?php if(isset($item2['feature_image']['url']) && $item2['feature_image']['url'] != ''){?>
                        <div class="image">
                            <a href="#" data-bs-toggle="modal" data-bs-target="#donateModal"><img src="<?php echo wp_kses_post($item2['feature_image']['url']); ?>" alt="Feature"></a>
                        </div>
                        <?php } ?>
                        <div class="content">
                            <?php if(isset($item2['image_icon']['url']) && $item2['image_icon']['url'] != ''){?>
                            <div class="icon"><img src="<?php echo wp_kses_post($item2['image_icon']['url']); ?>" alt="Icon"></div>
                            <?php } ?>
                            <?php if(isset($item2['title']) && $item2['title'] != ''){?>
                            <h5><a href="#" data-bs-toggle="modal" data-bs-target="#donateModal"><?php print wp_kses_post($item2['title']); ?></a></h5>
                            <?php } ?>
                            <?php if(isset($item2['text']) && $item2['text'] != ''){?>
                            <p><?php print wp_kses_post($item2['text']); ?></p>
                            <?php } ?>
                            <?php if(isset($item2['link_button']) && $item2['link_button'] != ''){?>
                            <a href="#" class="read-more mt-20" data-bs-toggle="modal" data-bs-target="#donateModal"><?php print wp_kses_post($item2['button']); ?> <i class="far fa-chevron-double-right"></i></a>
                            <?php } ?>
                        </div>
                    </div>
                </div>
                <?php endif; ?>
                <?php $i = $i+2; ?>
                <?php endforeach; ?>
            </div>
        </div>
    </section>
    <!-- Features Area end -->
    <?php
    }
}


