<?php
namespace BdevsElementor\Widget;

use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;
use Elementor\Scheme_Typography;
use Elementor\Group_Control_Border;
use Elementor\Group_Control_Box_Shadow;

/**
 * Bdevs Elementor Widget.
 *
 * Elementor widget that inserts an embbedable content into the page, from any given URL.
 *
 * @since 1.0.0
 */
class BdevsMeter extends \Elementor\Widget_Base {

    /**
     * Get widget name.
     *
     * Retrieve Bdevs Elementor widget name.
     *
     * @since 1.0.0
     * @access public
     *
     * @return string Widget name.
     */
    public function get_name() {
        return 'bdevs-meter';
    }

    /**
     * Get widget title.
     *
     * Retrieve Bdevs Elementor widget title.
     *
     * @since 1.0.0
     * @access public
     *
     * @return string Widget title.
     */
    public function get_title() {
        return __( 'Meter', 'bdevs-elementor' );
    }

    /**
     * Get widget icon.
     *
     * Retrieve Bdevs About widget icon.
     *
     * @since 1.0.0
     * @access public
     *
     * @return string Widget icon.
     */
    public function get_icon() {
        return 'eicon-menu-bar';
    }

    /**
     * Get widget categories.
     *
     * Retrieve the list of categories the Bdevs About widget belongs to.
     *
     * @since 1.0.0
     * @access public
     *
     * @return array Widget categories.
     */
    public function get_categories() {
        return [ 'bdevs-elementor' ];
    }

    public function get_keywords() {
        return [ 'meter' ];
    }

    public function get_script_depends() {
        return [ 'bdevs-elementor'];
    }

    // BDT Position
    protected function element_pack_position() {
        $position_options = [
            ''              => esc_html__('Default', 'bdevs-elementor'),
            'top-left'      => esc_html__('Top Left', 'bdevs-elementor') ,
            'top-center'    => esc_html__('Top Center', 'bdevs-elementor') ,
            'top-right'     => esc_html__('Top Right', 'bdevs-elementor') ,
            'center'        => esc_html__('Center', 'bdevs-elementor') ,
            'center-left'   => esc_html__('Center Left', 'bdevs-elementor') ,
            'center-right'  => esc_html__('Center Right', 'bdevs-elementor') ,
            'bottom-left'   => esc_html__('Bottom Left', 'bdevs-elementor') ,
            'bottom-center' => esc_html__('Bottom Center', 'bdevs-elementor') ,
            'bottom-right'  => esc_html__('Bottom Right', 'bdevs-elementor') ,
        ];

        return $position_options;
    }

    protected function _register_controls() {
        
        $this->start_controls_section(
            'section_content_heading',
            [
                'label' => esc_html__( 'Meter', 'bdevs-elementor' ),
            ]   
        );
        $this->add_control(
            'background_image',
            [
                'label'   => esc_html__( 'Background Image:', 'bdevs-elementor' ),
                'type'    => Controls_Manager::MEDIA,
                'dynamic' => [ 'active' => true ],
                'description' => esc_html__( 'Add image from here', 'bdevs-elementor' ),
            ]
        );
        $this->add_control(
            'meter_image',
            [
                'label'   => esc_html__( 'Meter Image:', 'bdevs-elementor' ),
                'type'    => Controls_Manager::MEDIA,
                'dynamic' => [ 'active' => true ],
                'description' => esc_html__( 'Add image from here', 'bdevs-elementor' ),
            ]
        );
        $this->add_control(
            'subheading',
            [
                'label'       => __( 'Subheading:', 'bdevs-elementor' ),
                'type'        => Controls_Manager::TEXT,
                'placeholder' => __( 'Enter your subheading', 'bdevs-elementor' ),
                'default'     => __( 'People affected by poverty', 'bdevs-elementor' ),
                'label_block' => true,
            ]
        ); 
        $this->add_control(
            'tabs',
            [
                'label' => esc_html__( 'Heading:', 'bdevs-elementor' ),
                'type' => Controls_Manager::REPEATER,
                'fields' => [
                    [
                        'name'        => 'heading_style',
                        'label'     => esc_html__( 'Heading Style', 'bdevs-elementor' ),
                        'type'      => Controls_Manager::SELECT,
                        'dynamic' => [ 'active' => true ],
                        'options'   => [
                            '1'  => esc_html__( 'Normal', 'bdevs-elementor' ),
                            '2'  => esc_html__( 'Color', 'bdevs-elementor' ),
                        ],
                        'default'   => '1',
                    ],
                    
                    [
                        'name'        => 'text',
                        'label'       => esc_html__( 'Text:', 'bdevs-elementor' ),
                        'type'        => Controls_Manager::TEXTAREA,
                        'dynamic'     => [ 'active' => true ],
                        'default'     => esc_html__( 'We commit to supporting' , 'bdevs-elementor' ),
                        'label_block' => true,
                    ],                   
                ],
            ]
        );
        $this->add_control(
            'description',
            [
                'label'       => __( 'Description:', 'bdevs-elementor' ),
                'type'        => Controls_Manager::TEXTAREA,
                'placeholder' => __( 'Enter your description', 'bdevs-elementor' ),
                'default'     => __( 'For people affected by poverty or disaster, health is essential to a better future.' ),
                'label_block' => true,
            ]
        ); 
        $this->add_control(
            'number',
            [
                'label'       => __( 'Number:', 'bdevs-elementor' ),
                'type'        => Controls_Manager::TEXT,
                'placeholder' => __( 'Enter number', 'bdevs-elementor' ),
                'default'     => __( '200' ),
                'label_block' => true,
            ]
        );
        $this->add_control(
            'format',
            [
                'label'       => __( 'Number Format:', 'bdevs-elementor' ),
                'type'        => Controls_Manager::TEXT,
                'placeholder' => __( 'Enter format', 'bdevs-elementor' ),
                'default'     => __( 'K' ),
                'label_block' => true,
            ]
        );
        $this->add_control(
            'currency',
            [
                'label'       => __( 'Currency:', 'bdevs-elementor' ),
                'type'        => Controls_Manager::TEXT,
                'placeholder' => __( 'Enter currency', 'bdevs-elementor' ),
                'default'     => __( '(USD)' ),
                'label_block' => true,
            ]
        );
        $this->add_control(
            'text_under_number',
            [
                'label'       => __( 'Text Under Number:', 'bdevs-elementor' ),
                'type'        => Controls_Manager::TEXT,
                'placeholder' => __( 'Enter text', 'bdevs-elementor' ),
                'default'     => __( 'Homeless People Donations in Britain' ),
                'label_block' => true,
            ]
        );
        $this->add_control(
            'button',
            [
                'label'       => __( 'Button:', 'bdevs-elementor' ),
                'type'        => Controls_Manager::TEXT,
                'placeholder' => __( 'Enter button', 'bdevs-elementor' ),
                'default'     => __( 'Donate Now' ),
                'label_block' => true,
            ]
        );
        $this->end_controls_section();

        /** 
        *   Layout section 
        **/
        $this->start_controls_section(
            'section_content_layout',
            [
                'label' => esc_html__( 'Layout', 'bdevs-elementor' ),
            ]
        );

        $this->add_responsive_control(
            'align',
            [
                'label'   => esc_html__( 'Alignment', 'bdevs-elementor' ),
                'type'    => Controls_Manager::CHOOSE,
                'options' => [
                    'left' => [
                        'title' => esc_html__( 'Left', 'bdevs-elementor' ),
                        'icon'  => 'fa fa-align-left',
                    ],
                    'center' => [
                        'title' => esc_html__( 'Center', 'bdevs-elementor' ),
                        'icon'  => 'fa fa-align-center',
                    ],
                    'right' => [
                        'title' => esc_html__( 'Right', 'bdevs-elementor' ),
                        'icon'  => 'fa fa-align-right',
                    ],
                    'justify' => [
                        'title' => esc_html__( 'Justified', 'bdevs-elementor' ),
                        'icon'  => 'fa fa-align-justify',
                    ],
                ],
                'prefix_class' => 'elementor%s-align-',
                'description'  => 'Use align to match position',
                'default'      => 'left',
            ]
        );
        $this->end_controls_section();

    }
    public function render() {
    $settings  = $this->get_settings_for_display();
    extract($settings); 
    ?> 
    <!-- Meter Area start -->
    <?php if(isset($settings['background_image']['url']) && $settings['background_image']['url'] != ''){?>
    <section class="meter-area py-120 rel z-1" style="background-image: url(<?php echo wp_kses_post($settings['background_image']['url']);?>);">
    <?php } else { ?>
    <section class="meter-area py-120 rel z-1">
    <?php } ?>
        <div class="container">
            <div class="row align-items-center">
                <?php if(isset($settings['meter_image']['url']) && $settings['meter_image']['url'] != ''){?>
                <div class="col-lg-4">
                    <div class="meter-image rmb-55 text-center wow fadeInRight delay-0-2s">
                        <img src="<?php echo wp_kses_post($settings['meter_image']['url']);?>" alt="Donate">
                    </div>
                </div>
                <?php } ?>
                <div class="col-lg-8">
                    <div class="meter-content wow fadeInLeft delay-0-2s">
                        <div class="section-title mb-25">
                            <?php if(isset($settings['subheading']) && $settings['subheading'] != ''){?>
                            <span class="sub-title mb-5"><?php print wp_kses_post($settings['subheading']); ?></span>
                            <?php } ?>
                            <h3>
                                <?php foreach ( $settings['tabs'] as $item ) :  ?>
                                <?php if( wp_kses_post($item['heading_style']) == '1'): ?>
                                <?php print wp_kses_post($item['text']); ?>
                                <?php elseif( wp_kses_post($item['heading_style']) == '2'): ?>
                                <span><?php print wp_kses_post($item['text']); ?></span>  
                                <?php endif; ?> 
                                <?php endforeach; ?> 
                            </h3>
                        </div>
                        <?php if(isset($settings['description']) && $settings['description'] != ''){?>
                        <p><?php print wp_kses_post($settings['description']); ?></p>
                        <?php } ?>
                        <div class="people-number-btn">
                            <div class="text mt-20">
                                <?php if(isset($settings['number']) && $settings['number'] != ''){?>
                                <span class="h2"> <?php print wp_kses_post($settings['number']); ?><?php if(isset($settings['format']) && $settings['format'] != ''){?><small><?php print wp_kses_post($settings['format']); ?></small> <?php } ?><?php if(isset($settings['currency']) && $settings['currency'] != ''){?><span><?php print wp_kses_post($settings['currency']); ?></span><?php } ?>
                                </span>
                                <?php } ?>
                                <?php if(isset($settings['text_under_number']) && $settings['text_under_number'] != ''){?>
                                <i><?php print wp_kses_post($settings['text_under_number']); ?></i>
                                <?php } ?>
                            </div>
                            <a href="#" class="theme-btn br-10 mt-20" data-bs-toggle="modal" data-bs-target="#donateModal">
                                <span class="btn-text normal"><i class="fas fa-heart"></i> <?php print wp_kses_post($settings['button']); ?></span>
                                <span class="btn-text hover"><i class="fas fa-heart"></i> <?php print wp_kses_post($settings['button']); ?></span>
                            </a>
                        </div>
                    </div>
                </div>
            </div>
        </div>
    </section>
    <!-- Meter Area end -->
    <?php
    }

}

