<?php
namespace BdevsElementor\Widget;

use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;
use Elementor\Scheme_Typography;
use Elementor\Group_Control_Border;
use Elementor\Group_Control_Box_Shadow;

/**
 * Bdevs Elementor Widget.
 *
 * Elementor widget that inserts an embbedable content into the page, from any given URL.
 *
 * @since 1.0.0
 */
class BdevsRecentCauses extends \Elementor\Widget_Base {

    /**
     * Get widget name.
     *
     * Retrieve Bdevs Elementor widget name.
     *
     * @since 1.0.0
     * @access public
     *
     * @return string Widget name.
     */
    public function get_name() {
        return 'bdevs-recent-causes';
    }

    /**
     * Get widget title.
     *
     * Retrieve Bdevs Elementor widget title.
     *
     * @since 1.0.0
     * @access public
     *
     * @return string Widget title.
     */
    public function get_title() {
        return __( 'Recent Causes', 'bdevs-elementor' );
    }

    /**
     * Get widget icon.
     *
     * Retrieve Bdevs About widget icon.
     *
     * @since 1.0.0
     * @access public
     *
     * @return string Widget icon.
     */
    public function get_icon() {
        return 'eicon-info-box';
    }

    /**
     * Get widget categories.
     *
     * Retrieve the list of categories the Bdevs About widget belongs to.
     *
     * @since 1.0.0
     * @access public
     *
     * @return array Widget categories.
     */
    public function get_categories() {
        return [ 'bdevs-elementor' ];
    }

    public function get_keywords() {
        return [ 'recent causes' ];
    }

    public function get_script_depends() {
        return [ 'bdevs-elementor'];
    }

    // BDT Position
    protected function element_pack_position() {
        $position_options = [
            ''              => esc_html__('Default', 'bdevs-elementor'),
            'top-left'      => esc_html__('Top Left', 'bdevs-elementor') ,
            'top-center'    => esc_html__('Top Center', 'bdevs-elementor') ,
            'top-right'     => esc_html__('Top Right', 'bdevs-elementor') ,
            'center'        => esc_html__('Center', 'bdevs-elementor') ,
            'center-left'   => esc_html__('Center Left', 'bdevs-elementor') ,
            'center-right'  => esc_html__('Center Right', 'bdevs-elementor') ,
            'bottom-left'   => esc_html__('Bottom Left', 'bdevs-elementor') ,
            'bottom-center' => esc_html__('Bottom Center', 'bdevs-elementor') ,
            'bottom-right'  => esc_html__('Bottom Right', 'bdevs-elementor') ,
        ];

        return $position_options;
    }

    protected function _register_controls() {
        $this->start_controls_section(
            'section_content_heading',
            [
                'label' => esc_html__( 'Recent Causes', 'bdevs-elementor' ),
            ]   
        );
        $this->add_control(
            'choose_style',
            [
                'label'     => esc_html__( 'Choose Style', 'bdevs-elementor' ),
                'type'      => Controls_Manager::SELECT,
                'options'   => [
                    'style_1'  => esc_html__( 'Style 1', 'bdevs-elementor' ),
                    'style_2'  => esc_html__( 'Style 2', 'bdevs-elementor' ),
                    'style_3'  => esc_html__( 'Style 3', 'bdevs-elementor' ),
                    'style_4'  => esc_html__( 'Style 4', 'bdevs-elementor' ),
                ],
                'default'   => 'style_1',
            ]
        ); 
        $this->add_control(
            'background_image',
            [
                'label'   => esc_html__( 'Background Image:', 'bdevs-elementor' ),
                'type'    => Controls_Manager::MEDIA,
                'dynamic' => [ 'active' => true ],
                'description' => esc_html__( 'Add image from here', 'bdevs-elementor' ),
                'condition' => [
                    'choose_style' => 'style_3',
                ]
            ]
        ); 
        $this->add_control(
            'heading',
            [
                'label'       => __( 'Heading:', 'bdevs-elementor' ),
                'type'        => Controls_Manager::TEXT,
                'placeholder' => __( 'Enter your heading', 'bdevs-elementor' ),
                'default'     => __( 'Our Recent Causes', 'bdevs-elementor' ),
                'label_block' => true,
                'condition' => [
                    'choose_style' => ['style_1','style_2']
                ]
            ]
        );
        $this->add_control(
            'tabs',
            [
                'label' => esc_html__( 'Heading:', 'bdevs-elementor' ),
                'type' => Controls_Manager::REPEATER,
                'fields' => [
                    [
                        'name'        => 'heading_style',
                        'label'     => esc_html__( 'Heading Style:', 'bdevs-elementor' ),
                        'type'      => Controls_Manager::SELECT,
                        'dynamic' => [ 'active' => true ],
                        'options'   => [
                            '1'  => esc_html__( 'Normal', 'bdevs-elementor' ),
                            '2'  => esc_html__( 'Special', 'bdevs-elementor' ),
                        ],
                        'default'   => '1',
                    ],
                    [
                        'name'        => 'text',
                        'label'       => esc_html__( 'Text:', 'bdevs-elementor' ),
                        'type'        => Controls_Manager::TEXTAREA,
                        'dynamic'     => [ 'active' => true ],
                        'default'     => esc_html__( 'Our Recent ' , 'bdevs-elementor' ),
                        'label_block' => true,
                    ],                   
                ],
                'condition' => [
                    'choose_style' => ['style_3','style_4']
                ]
            ]
        ); 
        $this->add_control(
            'description',
            [
                'label'       => __( 'Description:', 'bdevs-elementor' ),
                'type'        => Controls_Manager::TEXTAREA,
                'placeholder' => __( 'Enter your description', 'bdevs-elementor' ),
                'default'     => __( 'adipisicing elit Rem autem voluptatem obcaecati', 'bdevs-elementor' ),
                'label_block' => true,
            ]
        );
        $this->add_control(
            'drop_image',
            [
                'label'   => esc_html__( 'Drop Image:', 'bdevs-elementor' ),
                'type'    => Controls_Manager::MEDIA,
                'dynamic' => [ 'active' => true ],
                'description' => esc_html__( 'Add image from here', 'bdevs-elementor' ),
                'condition' => [
                    'choose_style' => ['style_1','style_2']
                ]
            ]
        );         
        $this->add_control(
            'post_number',
            [
                'label'       => __( 'Posts Per Page:', 'bdevs-elementor' ),
                'type'        => Controls_Manager::TEXT,
                'placeholder' => __( 'Enter your posts per page', 'bdevs-elementor' ),
                'default'     => __( '3', 'bdevs-elementor' ),
                'label_block' => true,
            ]
        );
        $this->add_control(
            'sortby',
            [
                'label'     => esc_html__( 'Sort', 'bdevs-elementor' ),
                'type'      => Controls_Manager::SELECT,
                'options'   => [
                    'sortby_style_1'  => esc_html__( 'Newest', 'bdevs-elementor' ),
                    'sortby_style_2'  => esc_html__( 'Oldest', 'bdevs-elementor' ),
                ],
                'default'   => 'sortby_style_1',
            ]
        );
        $this->add_control(
            'before_button',
            [
                'label'       => __( 'Before Button:', 'bdevs-elementor' ),
                'type'        => Controls_Manager::TEXT,
                'placeholder' => __( 'Enter your text', 'bdevs-elementor' ),
                'default'     => __( 'Want to see our Recent Causes.', 'bdevs-elementor' ),
                'label_block' => true,
            ]
        );
        $this->add_control(
            'link_button',
            [
                'label'       => __( 'Link Button:', 'bdevs-elementor' ),
                'type'        => Controls_Manager::TEXT,
                'placeholder' => __( 'Enter link button', 'bdevs-elementor' ),
                'default'     => __( '#' ),
                'label_block' => true,
            ]
        );
        $this->add_control(
            'button',
            [
                'label'       => __( 'Button:', 'bdevs-elementor' ),
                'type'        => Controls_Manager::TEXT,
                'placeholder' => __( 'Enter button', 'bdevs-elementor' ),
                'default'     => __( 'Click here to View More' ),
                'label_block' => true,
            ]
        );
        $this->end_controls_section();
        /** 
        *   Layout section 
        **/
        $this->start_controls_section(
            'section_content_layout',
            [
                'label' => esc_html__( 'Layout', 'bdevs-elementor' ),
            ]
        );
        $this->add_responsive_control(
            'align',
            [
                'label'   => esc_html__( 'Alignment', 'bdevs-elementor' ),
                'type'    => Controls_Manager::CHOOSE,
                'options' => [
                    'left' => [
                        'title' => esc_html__( 'Left', 'bdevs-elementor' ),
                        'icon'  => 'fa fa-align-left',
                    ],
                    'center' => [
                        'title' => esc_html__( 'Center', 'bdevs-elementor' ),
                        'icon'  => 'fa fa-align-center',
                    ],
                    'right' => [
                        'title' => esc_html__( 'Right', 'bdevs-elementor' ),
                        'icon'  => 'fa fa-align-right',
                    ],
                    'justify' => [
                        'title' => esc_html__( 'Justified', 'bdevs-elementor' ),
                        'icon'  => 'fa fa-align-justify',
                    ],
                ],
                'prefix_class' => 'elementor%s-align-',
                'description'  => 'Use align to match position',
                'default'      => 'left',
            ]
        );
        $this->add_control(
            'show_heading',
            [
                'label'   => esc_html__( 'Show Heading', 'bdevs-elementor' ),
                'type'    => Controls_Manager::SWITCHER,
                'default' => 'yes',
            ]
        );
        $this->end_controls_section();

    }

    public function render() {
    $settings  = $this->get_settings_for_display();
    extract($settings); 
    if ($settings['sortby']=='sortby_style_1') {
        $sortby = 'DESC';
    }
    if ($settings['sortby']=='sortby_style_2') {
        $sortby = 'ASC';
    }
    ?>
    <?php $style = $settings['choose_style'];?>
    <?php if( $style == 'style_1' ): ?>   
    <!-- Causes Area start -->
    <section class="causes-area py-115 rel z-1">
        <div class="container">
            <?php if ( $settings['show_heading'] ) : ?>
            <div class="section-title text-center mb-15 wow fadeInUp delay-0-2s">
                <?php if(isset($settings['heading']) && $settings['heading'] != ''){?>
                <h2><?php print wp_kses_post($settings['heading']); ?></h2>
                <?php } ?>
                <?php if(isset($settings['description']) && $settings['description'] != ''){?>
                <p><?php print wp_kses_post($settings['description']); ?></p>
                <?php } ?>
               <span class="line"></span>
               <?php if(isset($settings['drop_image']['url']) && $settings['drop_image']['url'] != ''){?>
               <img class="drops" src="<?php echo wp_kses_post($settings['drop_image']['url']);?>" alt="Drops">
               <?php } ?>
            </div>
            <?php endif; ?>
            <div class="row justify-content-center">
                <?php $post_number = $settings['post_number'];
                $wp_query = new \WP_Query(array('posts_per_page' => $post_number,'post_type' => 'cause',  'orderby' => 'ID', 'order' => $sortby));     
                $args = new \WP_Query(array(   
                    'post_type' => 'cause', 
                ));  
                while ($wp_query -> have_posts()) : $wp_query -> the_post(); ?>
                <?php $c_featured_image_2 = get_post_meta(get_the_ID(),'_cmb_c_featured_image_2', true); ?>
                <?php $donation_raised_number = get_post_meta(get_the_ID(),'_cmb_donation_raised_number', true); ?>
                <?php $donation_raised_text = get_post_meta(get_the_ID(),'_cmb_donation_raised_text', true); ?>
                <?php $before_donation_goal = get_post_meta(get_the_ID(),'_cmb_before_donation_goal', true); ?>
                <?php $donation_goal = get_post_meta(get_the_ID(),'_cmb_donation_goal', true); ?>
                <?php $location = get_post_meta(get_the_ID(),'_cmb_location', true); ?>
                <div class="col-xl-4 col-md-6">
                    <div class="cause-item wow fadeInUp delay-0-2s">
                        <div class="image">
                            <?php if(isset($c_featured_image_2) && $c_featured_image_2 != '') { ?>
                            <a href="<?php the_permalink();?>"><img src="<?php echo wp_get_attachment_url($c_featured_image_2);?>" alt="causes"></a>
                            <?php } ?>
                            <div class="donation-raised">
                                <span class="price"><?php echo esc_attr($donation_raised_number); ?></span>
                                <span class="text"><?php echo esc_attr($donation_raised_text); ?></span>
                            </div>
                        </div>
                        <div class="content">
                           <span class="goal-price"><i class="fas fa-heart"></i> <?php echo esc_attr($before_donation_goal); ?> <?php echo esc_attr($donation_goal); ?></span>
                            <h5><a href="<?php the_permalink();?>"><?php the_title(); ?></a></h5>
                            <span class="location"><i class="fas fa-map-marker"></i> <?php echo esc_attr($location); ?></span>
                        </div>
                    </div>
                </div>
                <?php endwhile; ?> 
                </div>
            </div>
            <?php if(isset($settings['link_button']) && $settings['link_button'] != ''){?>
            <div class="more-btn-with-text text-center mt-25 wow fadeInUp delay-0-2s">
                <i><?php print wp_kses_post($settings['before_button']); ?> <a href="<?php print wp_kses_post($settings['link_button']); ?>"><?php print wp_kses_post($settings['button']); ?></a></i>
            </div>
            <?php } ?>
        </div>
    </section>
    <!-- Causes Area end -->
    <?php elseif( $style == 'style_2' ): ?>
    <!-- Causes Area start -->
    <section class="causes-two-area py-110">
        <div class="container">
            <?php if ( $settings['show_heading'] ) : ?>
            <div class="section-title text-center mb-15">
                <?php if(isset($settings['heading']) && $settings['heading'] != ''){?>
                <h2><?php print wp_kses_post($settings['heading']); ?></h2>
                <?php } ?>
                <?php if(isset($settings['description']) && $settings['description'] != ''){?>
                <p><?php print wp_kses_post($settings['description']); ?></p>
                <?php } ?>
                <span class="line"></span>
                <?php if(isset($settings['drop_image']['url']) && $settings['drop_image']['url'] != ''){?>
                <img class="drops" src="<?php echo wp_kses_post($settings['drop_image']['url']);?>" alt="Drops">
                <?php } ?>
            </div>
            <?php endif; ?>
            <div class="row justify-content-center">
                <?php $post_number = $settings['post_number'];
                $wp_query = new \WP_Query(array('posts_per_page' => $post_number,'post_type' => 'cause',  'orderby' => 'ID', 'order' => $sortby));     
                $args = new \WP_Query(array(   
                    'post_type' => 'cause', 
                ));  
                while ($wp_query -> have_posts()) : $wp_query -> the_post(); ?>
                <?php $c_featured_image_4 = get_post_meta(get_the_ID(),'_cmb_c_featured_image_4', true); ?>
                <?php $donation_raised_number = get_post_meta(get_the_ID(),'_cmb_donation_raised_number', true); ?>
                <?php $after_donation_raised = get_post_meta(get_the_ID(),'_cmb_after_donation_raised', true); ?>
                <?php $before_donation_goal_2 = get_post_meta(get_the_ID(),'_cmb_before_donation_goal_2', true); ?>
                <?php $donation_goal = get_post_meta(get_the_ID(),'_cmb_donation_goal', true); ?>
                <?php $raised_percent = get_post_meta(get_the_ID(),'_cmb_raised_percent', true); ?>
                <?php $location = get_post_meta(get_the_ID(),'_cmb_location', true); ?> 
                <div class="col-xl-4 col-md-6">
                    <div class="cause-item-two wow fadeInUp delay-0-2s">
                        <?php if(isset($c_featured_image_4) && $c_featured_image_4 != '') { ?>
                        <div class="image">
                            <a href="<?php the_permalink();?>"><img src="<?php echo wp_get_attachment_url($c_featured_image_4);?>" alt="causes"></a>
                        </div>
                        <?php } ?>
                        <div class="content">
                            <?php
                            $cats = get_the_terms(get_the_ID(),'category1');
                            foreach($cats as $cat) { ?>
                            <a class="category" href="<?php echo get_category_link( $cat->term_id ) ?>"><?php echo esc_attr($cat->name);?></a>
                            <?php } ?>
                            <span class="price"><span><?php echo esc_attr($donation_raised_number); ?> <?php echo esc_attr($after_donation_raised); ?></span> <?php echo esc_attr($before_donation_goal_2); ?> <?php echo esc_attr($donation_goal); ?></span>
                            <h5><a href="<?php the_permalink();?>"><?php the_title(); ?></a></h5>
                            <div class="progress">
                              <div class="progress-bar" style="width: <?php echo esc_attr($raised_percent); ?>%"><span><?php echo esc_attr($raised_percent); ?>%</span></div>
                            </div>
                        </div>
                        <ul class="cause-footer">
                            <li><i class="fal fa-calendar-minus"></i> <?php the_time(get_option( 'date_format' ));?></li>
                            <li><i class="fal fa-user"></i> <?php echo gt_get_post_view(); ?></li>
                        </ul>
                    </div>
                </div>
                <?php endwhile; ?> 
            </div>
            <?php if(isset($settings['link_button']) && $settings['link_button'] != ''){?>
            <div class="more-btn-with-text text-center mt-30 wow fadeInUp delay-0-2s">
                <i><?php print wp_kses_post($settings['before_button']); ?> <a href="<?php print wp_kses_post($settings['link_button']); ?>"><?php print wp_kses_post($settings['button']); ?></a></i>
            </div>
            <?php } ?>
        </div>
    </section>
    <!-- Causes Area end -->
    <?php elseif( $style == 'style_3' ): ?>
    <!-- Causes Area Three start -->
    <?php if(isset($settings['background_image']['url']) && $settings['background_image']['url'] != ''){?>
    <section class="causes-area-three py-115 rpt-85 bgs-cover rel z-1" style="background-image: url(<?php echo wp_kses_post($settings['background_image']['url']);?>)">
    <?php } else { ?>
    <section class="causes-area-three py-115 rpt-85 bgs-cover rel z-1">
    <?php } ?>
        <div class="container">
            <?php if ( $settings['show_heading'] ) : ?>
            <div class="section-title text-center text-white mb-15 wow fadeInUp delay-0-2s">
                <h2><?php foreach ( $settings['tabs'] as $item ) :  ?>
                    <?php if( wp_kses_post($item['heading_style']) == '1'): ?>
                    <?php print wp_kses_post($item['text']); ?>
                    <?php elseif( wp_kses_post($item['heading_style']) == '2'): ?>
                    <span><?php print wp_kses_post($item['text']); ?></span>  
                    <?php endif; ?> 
                    <?php endforeach; ?></h2>
                <?php if(isset($settings['description']) && $settings['description'] != ''){?>
                <p><?php print wp_kses_post($settings['description']); ?></p>
                <?php } ?>
                <span class="line"></span>
            </div>
            <?php endif; ?>
            <div class="row justify-content-center">
                <div class="col-xl-10">
                    <?php $post_number = $settings['post_number'];
                    $wp_query = new \WP_Query(array('posts_per_page' => $post_number,'post_type' => 'cause',  'orderby' => 'ID', 'order' => $sortby));     
                    $args = new \WP_Query(array(   
                        'post_type' => 'cause', 
                    ));  
                    $i=0;
                    while ($wp_query -> have_posts()) : $wp_query -> the_post(); ?>
                    <?php $i++; ?>
                    <?php $c_featured_image_6 = get_post_meta(get_the_ID(),'_cmb_c_featured_image_6', true); ?>
                    <?php $donation_raised_number = get_post_meta(get_the_ID(),'_cmb_donation_raised_number', true); ?>
                    <?php $donation_raised_text = get_post_meta(get_the_ID(),'_cmb_donation_raised_text', true); ?>
                    <?php $donation_goal = get_post_meta(get_the_ID(),'_cmb_donation_goal', true); ?>
                    <?php $donation_goal_text = get_post_meta(get_the_ID(),'_cmb_donation_goal_text', true); ?>
                    <?php $raised_percent = get_post_meta(get_the_ID(),'_cmb_raised_percent', true); ?>
                    <?php $location = get_post_meta(get_the_ID(),'_cmb_location', true); ?> 
                    <?php if($i%2==1) { ?>
                    <div class="cause-item-three content-left wow fadeInUp delay-0-3s">
                        <div class="content">
                            <ul class="blog-meta">
                                <li><i class="fas fa-calendar-alt"></i> <?php the_time(get_option( 'date_format' ));?></li>
                            </ul>
                            <h5><a href="<?php the_permalink();?>"><?php the_title(); ?></a></h5>
                            <p><?php echo esc_attr(charitxa_excerpt_3(20));?></p>
                            <div class="goal-donation">
                                <div class="left">
                                    <span class="donate-price"><?php echo esc_attr($donation_goal); ?></span>
                                    <span class="donate-price-text"><?php echo esc_attr($donation_goal_text); ?></span>
                                </div>
                                <a href="#" class="theme-btn br-10" data-bs-toggle="modal" data-bs-target="#donateModal">
                                    <span class="btn-text normal"><i class="fas fa-heart"></i> <?php if(isset($charitxa_redux_demo['donate_now'])){?>
                                        <?php echo wp_specialchars_decode(esc_attr($charitxa_redux_demo['donate_now']));?>
                                        <?php }else{?>
                                        <?php echo esc_html__( 'Donate Now', 'charitxa' ); }  ?></span>
                                    <span class="btn-text hover"><i class="fas fa-heart"></i> <?php if(isset($charitxa_redux_demo['donate_now'])){?>
                                        <?php echo wp_specialchars_decode(esc_attr($charitxa_redux_demo['donate_now']));?>
                                        <?php }else{?>
                                        <?php echo esc_html__( 'Donate Now', 'charitxa' ); }  ?></span>
                                </a>
                            </div>
                        </div>
                        <div class="image">
                            <?php if(isset($c_featured_image_6) && $c_featured_image_6 != '') { ?>
                            <a href="<?php the_permalink();?>"><img src="<?php echo wp_get_attachment_url($c_featured_image_6);?>" alt="causes"></a>
                            <?php } ?>
                            <div class="rised-donation">
                                <span class="donate-price"><?php echo esc_attr($donation_raised_number); ?></span>
                                <span class="donate-price-text"><?php echo esc_attr($donation_raised_text); ?></span>
                            </div>
                            <?php
                            $cats = get_the_terms(get_the_ID(),'category1');
                            foreach($cats as $cat) { ?>
                            <span class="category"><?php echo esc_attr($cat->name);?></span>
                            <?php } ?>
                        </div>
                    </div>
                    <?php } elseif($i%2==0) { ?>
                    <div class="cause-item-three wow fadeInUp delay-0-3s">
                        <div class="image">
                            <?php if(isset($c_featured_image_6) && $c_featured_image_6 != '') { ?>
                            <a href="<?php the_permalink();?>"><img src="<?php echo wp_get_attachment_url($c_featured_image_6);?>" alt="causes"></a>
                            <?php } ?>
                            <div class="rised-donation">
                                <span class="donate-price"><?php echo esc_attr($donation_raised_number); ?></span>
                                <span class="donate-price-text"><?php echo esc_attr($donation_raised_text); ?></span>
                            </div>
                            <?php
                            $cats = get_the_terms(get_the_ID(),'category1');
                            foreach($cats as $cat) { ?>
                            <span class="category"><?php echo esc_attr($cat->name);?></span>
                            <?php } ?>
                        </div>
                        <div class="content">
                            <ul class="blog-meta">
                                <li><i class="fas fa-calendar-alt"></i> <?php the_time(get_option( 'date_format' ));?></li>
                            </ul>
                            <h5><a href="<?php the_permalink();?>"><?php the_title(); ?></a></h5>
                            <p><?php echo esc_attr(charitxa_excerpt_3(20));?></p>
                            <div class="goal-donation">
                                <div class="left">
                                    <span class="donate-price"><?php echo esc_attr($donation_goal); ?></span>
                                    <span class="donate-price-text"><?php echo esc_attr($donation_goal_text); ?></span>
                                </div>
                                <a href="#" class="theme-btn br-10" data-bs-toggle="modal" data-bs-target="#donateModal">
                                    <span class="btn-text normal"><i class="fas fa-heart"></i> <?php if(isset($charitxa_redux_demo['donate_now'])){?>
                                        <?php echo wp_specialchars_decode(esc_attr($charitxa_redux_demo['donate_now']));?>
                                        <?php }else{?>
                                        <?php echo esc_html__( 'Donate Now', 'charitxa' ); }  ?></span>
                                    <span class="btn-text hover"><i class="fas fa-heart"></i> <?php if(isset($charitxa_redux_demo['donate_now'])){?>
                                        <?php echo wp_specialchars_decode(esc_attr($charitxa_redux_demo['donate_now']));?>
                                        <?php }else{?>
                                        <?php echo esc_html__( 'Donate Now', 'charitxa' ); }  ?></span>
                                </a>
                            </div>
                        </div>
                    </div>
                    <?php } ?>
                    <?php endwhile; ?> 
                </div>
            </div>
            <?php if(isset($settings['link_button']) && $settings['link_button'] != ''){?>
            <div class="more-btn-with-text text-white text-center pt-30 wow fadeInUp delay-0-2s">
                <i><?php print wp_kses_post($settings['before_button']); ?><a href="<?php print wp_kses_post($settings['link_button']); ?>"><?php print wp_kses_post($settings['button']); ?></a></i>
            </div>
            <?php } ?>
        </div>
    </section>
    <!-- Causes Area Three end -->
    <?php elseif( $style == 'style_4' ): ?>
    <!-- Causes Area start -->
    <section class="causes-four-area pt-110 pb-105">
        <div class="container">
            <?php if ( $settings['show_heading'] ) : ?>
            <div class="section-title text-center mb-15 wow fadeInUp delay-0-2s">
                <h2><?php foreach ( $settings['tabs'] as $item ) :  ?>
                    <?php if( wp_kses_post($item['heading_style']) == '1'): ?>
                    <?php print wp_kses_post($item['text']); ?>
                    <?php elseif( wp_kses_post($item['heading_style']) == '2'): ?>
                    <span><?php print wp_kses_post($item['text']); ?></span>  
                    <?php endif; ?> 
                    <?php endforeach; ?></h2>
                <?php if(isset($settings['description']) && $settings['description'] != ''){?>
                <p><?php print wp_kses_post($settings['description']); ?></p>
                <?php } ?>
                <span class="line"></span>
            </div>
            <?php endif; ?>
            <div class="row justify-content-center">
                <?php $post_number = $settings['post_number'];
                $wp_query = new \WP_Query(array('posts_per_page' => $post_number,'post_type' => 'cause',  'orderby' => 'ID', 'order' => $sortby));     
                $args = new \WP_Query(array(   
                    'post_type' => 'cause', 
                ));  
                $i=2;
                while ($wp_query -> have_posts()) : $wp_query -> the_post(); 
                $c_featured_image_5 = get_post_meta(get_the_ID(),'_cmb_c_featured_image_5', true);
                    ?>
                <?php $donation_raised_number = get_post_meta(get_the_ID(),'_cmb_donation_raised_number', true); ?>
                <?php $donation_raised_text = get_post_meta(get_the_ID(),'_cmb_donation_raised_text', true); ?>
                <?php $raised_percent = get_post_meta(get_the_ID(),'_cmb_raised_percent', true); ?>
                <?php $location = get_post_meta(get_the_ID(),'_cmb_location', true); ?> 
                <div class="col-xl-4 col-md-6">
                    <div class="cause-item-four wow fadeInUp delay-0-<?php echo $i; ?>s">
                        <?php if(isset($c_featured_image_5) && $c_featured_image_5 != '') { ?>
                        <div class="image">    
                            <a href="<?php the_permalink();?>"><img src="<?php echo wp_get_attachment_url($c_featured_image_5);?>" alt="causes"></a>
                        </div>
                        <?php } ?>
                        <div class="content">
                            <?php
                            $cats = get_the_terms(get_the_ID(),'category1');
                            foreach($cats as $cat) { ?>
                            <span class="category"><?php echo esc_attr($cat->name);?></span>
                            <?php } ?>
                            <h5><a href="<?php the_permalink();?>"><?php the_title(); ?></a></h5>
                            <span class="price"><span><?php echo esc_attr($donation_raised_number); ?> </span> <i><?php echo esc_attr($donation_raised_text); ?></i></span>
                            <div class="progress">
                              <div class="progress-bar" style="width: <?php echo esc_attr($raised_percent); ?>%"></div>
                            </div>
                            <ul class="cause-footer">
                                <li><i class="fal fa-calendar-alt"></i> <?php the_time(get_option( 'date_format' ));?></li>
                                <li><i class="far fa-map-marker-alt"></i> <?php echo esc_attr($location); ?></li>
                            </ul>
                        </div>
                    </div>
                </div>
                <?php $i=$i+2; ?>
                <?php endwhile; ?>
            </div>
            <?php if(isset($settings['link_button']) && $settings['link_button'] != ''){?>
            <div class="more-btn-with-text text-center mt-30 wow fadeInUp delay-0-2s">
                <i><?php print wp_kses_post($settings['before_button']); ?><a href="<?php print wp_kses_post($settings['link_button']); ?>"><?php print wp_kses_post($settings['button']); ?></a></i>
            </div>
            <?php } ?>
        </div>
    </section>
    <!-- Causes Area end -->
    <?php endif; ?>
    <?php
    }
}


