<?php
namespace BdevsElementor\Widget;

use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;
use Elementor\Scheme_Typography;
use Elementor\Group_Control_Border;
use Elementor\Group_Control_Box_Shadow;

/**
 * Bdevs Elementor Widget.
 *
 * Elementor widget that inserts an embbedable content into the page, from any given URL.
 *
 * @since 1.0.0
 */
class BdevsServices extends \Elementor\Widget_Base {

    /**
     * Get widget name.
     *
     * Retrieve Bdevs Elementor widget name.
     *
     * @since 1.0.0
     * @access public
     *
     * @return string Widget name.
     */
    public function get_name() {
        return 'bdevs-services';
    }

    /**
     * Get widget title.
     *
     * Retrieve Bdevs Elementor widget title.
     *
     * @since 1.0.0
     * @access public
     *
     * @return string Widget title.
     */
    public function get_title() {
        return __( 'Services', 'bdevs-elementor' );
    }

    /**
     * Get widget icon.
     *
     * Retrieve Bdevs About widget icon.
     *
     * @since 1.0.0
     * @access public
     *
     * @return string Widget icon.
     */
    public function get_icon() {
        return 'eicon-posts-justified';
    }

    /**
     * Get widget categories.
     *
     * Retrieve the list of categories the Bdevs About widget belongs to.
     *
     * @since 1.0.0
     * @access public
     *
     * @return array Widget categories.
     */
    public function get_categories() {
        return [ 'bdevs-elementor' ];
    }

    public function get_keywords() {
        return [ 'services' ];
    }

    public function get_script_depends() {
        return [ 'bdevs-elementor'];
    }

    // BDT Position
    protected function element_pack_position() {
        $position_options = [
            ''              => esc_html__('Default', 'bdevs-elementor'),
            'top-left'      => esc_html__('Top Left', 'bdevs-elementor') ,
            'top-center'    => esc_html__('Top Center', 'bdevs-elementor') ,
            'top-right'     => esc_html__('Top Right', 'bdevs-elementor') ,
            'center'        => esc_html__('Center', 'bdevs-elementor') ,
            'center-left'   => esc_html__('Center Left', 'bdevs-elementor') ,
            'center-right'  => esc_html__('Center Right', 'bdevs-elementor') ,
            'bottom-left'   => esc_html__('Bottom Left', 'bdevs-elementor') ,
            'bottom-center' => esc_html__('Bottom Center', 'bdevs-elementor') ,
            'bottom-right'  => esc_html__('Bottom Right', 'bdevs-elementor') ,
        ];

        return $position_options;
    }

    protected function _register_controls() {
        $this->start_controls_section(
            'section_content_heading',
            [
                'label' => esc_html__( 'Services', 'bdevs-elementor' ),
            ]   
        );
        $this->add_control(
            'subheading',
            [
                'label'       => __( 'Subheading:', 'bdevs-elementor' ),
                'type'        => Controls_Manager::TEXT,
                'placeholder' => __( 'Enter your subheading', 'bdevs-elementor' ),
                'default'     => __( 'Our Focus Areas.', 'bdevs-elementor' ),
                'label_block' => true,
            ]
        );
        $this->add_control(
            'background_subheading',
            [
                'label'   => esc_html__( 'Subheading Background Image:', 'bdevs-elementor' ),
                'type'    => Controls_Manager::MEDIA,
                'dynamic' => [ 'active' => true ],
                'description' => esc_html__( 'Add image from here', 'bdevs-elementor' ),
            ]
        ); 
        $this->add_control(
            'heading',
            [
                'label'       => __( 'Heading:', 'bdevs-elementor' ),
                'type'        => Controls_Manager::TEXT,
                'placeholder' => __( 'Enter your heading', 'bdevs-elementor' ),
                'default'     => __( 'What’s At Stake?', 'bdevs-elementor' ),
                'label_block' => true,
            ]
        ); 
        $this->add_control(
            'description',
            [
                'label'       => __( 'Description:', 'bdevs-elementor' ),
                'type'        => Controls_Manager::TEXTAREA,
                'placeholder' => __( 'Enter your description', 'bdevs-elementor' ),
                'default'     => __( 'The Feeding America network is the nation’s largest domestic hunger-relief organization, working to connect people with food and end hunger.' ),
                'label_block' => true,
            ]
        ); 
        $this->add_control(
            'post_number',
            [
                'label'       => __( 'Posts Per Page:', 'bdevs-elementor' ),
                'type'        => Controls_Manager::TEXT,
                'placeholder' => __( 'Enter your posts per page', 'bdevs-elementor' ),
                'default'     => __( '5', 'bdevs-elementor' ),
                'label_block' => true,
            ]
        );
        $this->add_control(
            'sortby',
            [
                'label'     => esc_html__( 'Sort', 'bdevs-elementor' ),
                'type'      => Controls_Manager::SELECT,
                'options'   => [
                    'sortby_style_1'  => esc_html__( 'Newest', 'bdevs-elementor' ),
                    'sortby_style_2'  => esc_html__( 'Oldest', 'bdevs-elementor' ),
                ],
                'default'   => 'sortby_style_1',
            ]
        );
        $this->add_control(
            'before_button',
            [
                'label'       => __( 'Before Button:', 'bdevs-elementor' ),
                'type'        => Controls_Manager::TEXT,
                'placeholder' => __( 'Enter your text', 'bdevs-elementor' ),
                'default'     => __( 'Want to see our focus areas.', 'bdevs-elementor' ),
                'label_block' => true,
            ]
        );
        $this->add_control(
            'link_button',
            [
                'label'       => __( 'Link Button:', 'bdevs-elementor' ),
                'type'        => Controls_Manager::TEXT,
                'placeholder' => __( 'Enter link button', 'bdevs-elementor' ),
                'default'     => __( '#' ),
                'label_block' => true,
            ]
        );
        $this->add_control(
            'button',
            [
                'label'       => __( 'Button:', 'bdevs-elementor' ),
                'type'        => Controls_Manager::TEXT,
                'placeholder' => __( 'Enter button', 'bdevs-elementor' ),
                'default'     => __( 'Click here to View More' ),
                'label_block' => true,
            ]
        );
        $this->end_controls_section();
        /** 
        *   Layout section 
        **/
        $this->start_controls_section(
            'section_content_layout',
            [
                'label' => esc_html__( 'Layout', 'bdevs-elementor' ),
            ]
        );
        $this->add_responsive_control(
            'align',
            [
                'label'   => esc_html__( 'Alignment', 'bdevs-elementor' ),
                'type'    => Controls_Manager::CHOOSE,
                'options' => [
                    'left' => [
                        'title' => esc_html__( 'Left', 'bdevs-elementor' ),
                        'icon'  => 'fa fa-align-left',
                    ],
                    'center' => [
                        'title' => esc_html__( 'Center', 'bdevs-elementor' ),
                        'icon'  => 'fa fa-align-center',
                    ],
                    'right' => [
                        'title' => esc_html__( 'Right', 'bdevs-elementor' ),
                        'icon'  => 'fa fa-align-right',
                    ],
                    'justify' => [
                        'title' => esc_html__( 'Justified', 'bdevs-elementor' ),
                        'icon'  => 'fa fa-align-justify',
                    ],
                ],
                'prefix_class' => 'elementor%s-align-',
                'description'  => 'Use align to match position',
                'default'      => 'left',
            ]
        ); 
        $this->end_controls_section();

    }

    public function render() {
    $settings  = $this->get_settings_for_display();
    extract($settings); 
    if ($settings['sortby']=='sortby_style_1') {
        $sortby = 'DESC';
    }
    if ($settings['sortby']=='sortby_style_2') {
        $sortby = 'ASC';
    }
    ?>
    <!-- Focused Area start -->
    <section class="focused-area py-115">
        <div class="container">
            <div class="row">
                <div class="col-lg-8">
                    <div class="focused-content mb-50 rmb-30 wow fadeInUp delay-0-2s">
                        <div class="section-title mb-15">
                           <?php if(isset($settings['subheading']) && $settings['subheading'] != ''){?>
                            <span class="sub-title style-two" style="background-image: url(<?php echo wp_kses_post($settings['background_subheading']['url']);?>);"><?php print wp_kses_post($settings['subheading']); ?></span>
                            <?php } ?>
                            <?php if(isset($settings['heading']) && $settings['heading'] != ''){?>
                            <h2><?php print wp_kses_post($settings['heading']); ?></h2>
                            <?php } ?>
                        </div>
                        <?php if(isset($settings['description']) && $settings['description'] != ''){?>
                        <p><?php print wp_kses_post($settings['description']); ?></p>
                        <?php } ?>
                    </div>
                    <?php $post_number = $settings['post_number'];
                    $wp_query = new \WP_Query(array('posts_per_page' => $post_number,'post_type' => 'service',  'orderby' => 'ID', 'order' => $sortby));     
                    $args = new \WP_Query(array(   
                        'post_type' => 'service', 
                    ));  
                    $i=0;
                    while ($wp_query -> have_posts()) : $wp_query -> the_post(); 
                    $i++;
                    $s_featured_image_2 = get_post_meta(get_the_ID(),'_cmb_s_featured_image_2', true);
                    $sv_icon_0 = get_post_meta(get_the_ID(),'_cmb_sv_icon_0', true);
                    ?> 
                    <?php if($i%5==1) { ?>
                    <div class="focused-item left-right wow fadeInUp delay-0-2s">
                        <?php if(isset($s_featured_image_2) && $s_featured_image_2 != '') { ?>
                        <div class="image">
                            <a href="<?php the_permalink();?>"><img src="<?php echo wp_get_attachment_url($s_featured_image_2);?>" alt="Focused"></a>
                        </div>
                        <?php } ?>
                        <div class="content bgc-blue text-white">
                            <?php if(isset($sv_icon_0) && $sv_icon_0 != '') { ?>
                            <div class="icon">
                                <img src="<?php echo wp_get_attachment_url($sv_icon_0);?>" alt="Icon">
                            </div>
                            <?php } ?>
                            <h5><a href="<?php the_permalink();?>"><?php the_title(); ?></a></h5>
                            <p><?php echo esc_attr(charitxa_excerpt_5(10));?></p>
                            <a class="read-more" href="<?php the_permalink(); ?>"><?php if(isset($charitxa_redux_demo['read_more'])){?>
                                <?php echo wp_specialchars_decode(esc_attr($charitxa_redux_demo['read_more']));?>
                                <?php } else { ?>
                                <?php echo esc_html__( 'Read More', 'charitxa' ); } ?><i class="far fa-chevron-double-right"></i></a>
                        </div>
                    </div>
                    <?php } elseif(($i%5==2) || ($i%5==3)) { ?>
                    <?php if($i%5==2) { ?>
                    <div class="row">
                        <div class="col-md-6">
                            <div class="focused-item wow fadeInUp delay-0-2s">
                                <?php if(isset($s_featured_image_2) && $s_featured_image_2 != '') { ?>
                                <div class="image">
                                    <a href="<?php the_permalink();?>"><img src="<?php echo wp_get_attachment_url($s_featured_image_2);?>" alt="Focused"></a>
                                </div>
                                <?php } ?>
                                <div class="content bgc-light-blue text-white">
                                    <?php if(isset($sv_icon_0) && $sv_icon_0 != '') { ?>
                                    <div class="icon">
                                        <img src="<?php echo wp_get_attachment_url($sv_icon_0);?>" alt="Icon">
                                    </div>
                                    <?php } ?>
                                    <h5><a href="<?php the_permalink();?>"><?php the_title(); ?></a></h5>
                                    <p><?php echo esc_attr(charitxa_excerpt_5(10));?></p>
                                    <a class="read-more" href="<?php the_permalink(); ?>"><?php if(isset($charitxa_redux_demo['read_more'])){?>
                                    <?php echo wp_specialchars_decode(esc_attr($charitxa_redux_demo['read_more']));?>
                                    <?php } else { ?>
                                    <?php echo esc_html__( 'Read More', 'charitxa' ); } ?><i class="far fa-chevron-double-right"></i></a>
                                </div>
                            </div>
                        </div>
                    <?php } elseif($i%5==3) { ?>
                        <div class="col-md-6">
                            <div class="focused-item wow fadeInUp delay-0-2s">
                                <?php if(isset($s_featured_image_2) && $s_featured_image_2 != '') { ?>
                                <div class="image">
                                    <a href="<?php the_permalink();?>"><img src="<?php echo wp_get_attachment_url($s_featured_image_2);?>" alt="Focused"></a>
                                </div>
                                <?php } ?>
                                <div class="content bgc-yellow">
                                    <?php if(isset($sv_icon_0) && $sv_icon_0 != '') { ?>
                                    <div class="icon">
                                        <img src="<?php echo wp_get_attachment_url($sv_icon_0);?>" alt="Icon">
                                    </div>
                                    <?php } ?>
                                    <h5><a href="<?php the_permalink();?>"><?php the_title(); ?></a></h5>
                                    <p><?php echo esc_attr(charitxa_excerpt_5(10));?></p>
                                    <a class="read-more" href="<?php the_permalink(); ?>"><?php if(isset($charitxa_redux_demo['read_more'])){?>
                                    <?php echo wp_specialchars_decode(esc_attr($charitxa_redux_demo['read_more']));?>
                                    <?php } else { ?>
                                    <?php echo esc_html__( 'Read More', 'charitxa' ); } ?><i class="far fa-chevron-double-right"></i></a>
                                </div>
                            </div>
                        </div>
                    </div>
                    <?php } ?>
                    <?php } ?>
                    <?php endwhile; ?>
                    </div>
                <div class="col-lg-4">
                    <div class="row">
                        <?php $post_number = $settings['post_number'];
                        $wp_query = new \WP_Query(array('posts_per_page' => $post_number,'post_type' => 'service',  'orderby' => 'ID', 'order' => $sortby));     
                        $args = new \WP_Query(array(   
                            'post_type' => 'service', 
                        )); 
                        $i=0;
                        while ($wp_query -> have_posts()) : $wp_query -> the_post(); 
                        $i++;
                        $s_featured_image_2 = get_post_meta(get_the_ID(),'_cmb_s_featured_image_2', true);
                        $sv_icon_0 = get_post_meta(get_the_ID(),'_cmb_sv_icon_0', true);
                        ?> 
                        <?php if(($i%5==4) || ($i%5==0) ){ ?>
                        <?php if($i%5==4) { ?>
                        <div class="col-lg-12 col-md-6">
                            <div class="focused-item wow fadeInUp delay-0-2s">
                                <?php if(isset($s_featured_image_2) && $s_featured_image_2 != '') { ?>
                                <div class="image">
                                    <a href="<?php the_permalink();?>"><img src="<?php echo wp_get_attachment_url($s_featured_image_2);?>" alt="Focused"></a>
                                </div>
                                <?php } ?>
                                <div class="content bgc-red text-white">
                                    <?php if(isset($sv_icon_0) && $sv_icon_0 != '') { ?>
                                    <div class="icon">
                                        <img src="<?php echo wp_get_attachment_url($sv_icon_0);?>" alt="Icon">
                                    </div>
                                    <?php } ?>
                                    <h5><a href="<?php the_permalink();?>"><?php the_title(); ?></a></h5>
                                    <p><?php echo esc_attr(charitxa_excerpt_5(10));?></p>
                                    <a class="read-more" href="<?php the_permalink(); ?>"><?php if(isset($charitxa_redux_demo['read_more'])){?>
                                    <?php echo wp_specialchars_decode(esc_attr($charitxa_redux_demo['read_more']));?>
                                    <?php } else { ?>
                                    <?php echo esc_html__( 'Read More', 'charitxa' ); } ?><i class="far fa-chevron-double-right"></i></a>
                                </div>
                            </div>
                        </div>
                        <?php } elseif($i%5==0) { ?>
                        <div class="col-lg-12 col-md-6">
                            <div class="focused-item wow fadeInUp delay-0-2s">
                                <?php if(isset($s_featured_image_2) && $s_featured_image_2 != '') { ?>
                                <div class="image">
                                    <a href="<?php the_permalink();?>"><img src="<?php echo wp_get_attachment_url($s_featured_image_2);?>" alt="Focused"></a>
                                </div>
                                <?php } ?>
                                <div class="content bgc-light-purple text-white">
                                    <?php if(isset($sv_icon_0) && $sv_icon_0 != '') { ?>
                                    <div class="icon">
                                        <img src="<?php echo wp_get_attachment_url($sv_icon_0);?>" alt="Icon">
                                    </div>
                                    <?php } ?>
                                    <h5><a href="<?php the_permalink();?>"><?php the_title(); ?></a></h5>
                                    <p><?php echo esc_attr(charitxa_excerpt_5(10));?></p>
                                    <a class="read-more" href="<?php the_permalink(); ?>"><?php if(isset($charitxa_redux_demo['read_more'])){?>
                                    <?php echo wp_specialchars_decode(esc_attr($charitxa_redux_demo['read_more']));?>
                                    <?php } else { ?>
                                    <?php echo esc_html__( 'Read More', 'charitxa' ); } ?><i class="far fa-chevron-double-right"></i></a>
                                </div>
                            </div>
                        </div>
                        <?php } ?>
                        <?php } ?>
                        <?php endwhile; ?> 
                    </div>
                </div>
            </div>
            <?php if(isset($settings['link_button']) && $settings['link_button'] != ''){?>
            <div class="more-btn-with-text text-center mt-30 wow fadeInUp delay-0-2s">
                <i><?php print wp_kses_post($settings['before_button']); ?> <a href="<?php print wp_kses_post($settings['link_button']); ?>"><?php print wp_kses_post($settings['button']); ?></a></i>
            </div>
            <?php } ?>
        </div>
    </section>
    <!-- Focused Area end -->
    <?php
    }
}


