<?php
namespace BdevsElementor\Widget;

use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;
use Elementor\Scheme_Typography;
use Elementor\Group_Control_Border;
use Elementor\Group_Control_Box_Shadow;

/**
 * Bdevs Elementor Widget.
 *
 * Elementor widget that inserts an embbedable content into the page, from any given URL.
 *
 * @since 1.0.0
 */
class BdevsStories extends \Elementor\Widget_Base {

    /**
     * Get widget name.
     *
     * Retrieve Bdevs Elementor widget name.
     *
     * @since 1.0.0
     * @access public
     *
     * @return string Widget name.
     */
    public function get_name() {
        return 'bdevs-stories';
    }

    /**
     * Get widget title.
     *
     * Retrieve Bdevs Elementor widget title.
     *
     * @since 1.0.0
     * @access public
     *
     * @return string Widget title.
     */
    public function get_title() {
        return __( 'Stories', 'bdevs-elementor' );
    }

    /**
     * Get widget icon.
     *
     * Retrieve Bdevs About widget icon.
     *
     * @since 1.0.0
     * @access public
     *
     * @return string Widget icon.
     */
    public function get_icon() {
        return 'eicon-kit-details';
    }

    /**
     * Get widget categories.
     *
     * Retrieve the list of categories the Bdevs About widget belongs to.
     *
     * @since 1.0.0
     * @access public
     *
     * @return array Widget categories.
     */
    public function get_categories() {
        return [ 'bdevs-elementor' ];
    }

    public function get_keywords() {
        return [ 'stories' ];
    }

    public function get_script_depends() {
        return [ 'bdevs-elementor'];
    }

    // BDT Position
    protected function element_pack_position() {
        $position_options = [
            ''              => esc_html__('Default', 'bdevs-elementor'),
            'top-left'      => esc_html__('Top Left', 'bdevs-elementor') ,
            'top-center'    => esc_html__('Top Center', 'bdevs-elementor') ,
            'top-right'     => esc_html__('Top Right', 'bdevs-elementor') ,
            'center'        => esc_html__('Center', 'bdevs-elementor') ,
            'center-left'   => esc_html__('Center Left', 'bdevs-elementor') ,
            'center-right'  => esc_html__('Center Right', 'bdevs-elementor') ,
            'bottom-left'   => esc_html__('Bottom Left', 'bdevs-elementor') ,
            'bottom-center' => esc_html__('Bottom Center', 'bdevs-elementor') ,
            'bottom-right'  => esc_html__('Bottom Right', 'bdevs-elementor') ,
        ];

        return $position_options;
    }

    protected function _register_controls() {
        $this->start_controls_section(
            'section_content_heading',
            [
                'label' => esc_html__( 'Stories', 'bdevs-elementor' ),
            ]   
        ); 
        $this->add_control(
            'choose_style',
            [
                'label'     => esc_html__( 'Choose Style', 'bdevs-elementor' ),
                'type'      => Controls_Manager::SELECT,
                'options'   => [
                    'style_1'  => esc_html__( 'Style 1', 'bdevs-elementor' ),
                    'style_2'  => esc_html__( 'Style 2', 'bdevs-elementor' ),
                ],
                'default'   => 'style_1',
            ]
        );
        $this->add_control(
            'background_image',
            [
                'label'   => esc_html__( 'Background Image:', 'bdevs-elementor' ),
                'type'    => Controls_Manager::MEDIA,
                'dynamic' => [ 'active' => true ],
                'description' => esc_html__( 'Add image from here', 'bdevs-elementor' ),
            ]
        );
        $this->add_control(
            'heading',
            [
                'label'       => __( 'Heading:', 'bdevs-elementor' ),
                'type'        => Controls_Manager::TEXT,
                'placeholder' => __( 'Enter your heading', 'bdevs-elementor' ),
                'default'     => __( 'Charitxa Stories', 'bdevs-elementor' ),
                'label_block' => true,
            ]
        ); 
        $this->add_control(
            'description',
            [
                'label'       => __( 'Description:', 'bdevs-elementor' ),
                'type'        => Controls_Manager::TEXTAREA,
                'placeholder' => __( 'Enter your description', 'bdevs-elementor' ),
                'default'     => __( 'adipisicing elit Rem autem voluptatem obcaecati', 'bdevs-elementor' ),
                'label_block' => true,
            ]
        );
        $this->add_control(
            'link_button',
            [
                'label'       => __( 'Link Button:', 'bdevs-elementor' ),
                'type'        => Controls_Manager::TEXT,
                'placeholder' => __( 'Enter link button', 'bdevs-elementor' ),
                'default'     => __( '#' ),
                'label_block' => true,
            ]
        );
        $this->add_control(
            'button',
            [
                'label'       => __( 'Button:', 'bdevs-elementor' ),
                'type'        => Controls_Manager::TEXT,
                'placeholder' => __( 'Enter button', 'bdevs-elementor' ),
                'default'     => __( 'More Stories' ),
                'label_block' => true,
            ]
        );
        $this->add_control(
            'post_number',
            [
                'label'       => __( 'Posts Per Page:', 'bdevs-elementor' ),
                'type'        => Controls_Manager::TEXT,
                'placeholder' => __( 'Enter your posts per page', 'bdevs-elementor' ),
                'default'     => __( '2', 'bdevs-elementor' ),
                'label_block' => true,
            ]
        );
        $this->add_control(
            'sortby',
            [
                'label'     => esc_html__( 'Sort', 'bdevs-elementor' ),
                'type'      => Controls_Manager::SELECT,
                'options'   => [
                    'sortby_style_1'  => esc_html__( 'Newest', 'bdevs-elementor' ),
                    'sortby_style_2'  => esc_html__( 'Oldest', 'bdevs-elementor' ),
                ],
                'default'   => 'sortby_style_1',
            ]
        );
        $this->end_controls_section();

        $this->start_controls_section(
            'section_content_campaign',
            [
                'label' => esc_html__( 'Campaign Content', 'bdevs-elementor' ),
                'condition' => [
                    'choose_style' => ['style_1'],
                ]
            ]   
        ); 
        $this->add_control(
            'subtitle',
            [
                'label'       => __( 'Subtitle:', 'bdevs-elementor' ),
                'type'        => Controls_Manager::TEXT,
                'placeholder' => __( 'Enter your subtitle', 'bdevs-elementor' ),
                'default'     => __( 'We are Near to Our', 'bdevs-elementor' ),
                'label_block' => true,
                'condition' => [
                    'choose_style' => ['style_1'],
                ]
            ]
        ); 
        $this->add_control(
            'title',
            [
                'label'       => __( 'title:', 'bdevs-elementor' ),
                'type'        => Controls_Manager::TEXT,
                'placeholder' => __( 'Enter your title', 'bdevs-elementor' ),
                'default'     => __( 'Campaign', 'bdevs-elementor' ),
                'label_block' => true,
                'condition' => [
                    'choose_style' => ['style_1'],
                ]
            ]
        ); 
        $this->add_control(
            'description',
            [
                'label'       => __( 'Description:', 'bdevs-elementor' ),
                'type'        => Controls_Manager::TEXTAREA,
                'placeholder' => __( 'Enter your description', 'bdevs-elementor' ),
                'default'     => __( 'Foundation awarded $86,667,390 in funding to 1,306 grants.', 'bdevs-elementor' ),
                'label_block' => true,
                'condition' => [
                    'choose_style' => ['style_1'],
                ]
            ]
        );
        $this->add_control(
            'tabs',
            [
                'label' => esc_html__( 'Campaign Money', 'bdevs-elementor' ),
                'type' => Controls_Manager::REPEATER,
                'fields' => [
                    [
                        'name'        => 'title',
                        'label'       => esc_html__( 'Title:', 'bdevs-elementor' ),
                        'type'        => Controls_Manager::TEXT,
                        'dynamic'     => [ 'active' => true ],
                        'default'     => esc_html__( 'Goal' , 'bdevs-elementor' ),
                        'label_block' => true,
                    ],
                    [
                        'name'        => 'number',
                        'label'       => esc_html__( 'Number:', 'bdevs-elementor' ),
                        'type'        => Controls_Manager::TEXT,
                        'dynamic'     => [ 'active' => true ],
                        'default'     => esc_html__( '$39,860' , 'bdevs-elementor' ),
                        'label_block' => true,
                    ],
                ],
                'condition' => [
                    'choose_style' => ['style_1'],
                ]
            ]
        );
        $this->add_control(
            'percent_raised',
            [
                'label'       => __( 'Percent Raised:', 'bdevs-elementor' ),
                'type'        => Controls_Manager::TEXT,
                'placeholder' => __( 'Enter your percent number', 'bdevs-elementor' ),
                'default'     => __( '74', 'bdevs-elementor' ),
                'label_block' => true,
                'condition' => [
                    'choose_style' => ['style_1'],
                ]
            ]
        );
         $this->add_control(
            'cta_button',
            [
                'label'       => __( 'Button:', 'bdevs-elementor' ),
                'type'        => Controls_Manager::TEXT,
                'placeholder' => __( 'Enter button', 'bdevs-elementor' ),
                'default'     => __( 'Take Action' ),
                'label_block' => true,
                'condition' => [
                    'choose_style' => ['style_1'],
                ]
            ]
        );
        $this->end_controls_section();
        /** 
        *   Layout section 
        **/
        $this->start_controls_section(
            'section_content_layout',
            [
                'label' => esc_html__( 'Layout', 'bdevs-elementor' ),
            ]
        );
        $this->add_responsive_control(
            'align',
            [
                'label'   => esc_html__( 'Alignment', 'bdevs-elementor' ),
                'type'    => Controls_Manager::CHOOSE,
                'options' => [
                    'left' => [
                        'title' => esc_html__( 'Left', 'bdevs-elementor' ),
                        'icon'  => 'fa fa-align-left',
                    ],
                    'center' => [
                        'title' => esc_html__( 'Center', 'bdevs-elementor' ),
                        'icon'  => 'fa fa-align-center',
                    ],
                    'right' => [
                        'title' => esc_html__( 'Right', 'bdevs-elementor' ),
                        'icon'  => 'fa fa-align-right',
                    ],
                    'justify' => [
                        'title' => esc_html__( 'Justified', 'bdevs-elementor' ),
                        'icon'  => 'fa fa-align-justify',
                    ],
                ],
                'prefix_class' => 'elementor%s-align-',
                'description'  => 'Use align to match position',
                'default'      => 'left',
            ]
        );
        $this->end_controls_section();

    }

    public function render() {
    $settings  = $this->get_settings_for_display();
    extract($settings); 
    if ($settings['sortby']=='sortby_style_1') {
        $sortby = 'DESC';
    }
    if ($settings['sortby']=='sortby_style_2') {
        $sortby = 'ASC';
    }
    ?>
    <?php $style = $settings['choose_style'];?>
    <?php if( $style == 'style_1' ): ?> 
    <!-- Stories Area start -->
    <?php if(isset($settings['background_image']['url']) && $settings['background_image']['url'] != ''){?>
    <section class="stories-area pt-140 pb-25 rpb-110 rel z-1" style="background-image: url(<?php echo wp_kses_post($settings['background_image']['url']);?>);">
    <?php } else { ?>
    <section class="stories-area pt-140 pb-25 rpb-110 rel z-1">
    <?php } ?>
        <div class="container">
            <div class="row justify-content-end">
                <div class="col-xl-4 col-md-6">
                    <div class="stories-left-content wow fadeInUp delay-0-2s">
                        <div class="section-title text-white mb-30">
                            <?php if(isset($settings['heading']) && $settings['heading'] != ''){?>
                            <h2><?php print wp_kses_post($settings['heading']); ?></h2>
                            <?php } ?>
                            <?php if(isset($settings['description']) && $settings['description'] != ''){?>
                            <p><?php print wp_kses_post($settings['description']); ?></p>
                            <?php } ?>
                        </div>
                        <?php if(isset($settings['link_button']) && $settings['link_button'] != ''){?>
                        <a href="<?php print wp_kses_post($settings['link_button']); ?>" class="theme-btn style-two br-5">
                            <span class="btn-text normal"><?php print wp_kses_post($settings['button']); ?></span>
                            <span class="btn-text hover"><?php print wp_kses_post($settings['button']); ?></span>
                        </a>
                        <?php } ?>
                        <div class="campaign-content mt-60 bgc-yellow">
                            <div class="section-title">
                                <?php if(isset($settings['subtitle']) && $settings['subtitle'] != ''){?>
                                <span class="sub-title"><i><b><?php print wp_kses_post($settings['subtitle']); ?></b></i></span>
                                <?php } ?>
                                <?php if(isset($settings['title']) && $settings['title'] != ''){?>
                                <h3><?php print wp_kses_post($settings['title']); ?></h3>
                                <?php } ?>
                                <?php if(isset($settings['description']) && $settings['description'] != ''){?>
                                <p><?php print wp_kses_post($settings['description']); ?></p>
                                <?php } ?>
                            </div>
                            <div class="cause-price">
                                <?php foreach ( $settings['tabs'] as $item ) :  ?>
                                <span><?php print wp_kses_post($item['title']); ?> <b><?php print wp_kses_post($item['number']); ?></b></span>
                                <?php endforeach; ?>                                   
                            </div>
                            <?php if(isset($settings['percent_raised']) && $settings['percent_raised'] != ''){?>
                            <div class="progress">
                              <div class="progress-bar" style="width: <?php print wp_kses_post($settings['percent_raised']); ?>%"></div>
                              <span><?php print wp_kses_post($settings['percent_raised']); ?>%</span>
                            </div>
                            <?php } ?>
                        </div>
                        <?php if(isset($settings['cta_button']) && $settings['cta_button'] != ''){?>
                        <a href="#" class="theme-btn style-three w-100 d-flex" data-bs-toggle="modal" data-bs-target="#donateModal">
                            <span class="btn-text normal"><i class="fas fa-heart"></i> <?php print wp_kses_post($settings['cta_button']); ?></span>
                            <span class="btn-text hover"><i class="fas fa-heart"></i> <?php print wp_kses_post($settings['cta_button']); ?></span>
                        </a>
                        <?php } ?>
                    </div>
                </div>
                <?php $post_number = $settings['post_number'];
                $wp_query = new \WP_Query(array('posts_per_page' => $post_number,'post_type' => 'story',  'orderby' => 'ID', 'order' => $sortby));     
                $args = new \WP_Query(array(   
                    'post_type' => 'story', 
                ));  
                while ($wp_query -> have_posts()) : $wp_query -> the_post(); 
                $st_featured_image_2 = get_post_meta(get_the_ID(),'_cmb_st_featured_image_2', true);
                ?>
                <div class="col-xl-4 col-md-6">
                    <div class="story-item wow fadeInUp delay-0-4s">
                        <?php if(isset($st_featured_image_2) && $st_featured_image_2 != '') { ?>
                        <div class="image">
                            <a href="<?php the_permalink(); ?>"><img src="<?php echo wp_get_attachment_url($st_featured_image_2);?>" alt="story"></a>
                        </div>
                        <?php } ?>
                        <div class="content">
                            <?php
                            $cats = get_the_terms(get_the_ID(),'category5');
                            foreach($cats as $cat) { ?>
                            <span class="badge"><?php echo esc_attr($cat->name);?></span>
                            <?php } ?>
                            <ul class="blog-meta">
                                <li><i class="fas fa-calendar-alt"></i> <?php the_time(get_option( 'date_format' ));?></li>
                            </ul>
                            <h5><a href="<?php the_permalink(); ?>"><?php the_title(); ?></a></h5>
                            <ul class="bottom-list">
                                <li><?php echo gt_get_post_view(); ?></li>
                                <li><?php the_author_posts_link(); ?></li>
                            </ul>
                            <a class="details-btn" href="<?php the_permalink(); ?>"><i class="fas fa-arrow-right"></i></a>
                        </div>
                    </div>
                </div>
                <?php endwhile; ?> 
            </div>
        </div>
    </section>
    <!-- Stories Area end -->
    <?php elseif( $style == 'style_2' ): ?>
     <!-- Stories Area start -->
    <?php if(isset($settings['background_image']['url']) && $settings['background_image']['url'] != ''){?>
    <section class="stories-area-two bgs-cover pt-125 pb-100 rel z-1" style="background-image: url(<?php echo wp_kses_post($settings['background_image']['url']);?>);">
    <?php } else { ?>
    <section class="stories-area-two bgs-cover pt-125 pb-100 rel z-1">
    <?php } ?>
        <div class="container">
            <div class="row">
                <div class="col-xl-4 col-md-8">
                    <div class="stories-content-two mb-55 wow fadeInUp delay-0-2s">
                        <div class="section-title text-white mb-30">
                           <?php if(isset($settings['heading']) && $settings['heading'] != ''){?>
                            <h2><?php print wp_kses_post($settings['heading']); ?></h2>
                            <?php } ?>
                            <?php if(isset($settings['description']) && $settings['description'] != ''){?>
                            <p><?php print wp_kses_post($settings['description']); ?></p>
                            <?php } ?>
                        </div>
                        <?php if(isset($settings['link_button']) && $settings['link_button'] != ''){?>
                        <a href="<?php print wp_kses_post($settings['link_button']); ?>" class="theme-btn style-two br-10">
                            <span class="btn-text normal"><?php print wp_kses_post($settings['button']); ?></span>
                            <span class="btn-text hover"><?php print wp_kses_post($settings['button']); ?></span>
                        </a>
                        <?php } ?>
                    </div>
                </div>
                <?php $post_number = $settings['post_number'];
                $wp_query = new \WP_Query(array('posts_per_page' => $post_number,'post_type' => 'story',  'orderby' => 'ID', 'order' => $sortby));     
                $args = new \WP_Query(array(   
                    'post_type' => 'story', 
                ));  
                while ($wp_query -> have_posts()) : $wp_query -> the_post(); 
                $st_featured_image_2 = get_post_meta(get_the_ID(),'_cmb_st_featured_image_2', true);
                ?>
                <div class="col-xl-4 col-md-6">
                    <div class="story-item wow fadeInUp delay-0-4s">
                        <?php if(isset($st_featured_image_2) && $st_featured_image_2 != '') { ?>
                        <div class="image">
                            <a href="<?php the_permalink(); ?>"><img src="<?php echo wp_get_attachment_url($st_featured_image_2);?>" alt="story"></a>
                        </div>
                        <?php } ?>
                        <div class="content">
                            <?php
                            $cats = get_the_terms(get_the_ID(),'category5');
                            foreach($cats as $cat) { ?>
                            <span class="badge"><?php echo esc_attr($cat->name);?></span>
                            <?php } ?>
                            <ul class="blog-meta">
                                <li><i class="fas fa-calendar-alt"></i> <?php the_time(get_option( 'date_format' ));?></li>
                            </ul>
                            <h5><a href="<?php the_permalink(); ?>"><?php the_title(); ?></a></h5>
                            <ul class="bottom-list">
                                <li><?php echo gt_get_post_view(); ?></li>
                                <li><?php the_author_posts_link(); ?></li>
                            </ul>
                            <a class="details-btn" href="<?php the_permalink(); ?>"><i class="fas fa-arrow-right"></i></a>
                        </div>
                    </div>
                </div>
                <?php endwhile; ?> 
            </div>
        </div>
    </section>
    <!-- Stories Area end -->
    <?php endif; ?>
    <?php
    }
}


