<?php
namespace BdevsElementor\Widget;

use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;
use Elementor\Scheme_Typography;
use Elementor\Group_Control_Border;
use Elementor\Group_Control_Box_Shadow;

/**
 * Bdevs Elementor Widget.
 *
 * Elementor widget that inserts an embbedable content into the page, from any given URL.
 *
 * @since 1.0.0
 */
class BdevsTestimonial2 extends \Elementor\Widget_Base {

    /**
     * Get widget name.
     *
     * Retrieve Bdevs Elementor widget name.
     *
     * @since 1.0.0
     * @access public
     *
     * @return string Widget name.
     */
    public function get_name() {
        return 'bdevs-testimonial-2';
    }

    /**
     * Get widget title.
     *
     * Retrieve Bdevs Elementor widget title.
     *
     * @since 1.0.0
     * @access public
     *
     * @return string Widget title.
     */
    public function get_title() {
        return __( 'Testimonial 2', 'bdevs-elementor' );
    }

    /**
     * Get widget icon.
     *
     * Retrieve Bdevs About widget icon.
     *
     * @since 1.0.0
     * @access public
     *
     * @return string Widget icon.
     */
    public function get_icon() {
        return 'eicon-blockquote';
    }

    /**
     * Get widget categories.
     *
     * Retrieve the list of categories the Bdevs About widget belongs to.
     *
     * @since 1.0.0
     * @access public
     *
     * @return array Widget categories.
     */
    public function get_categories() {
        return [ 'bdevs-elementor' ];
    }

    public function get_keywords() {
        return [ 'testimonial 2' ];
    }

    public function get_script_depends() {
        return [ 'bdevs-elementor'];
    }

    // BDT Position
    protected function element_pack_position() {
        $position_options = [
            ''              => esc_html__('Default', 'bdevs-elementor'),
            'top-left'      => esc_html__('Top Left', 'bdevs-elementor') ,
            'top-center'    => esc_html__('Top Center', 'bdevs-elementor') ,
            'top-right'     => esc_html__('Top Right', 'bdevs-elementor') ,
            'center'        => esc_html__('Center', 'bdevs-elementor') ,
            'center-left'   => esc_html__('Center Left', 'bdevs-elementor') ,
            'center-right'  => esc_html__('Center Right', 'bdevs-elementor') ,
            'bottom-left'   => esc_html__('Bottom Left', 'bdevs-elementor') ,
            'bottom-center' => esc_html__('Bottom Center', 'bdevs-elementor') ,
            'bottom-right'  => esc_html__('Bottom Right', 'bdevs-elementor') ,
        ];

        return $position_options;
    }

    protected function _register_controls() {
        
        $this->start_controls_section(
            'section_content_heading',
            [
                'label' => esc_html__( 'Testimonial 2', 'bdevs-elementor' ),
            ]   
        );
        $this->add_control(
            'background_image',
            [
                'label'   => esc_html__( 'Background Image:', 'bdevs-elementor' ),
                'type'    => Controls_Manager::MEDIA,
                'dynamic' => [ 'active' => true ],
                'description' => esc_html__( 'Add image from here', 'bdevs-elementor' ),
            ]
        );
        $this->add_control(
            'heading',
            [
                'label'       => __( 'Heading:', 'bdevs-elementor' ),
                'type'        => Controls_Manager::TEXT,
                'placeholder' => __( 'Enter your heading', 'bdevs-elementor' ),
                'default'     => __( 'Charitxa Reviews', 'bdevs-elementor' ),
                'label_block' => true,
            ]
        ); 
        $this->add_control(
            'description',
            [
                'label'       => __( 'Description:', 'bdevs-elementor' ),
                'type'        => Controls_Manager::TEXTAREA,
                'placeholder' => __( 'Enter your heading', 'bdevs-elementor' ),
                'default'     => __( 'adipisicing elit Rem autem voluptatem obcaecati', 'bdevs-elementor' ),
                'label_block' => true,
            ]
        ); 
        $this->add_control(
            'drop_image',
            [
                'label'   => esc_html__( 'Drop Image:', 'bdevs-elementor' ),
                'type'    => Controls_Manager::MEDIA,
                'dynamic' => [ 'active' => true ],
                'description' => esc_html__( 'Add image from here', 'bdevs-elementor' ),
            ]
        );  
        $this->add_control(
            'tabs',
            [
                'label' => esc_html__( 'Items', 'bdevs-elementor' ),
                'type' => Controls_Manager::REPEATER,
                'fields' => [
                    [
                        'name'    => 'author_image',
                        'label'   => esc_html__( 'Author Image', 'bdevs-elementor' ),
                        'type'    => Controls_Manager::MEDIA,
                        'default'     => esc_html__( '' , 'bdevs-elementor' ),
                        'dynamic' => [ 'active' => true ],
                    ],
                    [
                        'name'        => 'name',
                        'label'       => esc_html__( 'Name:', 'bdevs-elementor' ),
                        'type'        => Controls_Manager::TEXT,
                        'dynamic'     => [ 'active' => true ],
                        'default'     => esc_html__( '- SHALYNN P, CI SPONSOR ' , 'bdevs-elementor' ),
                        'label_block' => true,
                    ],
                    [
                        'name'        => 'time',
                        'label'       => esc_html__( 'Time:', 'bdevs-elementor' ),
                        'type'        => Controls_Manager::TEXT,
                        'dynamic'     => [ 'active' => true ],
                        'default'     => esc_html__( 'SINCE 2022' , 'bdevs-elementor' ),
                        'label_block' => true,
                    ],
                    [
                        'name'        => 'text',
                        'label'       => esc_html__( 'Text:', 'bdevs-elementor' ),
                        'type'        => Controls_Manager::TEXTAREA,
                        'dynamic'     => [ 'active' => true ],
                        'default'     => esc_html__( 'This is text' , 'bdevs-elementor' ),
                        'label_block' => true,
                    ],
                ],
            ]
        );
        $this->end_controls_section();
        $this->start_controls_section(
            'section_content_features',
            [
                'label' => esc_html__( 'Features', 'bdevs-elementor' ),
            ]   
        );
        $this->add_control(
            'tabs2',
            [
                'label' => esc_html__( 'Items', 'bdevs-elementor' ),
                'type' => Controls_Manager::REPEATER,
                'fields' => [
                    [
                        'name'        => 'choose_style',
                        'label'     => esc_html__( 'Choose Style:', 'bdevs-elementor' ),
                        'type'      => Controls_Manager::SELECT,
                        'dynamic' => [ 'active' => true ],
                        'options'   => [
                            'style_1'  => esc_html__( 'Text White', 'bdevs-elementor' ),
                            'style_2'  => esc_html__( 'Text Black', 'bdevs-elementor' ),
                        ],
                        'default'   => 'style_1',
                    ],
                    [
                        'name'    => 'feature_image',
                        'label'   => esc_html__( 'Image:', 'bdevs-elementor' ),
                        'type'    => Controls_Manager::MEDIA,
                        'default'     => esc_html__( '' , 'bdevs-elementor' ),
                        'dynamic' => [ 'active' => true ],
                    ],
                    [
                        'name'    => 'image_icon',
                        'label'   => esc_html__( 'Image Icon:', 'bdevs-elementor' ),
                        'type'    => Controls_Manager::MEDIA,
                        'default'     => esc_html__( '' , 'bdevs-elementor' ),
                        'dynamic' => [ 'active' => true ],
                    ],
                    [
                        'name'        => 'text',
                        'label'       => esc_html__( 'Text:', 'bdevs-elementor' ),
                        'type'        => Controls_Manager::TEXTAREA,
                        'dynamic'     => [ 'active' => true ],
                        'default'     => esc_html__( 'Lorem ipsum dolor sit amet, cons ili adipiscing  elitnec nec.' , 'bdevs-elementor' ),
                        'label_block' => true,
                    ],
                    [
                        'name'        => 'button_style',
                        'label'     => esc_html__( 'Button Style', 'bdevs-elementor' ),
                        'type'      => Controls_Manager::SELECT,
                        'dynamic' => [ 'active' => true ],
                        'options'   => [
                            '1'  => esc_html__( 'Link To', 'bdevs-elementor' ),
                            '2'  => esc_html__( 'Donate Form', 'bdevs-elementor' ),
                        ],
                        'default'   => '1',
                    ],
                    [
                        'name'        => 'link_button',
                        'label'       => esc_html__( 'Link Button:', 'bdevs-elementor' ),
                        'type'        => Controls_Manager::TEXT,
                        'dynamic'     => [ 'active' => true ],
                        'default'     => esc_html__( '#' , 'bdevs-elementor' ),
                        'label_block' => true,
                        'condition'   => [
                            'button_style' => '1',
                        ]
                    ],
                    [
                        'name'        => 'button',
                        'label'       => esc_html__( 'Button:', 'bdevs-elementor' ),
                        'type'        => Controls_Manager::TEXT,
                        'dynamic'     => [ 'active' => true ],
                        'default'     => esc_html__( 'Shop Now' , 'bdevs-elementor' ),
                        'label_block' => true,
                    ],
                ],
            ]
        );
        $this->end_controls_section();
        /** 
        *   Layout section 
        **/
        $this->start_controls_section(
            'section_content_layout',
            [
                'label' => esc_html__( 'Layout', 'bdevs-elementor' ),
            ]
        );

        $this->add_responsive_control(
            'align',
            [
                'label'   => esc_html__( 'Alignment', 'bdevs-elementor' ),
                'type'    => Controls_Manager::CHOOSE,
                'options' => [
                    'left' => [
                        'title' => esc_html__( 'Left', 'bdevs-elementor' ),
                        'icon'  => 'fa fa-align-left',
                    ],
                    'center' => [
                        'title' => esc_html__( 'Center', 'bdevs-elementor' ),
                        'icon'  => 'fa fa-align-center',
                    ],
                    'right' => [
                        'title' => esc_html__( 'Right', 'bdevs-elementor' ),
                        'icon'  => 'fa fa-align-right',
                    ],
                    'justify' => [
                        'title' => esc_html__( 'Justified', 'bdevs-elementor' ),
                        'icon'  => 'fa fa-align-justify',
                    ],
                ],
                'prefix_class' => 'elementor%s-align-',
                'description'  => 'Use align to match position',
                'default'      => 'left',
            ]
        );
        $this->end_controls_section();

    }
    public function render() {
    $settings  = $this->get_settings_for_display();
    extract($settings); 
    ?>
    <!-- Testimonials Area start -->
    <section class="testimonials-area-two pt-120 rel z-1">
        <div class="container">
            <div class="testimonials-active">
                <?php foreach ( $settings['tabs'] as $item ) : ?>
                <div class="testimonial-item">
                    <div class="row align-items-center justify-content-center">
                        <?php if(isset($item['author_image']['url']) && $item['author_image']['url'] != ''){?>
                        <div class="col-lg-3 col-md-4">
                           <div class="testimonial-image wow fadeInLeft delay-0-2s">
                               <img src="<?php echo wp_kses_post($item['author_image']['url']); ?>" alt="Author">
                           </div>
                        </div>
                        <?php } ?>
                        <div class="col-lg-7 col-md-8">
                            <div class="testimonial-content wow fadeInRight delay-0-2s">
                                <div class="section-title text-white mb-15">
                                    <?php if(isset($settings['heading']) && $settings['heading'] != ''){?>
                                    <h3><?php print wp_kses_post($settings['heading']); ?></h3>
                                    <?php } ?>
                                    <?php if(isset($settings['description']) && $settings['description'] != ''){?>
                                    <span><?php print wp_kses_post($settings['description']); ?></span>
                                    <?php } ?>
                                    <?php if(isset($settings['drop_image']['url']) && $settings['drop_image']['url'] != ''){?>
                                    <img class="drops" src="<?php echo wp_kses_post($settings['drop_image']['url']);?>" alt="Drops">
                                    <?php } ?>
                                </div>
                                <?php if(isset($item['text']) && $item['text'] != ''){?>
                                <p><?php print wp_kses_post($item['text']); ?></p>
                                <?php } ?>
                                <?php if((isset($item['name']) && $item['name'] != '') || (isset($item['time']) && $item['time'] != '')){?>
                                <span class="title mt-20"><?php print wp_kses_post($item['name']); ?><?php print wp_kses_post($item['time']); ?></span>
                                <?php } ?>                         
                            </div>
                        </div>
                    </div>
                </div>
                <?php endforeach; ?>
            </div>
            <div class="feature-two-wrap mt-100 wow fadeInUp delay-0-2s">
                <div class="row no-gap justify-content-center">
                    <?php foreach ( $settings['tabs2'] as $item2 ) : ?>
                    <?php if( wp_kses_post($item2['choose_style']) == 'style_1'): ?>
                    <div class="col-xl-4 col-md-6">
                        <div class="feature-two-item text-white" style="background-image: url(<?php echo wp_kses_post($item2['feature_image']['url']); ?>">
                            <div class="icon">
                                <img src="<?php echo wp_kses_post($item2['image_icon']['url']); ?>" alt="Icon">
                            </div>
                            <?php if( wp_kses_post($item2['button_style']) == '2'): ?>
                            <h5><a href="#" data-bs-toggle="modal" data-bs-target="#donateModal"><?php print wp_kses_post($item2['button']); ?></a></h5>
                            <?php elseif( wp_kses_post($item2['button_style']) == '1'): ?>
                            <h5><a href="<?php print wp_kses_post($item2['link_button']); ?>"><?php print wp_kses_post($item2['button']); ?></a></h5>
                            <?php endif; ?>
                            <?php if(isset($item2['text']) && $item2['text'] != ''){?>
                            <p><?php print wp_kses_post($item2['text']); ?></p>
                            <?php } ?>
                        </div>
                    </div>
                   <?php elseif( wp_kses_post($item2['choose_style']) == 'style_2'): ?>
                    <div class="col-xl-4 col-md-6">
                        <div class="feature-two-item" style="background-image: url(<?php echo wp_kses_post($item2['feature_image']['url']); ?>);">
                            <div class="icon">
                                <img src="<?php echo wp_kses_post($item2['image_icon']['url']); ?>" alt="Icon">
                            </div>
                            <?php if( wp_kses_post($item2['button_style']) == '2'): ?>
                            <h5><a href="#" data-bs-toggle="modal" data-bs-target="#donateModal"><?php print wp_kses_post($item2['button']); ?></a></h5>
                            <?php elseif( wp_kses_post($item2['button_style']) == '1'): ?>
                            <h5><a href="<?php print wp_kses_post($item2['link_button']); ?>"><?php print wp_kses_post($item2['button']); ?></a></h5>
                            <?php endif; ?>
                            <?php if(isset($item2['text']) && $item2['text'] != ''){?>
                            <p><?php print wp_kses_post($item2['text']); ?></p>
                            <?php } ?>
                        </div>
                    </div>
                    <?php endif; ?>
                    <?php endforeach; ?>
                </div>
            </div>
        </div>
        <?php if(isset($settings['background_image']['url']) && $settings['background_image']['url'] != ''){?>
        <div class="testimonials-two-bg bgs-cover" style="background-image: url(<?php echo wp_kses_post($settings['background_image']['url']);?>);"></div>
        <?php } else { ?>
        <div class="testimonials-two-bg bgs-cover"></div>  
        <?php } ?>
    </section>
    <!-- Testimonials Area end -->
    <?php if (is_admin()) { ?>
    <script type="text/javascript">
    if ($('.testimonials-active').length) {
        $('.testimonials-active').slick({
            infinite: true,
            arrows: false,
            dots: false,
            fade: false,
            autoplay: true,
            autoplaySpeed: 4000,
            pauseOnHover: false,
            slidesToScroll: 1,
            slidesToShow: 1,
        });
    }        
    </script>   
    <?php } ?>
    <?php
    }

}


