<?php
namespace BdevsElementor\Widget;

use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;
use Elementor\Scheme_Typography;
use Elementor\Group_Control_Border;
use Elementor\Group_Control_Box_Shadow;

/**
 * Bdevs Elementor Widget.
 *
 * Elementor widget that inserts an embbedable content into the page, from any given URL.
 *
 * @since 1.0.0
 */
class BdevsTestimonial3 extends \Elementor\Widget_Base {

    /**
     * Get widget name.
     *
     * Retrieve Bdevs Elementor widget name.
     *
     * @since 1.0.0
     * @access public
     *
     * @return string Widget name.
     */
    public function get_name() {
        return 'bdevs-testimonial-3';
    }

    /**
     * Get widget title.
     *
     * Retrieve Bdevs Elementor widget title.
     *
     * @since 1.0.0
     * @access public
     *
     * @return string Widget title.
     */
    public function get_title() {
        return __( 'Testimonial 3', 'bdevs-elementor' );
    }

    /**
     * Get widget icon.
     *
     * Retrieve Bdevs About widget icon.
     *
     * @since 1.0.0
     * @access public
     *
     * @return string Widget icon.
     */
    public function get_icon() {
        return 'eicon-blockquote';
    }

    /**
     * Get widget categories.
     *
     * Retrieve the list of categories the Bdevs About widget belongs to.
     *
     * @since 1.0.0
     * @access public
     *
     * @return array Widget categories.
     */
    public function get_categories() {
        return [ 'bdevs-elementor' ];
    }

    public function get_keywords() {
        return [ 'testimonial 3' ];
    }

    public function get_script_depends() {
        return [ 'bdevs-elementor'];
    }

    // BDT Position
    protected function element_pack_position() {
        $position_options = [
            ''              => esc_html__('Default', 'bdevs-elementor'),
            'top-left'      => esc_html__('Top Left', 'bdevs-elementor') ,
            'top-center'    => esc_html__('Top Center', 'bdevs-elementor') ,
            'top-right'     => esc_html__('Top Right', 'bdevs-elementor') ,
            'center'        => esc_html__('Center', 'bdevs-elementor') ,
            'center-left'   => esc_html__('Center Left', 'bdevs-elementor') ,
            'center-right'  => esc_html__('Center Right', 'bdevs-elementor') ,
            'bottom-left'   => esc_html__('Bottom Left', 'bdevs-elementor') ,
            'bottom-center' => esc_html__('Bottom Center', 'bdevs-elementor') ,
            'bottom-right'  => esc_html__('Bottom Right', 'bdevs-elementor') ,
        ];

        return $position_options;
    }

    protected function _register_controls() {
        
        $this->start_controls_section(
            'section_content_heading',
            [
                'label' => esc_html__( 'Testimonial', 'bdevs-elementor' ),
            ]   
        );
        $this->add_control(
            'choose_style',
            [
                'label'     => esc_html__( 'Choose Style', 'bdevs-elementor' ),
                'type'      => Controls_Manager::SELECT,
                'options'   => [
                    'style_1'  => esc_html__( 'Style 1', 'bdevs-elementor' ),
                    'style_2'  => esc_html__( 'Style 2', 'bdevs-elementor' ),
                ],
                'default'   => 'style_1',
            ]
        );
        $this->add_control(
            'left_background_image',
            [
                'label'   => esc_html__( 'Background Image 1:', 'bdevs-elementor' ),
                'type'    => Controls_Manager::MEDIA,
                'dynamic' => [ 'active' => true ],
                'description' => esc_html__( 'Add image from here', 'bdevs-elementor' ),
            ]
        );
        $this->add_control(
            'title',
            [
                'label'       => __( 'Title:', 'bdevs-elementor' ),
                'type'        => Controls_Manager::TEXT,
                'placeholder' => __( 'Enter your title', 'bdevs-elementor' ),
                'default'     => __( 'Our volunteers who are always going through the service', 'bdevs-elementor' ),
                'label_block' => true,
            ]
        );
        $this->add_control(
            'description',
            [
                'label'       => __( 'Description:', 'bdevs-elementor' ),
                'type'        => Controls_Manager::TEXTAREA,
                'placeholder' => __( 'Enter your text', 'bdevs-elementor' ),
                'default'     => __( 'Gifts in Wills power half of our saving work', 'bdevs-elementor' ),
                'label_block' => true,
            ]
        );
        $this->add_control(
            'button_style',
            [
                'label'     => esc_html__( 'Button Style', 'bdevs-elementor' ),
                'type'      => Controls_Manager::SELECT,
                'options'   => [
                    'btn_1'  => esc_html__( 'Style 1', 'bdevs-elementor' ),
                    'btn_2'  => esc_html__( 'Style 2', 'bdevs-elementor' ),
                ],
                'default'   => 'btn_1',
            ]
        );
        $this->add_control(
            'link_button',
            [
                'label'       => __( 'Link Button:', 'bdevs-elementor' ),
                'type'        => Controls_Manager::TEXT,
                'placeholder' => __( 'Enter button', 'bdevs-elementor' ),
                'default'     => __( '#' ),
                'label_block' => true,
            ]
        );
        $this->add_control(
            'button',
            [
                'label'       => __( 'Button:', 'bdevs-elementor' ),
                'type'        => Controls_Manager::TEXT,
                'placeholder' => __( 'Enter button', 'bdevs-elementor' ),
                'default'     => __( 'Join Us Now' ),
                'label_block' => true,
            ]
        );
        $this->add_control(
            'right_background_image',
            [
                'label'   => esc_html__( 'Background Image 2:', 'bdevs-elementor' ),
                'type'    => Controls_Manager::MEDIA,
                'dynamic' => [ 'active' => true ],
                'description' => esc_html__( 'Add image from here', 'bdevs-elementor' ),
            ]
        );
        $this->add_control(
            'text_style',
            [
                'label'     => esc_html__( 'Text Style', 'bdevs-elementor' ),
                'type'      => Controls_Manager::SELECT,
                'options'   => [
                    't_1'  => esc_html__( 'Style 1', 'bdevs-elementor' ),
                    't_2'  => esc_html__( 'Style 2', 'bdevs-elementor' ),
                ],
                'default'   => 't_1',
                'condition' => [
                    'choose_style' => ['style_1'],
                ]
            ]
        );
        $this->add_control(
            'icon',
            [
                'label'       => __( 'Icon:', 'bdevs-elementor' ),
                'type'        => Controls_Manager::TEXT,
                'placeholder' => __( 'Enter your icon', 'bdevs-elementor' ),
                'default'     => __( 'fa-quote-left', 'bdevs-elementor' ),
                'label_block' => true,
            ]
        );         
        $this->add_control(
            'text',
            [
                'label'       => __( 'Text:', 'bdevs-elementor' ),
                'type'        => Controls_Manager::TEXTAREA,
                'placeholder' => __( 'Enter your text', 'bdevs-elementor' ),
                'default'     => __( 'This is text', 'bdevs-elementor' ),
                'label_block' => true,
            ]
        ); 
        $this->add_control(
            'name',
            [
                'label'       => __( 'Name:', 'bdevs-elementor' ),
                'type'        => Controls_Manager::TEXT,
                'placeholder' => __( 'Enter name', 'bdevs-elementor' ),
                'default'     => __( 'Shailushi Richie ', 'bdevs-elementor' ),
                'label_block' => true,
            ]
        );
        $this->add_control(
            'job',
            [
                'label'       => __( 'Job:', 'bdevs-elementor' ),
                'type'        => Controls_Manager::TEXT,
                'placeholder' => __( 'Enter job', 'bdevs-elementor' ),
                'default'     => __( '- Director of Development', 'bdevs-elementor' ),
                'label_block' => true,
            ]
        ); 
        $this->end_controls_section();
        /** 
        *   Layout section 
        **/
        $this->start_controls_section(
            'section_content_layout',
            [
                'label' => esc_html__( 'Layout', 'bdevs-elementor' ),
            ]
        );

        $this->add_responsive_control(
            'align',
            [
                'label'   => esc_html__( 'Alignment', 'bdevs-elementor' ),
                'type'    => Controls_Manager::CHOOSE,
                'options' => [
                    'left' => [
                        'title' => esc_html__( 'Left', 'bdevs-elementor' ),
                        'icon'  => 'fa fa-align-left',
                    ],
                    'center' => [
                        'title' => esc_html__( 'Center', 'bdevs-elementor' ),
                        'icon'  => 'fa fa-align-center',
                    ],
                    'right' => [
                        'title' => esc_html__( 'Right', 'bdevs-elementor' ),
                        'icon'  => 'fa fa-align-right',
                    ],
                    'justify' => [
                        'title' => esc_html__( 'Justified', 'bdevs-elementor' ),
                        'icon'  => 'fa fa-align-justify',
                    ],
                ],
                'prefix_class' => 'elementor%s-align-',
                'description'  => 'Use align to match position',
                'default'      => 'left',
            ]
        );
        $this->end_controls_section();

    }
    public function render() {
    $settings  = $this->get_settings_for_display();
    extract($settings); 
    ?>
    <?php $style = $settings['choose_style'];?>
    <?php if( $style == 'style_1' ): ?>   
    <!-- Testimonials Area start -->
    <section class="testimonials-area-three py-90 rel z-1">
        <div class="container">
           <div class="row align-items-center">
               <div class="col-lg-5 wow fadeInLeft delay-0-2s">
                    <div class="testimonial-three-left p-65 py-90 rmb-40 bgs-cover text-white" style="background-image: url(<?php echo wp_kses_post($settings['left_background_image']['url']);?>);">
                        <?php if(isset($settings['title']) && $settings['title'] != ''){?>
                        <div class="section-title mb-20">
                           <h4><?php print wp_kses_post($settings['title']); ?></h4>
                        </div>
                        <?php } ?>
                        <?php if(isset($settings['description']) && $settings['description'] != ''){?>
                        <p><?php print wp_kses_post($settings['description']); ?></p>
                        <?php } ?>
                        <?php $btn_style = $settings['button_style'];?>
                        <?php if( $btn_style == 'btn_1' ): ?>  
                            <?php if(isset($settings['link_button']) && $settings['link_button'] != ''){?>
                            <a href="<?php print wp_kses_post($settings['link_button']); ?>" class="theme-btn mt-30">
                                <span class="btn-text normal"><i class="fas fa-heart"></i> <?php print wp_kses_post($settings['button']); ?></span>
                                <span class="btn-text hover"><i class="fas fa-heart"></i> <?php print wp_kses_post($settings['button']); ?></span>
                            </a>
                            <?php } ?>
                        <?php elseif( $btn_style == 'btn_2' ): ?>  
                            <?php if(isset($settings['link_button']) && $settings['link_button'] != ''){?>
                            <a href="<?php print wp_kses_post($settings['link_button']); ?>" class="theme-btn style-three mt-30">
                                <span class="btn-text normal"><i class="fas fa-heart"></i> <?php print wp_kses_post($settings['button']); ?></span>
                                <span class="btn-text hover"><i class="fas fa-heart"></i> <?php print wp_kses_post($settings['button']); ?></span>
                            </a>
                            <?php } ?>
                        <?php endif; ?>
                   </div>
               </div>
               <div class="col-lg-7 wow fadeInRight delay-0-2s">
                    <?php $text_style = $settings['text_style'];?>
                    <?php if( $text_style == 't_1' ): ?> 
                    <div class="testimonial-three-right text-center text-white">
                    <?php elseif( $text_style == 't_2' ): ?> 
                    <div class="testimonial-three-right style-three text-center text-white">
                    <?php endif; ?>
                        <?php if(isset($settings['icon']) && $settings['icon'] != ''){?>
                        <div class="icon"><i class="fas <?php print wp_kses_post($settings['icon']); ?>"></i></div>
                        <?php } ?>
                        <?php if(isset($settings['text']) && $settings['text'] != ''){?>
                        <i><?php print wp_kses_post($settings['text']); ?></i>
                        <?php } ?>
                        <div class="testi-footer mt-25">
                           <?php print wp_kses_post($settings['name']); ?> <span><?php print wp_kses_post($settings['job']); ?></span>
                        </div>
                    </div>
               </div>
           </div>
        </div>
        <?php if(isset($settings['right_background_image']['url']) && $settings['right_background_image']['url'] != ''){?>
        <div class="testimonials-three-bg bgs-cover" style="background-image: url(<?php echo wp_kses_post($settings['right_background_image']['url']);?>);"></div>
        <?php } else { ?>
        <div class="testimonials-three-bg bgs-cover"></div>
        <?php } ?>
    </section>
    <!-- Testimonials Area end -->
    <?php elseif( $style == 'style_2' ): ?>
    <!-- Testimonials Area start -->
    <section class="testimonials-area-three py-90 rpt-70 rel z-1">
        <div class="container">
           <div class="row align-items-center">
               <div class="col-lg-7 wow fadeInRight delay-0-2s">
                   <div class="testimonial-three-right style-two rmb-50 text-center text-white">
                        <?php if(isset($settings['icon']) && $settings['icon'] != ''){?>
                        <div class="icon"><i class="fas <?php print wp_kses_post($settings['icon']); ?>"></i></div>
                        <?php } ?>
                        <?php if(isset($settings['text']) && $settings['text'] != ''){?>
                        <i><?php print wp_kses_post($settings['text']); ?></i>
                        <?php } ?>
                        <div class="testi-footer mt-25">
                           <?php print wp_kses_post($settings['name']); ?> <span><?php print wp_kses_post($settings['job']); ?></span>
                        </div>
                   </div>
               </div>
               <div class="col-lg-5 wow fadeInLeft delay-0-2s">
                   <div class="testimonial-three-left p-65 py-90 bgs-cover text-white" style="background-image: url(<?php echo wp_kses_post($settings['left_background_image']['url']);?>);">
                        <?php if(isset($settings['title']) && $settings['title'] != ''){?>
                        <div class="section-title mb-20">
                           <h4><?php print wp_kses_post($settings['title']); ?></h4>
                        </div>
                        <?php } ?>
                        <?php if(isset($settings['description']) && $settings['description'] != ''){?>
                        <p><?php print wp_kses_post($settings['description']); ?></p>
                        <?php } ?>
                        <?php $btn_style = $settings['button_style'];?>
                        <?php if( $btn_style == 'btn_1' ): ?>  
                            <?php if(isset($settings['link_button']) && $settings['link_button'] != ''){?>
                            <a href="<?php print wp_kses_post($settings['link_button']); ?>" class="theme-btn mt-30">
                                <span class="btn-text normal"><i class="fas fa-heart"></i> <?php print wp_kses_post($settings['button']); ?></span>
                                <span class="btn-text hover"><i class="fas fa-heart"></i> <?php print wp_kses_post($settings['button']); ?></span>
                            </a>
                            <?php } ?>
                        <?php elseif( $btn_style == 'btn_2' ): ?>  
                            <?php if(isset($settings['link_button']) && $settings['link_button'] != ''){?>
                            <a href="<?php print wp_kses_post($settings['link_button']); ?>" class="theme-btn style-three mt-30">
                                <span class="btn-text normal"><i class="fas fa-heart"></i> <?php print wp_kses_post($settings['button']); ?></span>
                                <span class="btn-text hover"><i class="fas fa-heart"></i> <?php print wp_kses_post($settings['button']); ?></span>
                            </a>
                            <?php } ?>
                        <?php endif; ?>
                   </div>
               </div>
           </div>
        </div>
        <?php if(isset($settings['right_background_image']['url']) && $settings['right_background_image']['url'] != ''){?>
        <div class="testimonials-three-bg style-two bgs-cover" style="background-image: url(<?php echo wp_kses_post($settings['right_background_image']['url']);?>);"></div>
        <?php } else { ?>
        <div class="testimonials-three-bg style-two bgs-cover"></div>
        <?php } ?>
    </section>
    <!-- Testimonials Area end -->
    <?php endif; ?>
    <?php if (is_admin()) { ?>
    <script type="text/javascript">
    if ($('.testimonials-active').length) {
        $('.testimonials-active').slick({
            infinite: true,
            arrows: false,
            dots: false,
            fade: false,
            autoplay: true,
            autoplaySpeed: 4000,
            pauseOnHover: false,
            slidesToScroll: 1,
            slidesToShow: 1,
        });
    }        
    </script>   
    <?php } ?>
    <?php
    }

}


