<?php
namespace BdevsElementor\Widget;

use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;
use Elementor\Scheme_Typography;
use Elementor\Group_Control_Border;
use Elementor\Group_Control_Box_Shadow;

/**
 * Bdevs Elementor Widget.
 *
 * Elementor widget that inserts an embbedable content into the page, from any given URL.
 *
 * @since 1.0.0
 */
class BdevsVideo extends \Elementor\Widget_Base {

    /**
     * Get widget name.
     *
     * Retrieve Bdevs Elementor widget name.
     *
     * @since 1.0.0
     * @access public
     *
     * @return string Widget name.
     */
    public function get_name() {
        return 'bdevs-video';
    }

    /**
     * Get widget title.
     *
     * Retrieve Bdevs Elementor widget title.
     *
     * @since 1.0.0
     * @access public
     *
     * @return string Widget title.
     */
    public function get_title() {
        return __( 'Video', 'bdevs-elementor' );
    }

    /**
     * Get widget icon.
     *
     * Retrieve Bdevs About widget icon.
     *
     * @since 1.0.0
     * @access public
     *
     * @return string Widget icon.
     */
    public function get_icon() {
        return 'eicon-youtube';
    }

    /**
     * Get widget categories.
     *
     * Retrieve the list of categories the Bdevs About widget belongs to.
     *
     * @since 1.0.0
     * @access public
     *
     * @return array Widget categories.
     */
    public function get_categories() {
        return [ 'bdevs-elementor' ];
    }

    public function get_keywords() {
        return [ 'video' ];
    }

    public function get_script_depends() {
        return [ 'bdevs-elementor'];
    }

    // BDT Position
    protected function element_pack_position() {
        $position_options = [
            ''              => esc_html__('Default', 'bdevs-elementor'),
            'top-left'      => esc_html__('Top Left', 'bdevs-elementor') ,
            'top-center'    => esc_html__('Top Center', 'bdevs-elementor') ,
            'top-right'     => esc_html__('Top Right', 'bdevs-elementor') ,
            'center'        => esc_html__('Center', 'bdevs-elementor') ,
            'center-left'   => esc_html__('Center Left', 'bdevs-elementor') ,
            'center-right'  => esc_html__('Center Right', 'bdevs-elementor') ,
            'bottom-left'   => esc_html__('Bottom Left', 'bdevs-elementor') ,
            'bottom-center' => esc_html__('Bottom Center', 'bdevs-elementor') ,
            'bottom-right'  => esc_html__('Bottom Right', 'bdevs-elementor') ,
        ];

        return $position_options;
    }

    protected function _register_controls() {
        
        $this->start_controls_section(
            'section_content_video',
            [
                'label' => esc_html__( 'Video', 'bdevs-elementor' ),
            ]   
        ); 
        $this->add_control(
            'background_video',
            [
                'label'   => esc_html__( 'Background Video:', 'bdevs-elementor' ),
                'type'    => Controls_Manager::MEDIA,
                'dynamic' => [ 'active' => true ],
                'description' => esc_html__( 'Add image from here', 'bdevs-elementor' ),
            ]
        );
        $this->add_control(
            'play_icon',
            [
                'label'       => __( 'Play Icon:', 'bdevs-elementor' ),
                'type'        => Controls_Manager::TEXT,
                'placeholder' => __( 'Enter your play icon', 'bdevs-elementor' ),
                'default'     => __( 'fal fa-play-circle', 'bdevs-elementor' ),
                'label_block' => true,
            ]
        );
        $this->add_control(
            'link_video',
            [
                'label'       => __( 'Link Video:', 'bdevs-elementor' ),
                'type'        => Controls_Manager::TEXT,
                'placeholder' => __( 'Enter your link', 'bdevs-elementor' ),
                'default'     => __( 'https://www.youtube.com/watch?v=9Y7ma241N8k', 'bdevs-elementor' ),
                'label_block' => true,
            ]
        );
        $this->add_control(
            'subheading',
            [
                'label'       => __( 'Subheading:', 'bdevs-elementor' ),
                'type'        => Controls_Manager::TEXT,
                'placeholder' => __( 'Enter your subheading', 'bdevs-elementor' ),
                'default'     => __( 'Healthy People. Better World.', 'bdevs-elementor' ),
                'label_block' => true,
            ]
        ); 
        $this->add_control(
            'tabs',
            [
                'label' => esc_html__( 'Heading:', 'bdevs-elementor' ),
                'type' => Controls_Manager::REPEATER,
                'fields' => [
                    [
                        'name'        => 'heading_style',
                        'label'     => esc_html__( 'Heading Style', 'bdevs-elementor' ),
                        'type'      => Controls_Manager::SELECT,
                        'dynamic' => [ 'active' => true ],
                        'options'   => [
                            '1'  => esc_html__( 'Normal', 'bdevs-elementor' ),
                            '2'  => esc_html__( 'Color', 'bdevs-elementor' ),
                        ],
                        'default'   => '1',
                    ],
                    
                    [
                        'name'        => 'text',
                        'label'       => esc_html__( 'Text:', 'bdevs-elementor' ),
                        'type'        => Controls_Manager::TEXTAREA,
                        'dynamic'     => [ 'active' => true ],
                        'default'     => esc_html__( 'Charitxa' , 'bdevs-elementor' ),
                        'label_block' => true,
                    ],                   
                ],
            ]
        );
        $this->add_control(
            'description',
            [
                'label'       => __( 'Description:', 'bdevs-elementor' ),
                'type'        => Controls_Manager::TEXTAREA,
                'placeholder' => __( 'Enter your description', 'bdevs-elementor' ),
                'default'     => __( 'The Feeding America network is the nation’s largest domestic hunger-relief organization, working to connect people with food and end hunger.' ),
                'label_block' => true,
            ]
        ); 
        $this->add_control(
            'tabs2',
            [
                'label' => esc_html__( 'Couter:', 'bdevs-elementor' ),
                'type' => Controls_Manager::REPEATER,
                'fields' => [
                    [
                        'name'        => 'title',
                        'label'       => esc_html__( 'Title:', 'bdevs-elementor' ),
                        'type'        => Controls_Manager::TEXT,
                        'dynamic'     => [ 'active' => true ],
                        'default'     => esc_html__( 'Children Sponsored' , 'bdevs-elementor' ),
                        'label_block' => true,
                    ],
                    [
                        'name'        => 'count_from',
                        'label'       => esc_html__( 'Count From:', 'bdevs-elementor' ),
                        'type'        => Controls_Manager::TEXT,
                        'dynamic'     => [ 'active' => true ],
                        'default'     => esc_html__( '0' , 'bdevs-elementor' ),
                        'label_block' => true,
                    ],
                    [
                        'name'        => 'count_to',
                        'label'       => esc_html__( 'Count To:', 'bdevs-elementor' ),
                        'type'        => Controls_Manager::TEXT,
                        'dynamic'     => [ 'active' => true ],
                        'default'     => esc_html__( '3.42' , 'bdevs-elementor' ),
                        'label_block' => true,
                    ],
                    [
                        'name'        => 'after_number',
                        'label'       => esc_html__( 'After Number:', 'bdevs-elementor' ),
                        'type'        => Controls_Manager::TEXT,
                        'dynamic'     => [ 'active' => true ],
                        'default'     => esc_html__( 'M' , 'bdevs-elementor' ),
                        'label_block' => true,
                    ],
                ],
            ]
        );
        $this->add_control(
            'subtitle',
            [
                'label'       => __( 'Subtitle:', 'bdevs-elementor' ),
                'type'        => Controls_Manager::TEXT,
                'placeholder' => __( 'Enter your subtitle', 'bdevs-elementor' ),
                'default'     => __( 'Live Another Day', 'bdevs-elementor' ),
                'label_block' => true,
            ]
        );
        $this->add_control(
            'title',
            [
                'label'       => __( 'Title:', 'bdevs-elementor' ),
                'type'        => Controls_Manager::TEXTAREA,
                'placeholder' => __( 'Enter your title', 'bdevs-elementor' ),
                'default'     => __( 'Every 60 seconds a family receives the tools to overcome poverty', 'bdevs-elementor' ),
                'label_block' => true,
            ]
        );
        $this->end_controls_section();
        /** 
        *   Layout section 
        **/
        $this->start_controls_section(
            'section_content_layout',
            [
                'label' => esc_html__( 'Layout', 'bdevs-elementor' ),
            ]
        );

        $this->add_responsive_control(
            'align',
            [
                'label'   => esc_html__( 'Alignment', 'bdevs-elementor' ),
                'type'    => Controls_Manager::CHOOSE,
                'options' => [
                    'left' => [
                        'title' => esc_html__( 'Left', 'bdevs-elementor' ),
                        'icon'  => 'fa fa-align-left',
                    ],
                    'center' => [
                        'title' => esc_html__( 'Center', 'bdevs-elementor' ),
                        'icon'  => 'fa fa-align-center',
                    ],
                    'right' => [
                        'title' => esc_html__( 'Right', 'bdevs-elementor' ),
                        'icon'  => 'fa fa-align-right',
                    ],
                    'justify' => [
                        'title' => esc_html__( 'Justified', 'bdevs-elementor' ),
                        'icon'  => 'fa fa-align-justify',
                    ],
                ],
                'prefix_class' => 'elementor%s-align-',
                'description'  => 'Use align to match position',
                'default'      => 'left',
            ]
        );
        $this->end_controls_section();
    }
    public function render() {
        $settings  = $this->get_settings_for_display();
        extract($settings); 
        ?>
        <!-- Video Area start -->
        <section class="video-area py-80 rpt-0 rpb-25 rel z-1">
            <div class="container">
                <div class="row align-items-end">
                    <div class="col-lg-7">
                        <div class="video-left-part rel z-1 rmb-55 wow fadeInLeft delay-0-2s">
                            <div class="section-title mb-15">
                                <?php if(isset($settings['subheading']) && $settings['subheading'] != ''){?>
                                <span class="sub-title mb-5"><?php print wp_kses_post($settings['subheading']); ?></span>
                                <?php } ?>
                                <h3>
                                    <?php foreach ( $settings['tabs'] as $item ) :  ?>
                                    <?php if( wp_kses_post($item['heading_style']) == '1'): ?>
                                    <?php print wp_kses_post($item['text']); ?>
                                    <?php elseif( wp_kses_post($item['heading_style']) == '2'): ?>
                                    <span><?php print wp_kses_post($item['text']); ?></span>  
                                    <?php endif; ?> 
                                    <?php endforeach; ?> 
                                </h3>
                            </div>
                            <?php if(isset($settings['description']) && $settings['description'] != ''){?>
                            <p><?php print wp_kses_post($settings['description']); ?></p>
                            <?php } ?>
                            <div class="counter-inner-wrap">
                                <?php foreach ( $settings['tabs2'] as $item2 ) : ?>
                                <div class="counter-text-wrap">
                                    <span class="count-text m" data-speed="3000" data-stop="<?php print wp_kses_post($item2['count_to']); ?>"><?php print wp_kses_post($item2['count_from']); ?></span>
                                    <style type="text/css">
                                        .count-text.m:after {
                                            content: '<?php print wp_kses_post($item2['after_number']); ?>';
                                            font-size: 30px;
                                        }
                                    </style>
                                    <?php if(isset($item2['title']) && $item2['title'] != ''){?>
                                    <i class="counter-title"><?php print wp_kses_post($item2['title']); ?></i>
                                    <?php } ?>
                                </div>                                
                                <?php endforeach; ?>
                            </div>
                            <a href="<?php print wp_kses_post($settings['link_video']); ?>" class="mfp-iframe video-play"><i class="<?php print wp_kses_post($settings['play_icon']); ?>"></i></a>
                        </div>
                    </div>
                    <div class="col-lg-5">
                        <div class="video-right-part text-white mb-55 wow fadeInRight delay-0-2s">
                            <div class="section-title">
                                <?php if(isset($settings['subtitle']) && $settings['subtitle'] != ''){?>
                                <span class="sub-title mb-10"><?php print wp_kses_post($settings['subtitle']); ?></span>
                                <?php } ?>
                                <?php if(isset($settings['title']) && $settings['title'] != ''){?>
                                <h4><?php print wp_kses_post($settings['title']); ?></h4>
                                <?php } ?>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
            <div class="video-section-bg" style="background-image: url(<?php echo wp_kses_post($settings['background_video']['url']);?>);"></div>
        </section>
        <!-- Video Area end -->
    <?php
    }
}


