<?php
/**
 * Footer widget widget class
 *
 * @since 2.8.0
 */
class charitxa_contacts extends WP_Widget {

    function __construct() {
        $widget_ops = array('classname' => 'contacts', 'description' => esc_html__( "Footer Contacts", 'charitxa') );
        parent::__construct('footer-contacts', esc_html__('Footer Contacts', 'charitxa'), $widget_ops);
        $this->alt_option_name = 'contacts';
    }

    function widget($args, $instance) {
        $cache = wp_cache_get('charitxa_contacts', 'widget');

        if ( !is_array($cache) )
            $cache = array();

        if ( ! isset( $args['widget_id'] ) )
            $args['widget_id'] = $this->id;

        if ( isset( $cache[ $args['widget_id'] ] ) ) {
            echo wp_specialchars_decode(wp_kses_post($cache[ $args['widget_id'] ]));
            return;
        }

        ob_start();
        extract($args);
        $title = ( ! empty( $instance['title'] ) ) ? $instance['title'] : esc_html__( '', 'charitxa' );
        $title = apply_filters( 'widget_title', $title, $instance, $this->id_base );
        $email_title = ( ! empty( $instance['email_title'] ) ) ? $instance['email_title'] : esc_html__( '', 'charitxa' );
        $email = ( ! empty( $instance['email'] ) ) ? $instance['email'] : esc_html__( '', 'charitxa' );
        $phone_title = ( ! empty( $instance['phone_title'] ) ) ? $instance['phone_title'] : esc_html__( '', 'charitxa' );
        $phone = ( ! empty( $instance['phone'] ) ) ? $instance['phone'] : esc_html__( '', 'charitxa' );
        $location_title = ( ! empty( $instance['location_title'] ) ) ? $instance['location_title'] : esc_html__( '', 'charitxa' );
        $location_detail = ( ! empty( $instance['location_detail'] ) ) ? $instance['location_detail'] : esc_html__( '', 'charitxa' );
        ?>
        <?php echo wp_specialchars_decode(wp_kses_post($before_widget),ENT_QUOTES); ?>
        <?php if(isset($title) && $title != ''){?>
        <h4 class="footer-title"><?php echo wp_kses_post($title); ?></h4>
        <?php } ?>
        <ul>
            <li><b><?php echo wp_kses_post($email_title); ?></b> <a href="mailto:<?php echo wp_kses_post($email); ?>"><?php echo wp_kses_post($email); ?></a></li>
            <li><b><?php echo wp_kses_post($phone_title); ?></b> <a href="tel:<?php echo wp_kses_post($phone); ?>"><?php echo wp_kses_post($phone); ?></a></li>
            <li><b><?php echo wp_kses_post($location_title); ?></b> <?php echo wp_kses_post($location_detail); ?></li>
        </ul>
        <?php echo wp_specialchars_decode(wp_kses_post($after_widget)); ?>
    <?php
        // Reset the global $the_post as this query will have stomped on it
        $cache[$args['widget_id']] = ob_get_flush();
        wp_cache_set('charitxa_contacts', $cache, 'widget');
    }

    function update( $new_instance, $old_instance ) {
        $instance = $old_instance;
        $instance['title'] = strip_tags($new_instance['title']);
        $instance['location_title'] = strip_tags($new_instance['location_title']);
        $instance['location_detail'] = strip_tags($new_instance['location_detail']);
        $instance['email_title'] = strip_tags($new_instance['email_title']);
        $instance['email'] = strip_tags($new_instance['email']);
        $instance['phone_title'] = strip_tags($new_instance['phone_title']);
        $instance['phone'] = strip_tags($new_instance['phone']);
        
 
        $alloptions = wp_cache_get( 'alloptions', 'options' );
        if ( isset($alloptions['contacts']) )
            delete_option('contacts');
        return $instance;
    }

    function form( $instance ) {   
        $title     = isset( $instance['title'] ) ? wp_kses_post( $instance['title'] ) : '';
        $text     = isset( $instance['text'] ) ? wp_kses_post( $instance['text'] ) : '';   
        $location_title     = isset( $instance['location_title'] ) ? wp_kses_post( $instance['location_title'] ) : '';
        $location_detail     = isset( $instance['location_detail'] ) ? wp_kses_post( $instance['location_detail'] ) : '';
        $email_title     = isset( $instance['email_title'] ) ? wp_kses_post( $instance['email_title'] ) : '';
        $email     = isset( $instance['email'] ) ? wp_kses_post( $instance['email'] ) : '';
        $phone_title     = isset( $instance['phone_title'] ) ? wp_kses_post( $instance['phone_title'] ) : '';
        $phone     = isset( $instance['phone'] ) ? wp_kses_post( $instance['phone'] ) : '';
        
?>
    <p><label for="<?php echo wp_kses_post($this->get_field_id( 'title' )); ?>"><?php esc_html_e( 'Title:', 'charitxa' ); ?></label>
    <input class="widefat" id="<?php echo wp_kses_post($this->get_field_id( 'title' )); ?>" name="<?php echo wp_kses_post($this->get_field_name( 'title' )); ?>" type="text" value="<?php echo wp_kses_post($title); ?>"/></p>

    <p><label for="<?php echo wp_kses_post($this->get_field_id( 'email_title' )); ?>"><?php esc_html_e( 'Email Title:', 'charitxa' ); ?></label>
    <input class="widefat" id="<?php echo wp_kses_post($this->get_field_id( 'email_title' )); ?>" name="<?php echo wp_kses_post($this->get_field_name( 'email_title' )); ?>" type="text" value="<?php echo wp_kses_post($email_title); ?>"/></p>
    <p><label for="<?php echo wp_kses_post($this->get_field_id( 'email' )); ?>"><?php esc_html_e( 'Email:', 'charitxa' ); ?></label>
    <input class="widefat" id="<?php echo wp_kses_post($this->get_field_id( 'email' )); ?>" name="<?php echo wp_kses_post($this->get_field_name( 'email' )); ?>" type="text" value="<?php echo wp_kses_post($email); ?>"/></p>

    <p><label for="<?php echo wp_kses_post($this->get_field_id( 'phone_title' )); ?>"><?php esc_html_e( 'Phone Title:', 'charitxa' ); ?></label>
    <input class="widefat" id="<?php echo wp_kses_post($this->get_field_id( 'phone_title' )); ?>" name="<?php echo wp_kses_post($this->get_field_name( 'phone_title' )); ?>" type="text" value="<?php echo wp_kses_post($phone_title); ?>"/></p>
    <p><label for="<?php echo wp_kses_post($this->get_field_id( 'phone' )); ?>"><?php esc_html_e( 'Phone:', 'charitxa' ); ?></label>
    <input class="widefat" id="<?php echo wp_kses_post($this->get_field_id( 'phone' )); ?>" name="<?php echo wp_kses_post($this->get_field_name( 'phone' )); ?>" type="text" value="<?php echo wp_kses_post($phone); ?>"/></p>

    <p><label for="<?php echo wp_kses_post($this->get_field_id( 'location_title' )); ?>"><?php esc_html_e( 'Location Title:', 'charitxa' ); ?></label>
    <input class="widefat" id="<?php echo wp_kses_post($this->get_field_id( 'location_title' )); ?>" name="<?php echo wp_kses_post($this->get_field_name( 'location_title' )); ?>" type="text" value="<?php echo wp_kses_post($location_title); ?>"/></p>
    <p><label for="<?php echo wp_kses_post($this->get_field_id( 'location_detail' )); ?>"><?php esc_html_e( 'Location Detail:', 'charitxa' ); ?></label>
    <input class="widefat" id="<?php echo wp_kses_post($this->get_field_id( 'location_detail' )); ?>" name="<?php echo wp_kses_post($this->get_field_name( 'location_detail' )); ?>" type="text" value="<?php echo wp_kses_post($location_detail); ?>"/></p>
<?php
    }
}
function charitxa_register_custom_contacts() {
    register_widget( 'charitxa_contacts' );
}
add_action( 'widgets_init', 'charitxa_register_custom_contacts' );
