<?php
/**
 * Footer widget widget class
 *
 * @since 2.8.0
 */
class charitxa_widget_footer_social extends WP_Widget {

    function __construct() {
        $widget_ops = array('classname' => 'widget_footer_social', 'description' => esc_html__( "Footer Social", 'charitxa') );
        parent::__construct('footer-social', esc_html__('Charitxa Footer Social', 'charitxa'), $widget_ops);
        $this->alt_option_name = 'widget_footer_social';
    }

    function widget($args, $instance) {
        $cache = wp_cache_get('charitxa_widget_footer_social', 'widget');

        if ( !is_array($cache) )
            $cache = array();

        if ( ! isset( $args['widget_id'] ) )
            $args['widget_id'] = $this->id;

        if ( isset( $cache[ $args['widget_id'] ] ) ) {
            echo wp_specialchars_decode(wp_kses_post($cache[ $args['widget_id'] ]));
            return;
        }

        ob_start();
        extract($args);
        $title = ( ! empty( $instance['title'] ) ) ? $instance['title'] : esc_html__( '', 'charitxa' );
        $title = apply_filters( 'widget_title', $title, $instance, $this->id_base );
        $link_social_1 = ( ! empty( $instance['link_social_1'] ) ) ? $instance['link_social_1'] : esc_html__( '', 'charitxa' );
        $social_1 = ( ! empty( $instance['social_1'] ) ) ? $instance['social_1'] : esc_html__( '', 'charitxa' );
        $link_social_2 = ( ! empty( $instance['link_social_2'] ) ) ? $instance['link_social_2'] : esc_html__( '', 'charitxa' );
        $social_2 = ( ! empty( $instance['social_2'] ) ) ? $instance['social_2'] : esc_html__( '', 'charitxa' );
        $link_social_3 = ( ! empty( $instance['link_social_3'] ) ) ? $instance['link_social_3'] : esc_html__( '', 'charitxa' );
        $social_3 = ( ! empty( $instance['social_3'] ) ) ? $instance['social_3'] : esc_html__( '', 'charitxa' );
        $link_social_4 = ( ! empty( $instance['link_social_4'] ) ) ? $instance['link_social_4'] : esc_html__( '', 'charitxa' );
        $social_4 = ( ! empty( $instance['social_4'] ) ) ? $instance['social_4'] : esc_html__( '', 'charitxa' );
        ?>
        <?php echo wp_specialchars_decode(wp_kses_post($before_widget),ENT_QUOTES); ?>
        <?php if(isset($title) && $title != ''){?>
        <h4 class="footer-title"><?php echo wp_kses_post($title); ?></h4>
        <?php } ?>
        <div class="social-style-one">
            <?php if(isset($link_social_1) && $link_social_1 != ''){?>
            <a class="facebook" href="<?php echo esc_url($link_social_1); ?>"><i class="<?php echo wp_kses_post($social_1); ?>"></i></a>
            <?php } ?>
            <?php if(isset($link_social_2) && $link_social_2 != ''){?>
            <a class="twitter" href="<?php echo esc_url($link_social_2); ?>"><i class="<?php echo wp_kses_post($social_2); ?>"></i></a>
            <?php } ?>
            <?php if(isset($link_social_3) && $link_social_3 != ''){?>
            <a class="google" href="<?php echo esc_url($link_social_3); ?>"><i class="<?php echo wp_kses_post($social_3); ?>"></i></a>
            <?php } ?>
            <?php if(isset($link_social_4) && $link_social_4 != ''){?>
            <a class="linkedin" href="<?php echo esc_url($link_social_4); ?>"><i class="<?php echo wp_kses_post($social_4); ?>"></i></a>
            <?php } ?>
        </div>
        <?php echo wp_specialchars_decode(wp_kses_post($after_widget)); ?>
    <?php
        // Reset the global $the_post as this query will have stomped on it
        $cache[$args['widget_id']] = ob_get_flush();
        wp_cache_set('charitxa_widget_footer_social', $cache, 'widget');
    }

    function update( $new_instance, $old_instance ) {
        $instance = $old_instance;
         $instance['title'] = strip_tags($new_instance['title']);
        $instance['link_social_1'] = strip_tags($new_instance['link_social_1']);
        $instance['social_1'] = strip_tags($new_instance['social_1']);
        $instance['link_social_2'] = strip_tags($new_instance['link_social_2']);
        $instance['social_2'] = strip_tags($new_instance['social_2']);
        $instance['link_social_3'] = strip_tags($new_instance['link_social_3']);
        $instance['social_3'] = strip_tags($new_instance['social_3']);
        $instance['link_social_4'] = strip_tags($new_instance['link_social_4']);
        $instance['social_4'] = strip_tags($new_instance['social_4']);

        $alloptions = wp_cache_get( 'alloptions', 'options' );
        if ( isset($alloptions['widget_footer_social']) )
            delete_option('widget_footer_social');
        return $instance;
    }

    function form( $instance ) {   
        $title     = isset( $instance['title'] ) ? wp_kses_post( $instance['title'] ) : '';   
        $link_social_1     = isset( $instance['link_social_1'] ) ? esc_url( $instance['link_social_1'] ) : '';
        $social_1     = isset( $instance['social_1'] ) ? wp_kses_post( $instance['social_1'] ) : '';
        $link_social_2     = isset( $instance['link_social_2'] ) ? esc_url( $instance['link_social_2'] ) : '';
        $social_2     = isset( $instance['social_2'] ) ? wp_kses_post( $instance['social_2'] ) : '';
        $link_social_3     = isset( $instance['link_social_3'] ) ? esc_url( $instance['link_social_3'] ) : '';
        $social_3     = isset( $instance['social_3'] ) ? wp_kses_post( $instance['social_3'] ) : '';
        $link_social_4     = isset( $instance['link_social_4'] ) ? esc_url( $instance['link_social_4'] ) : '';
        $social_4     = isset( $instance['social_4'] ) ? wp_kses_post( $instance['social_4'] ) : '';
?>  
    <p><label for="<?php echo wp_kses_post($this->get_field_id( 'title' )); ?>"><?php esc_html_e( 'Title:', 'charitxa' ); ?></label>
    <input class="widefat" id="<?php echo wp_kses_post($this->get_field_id( 'title' )); ?>" name="<?php echo wp_kses_post($this->get_field_name( 'title' )); ?>" type="text" value="<?php echo wp_kses_post($title);?>"/></p>

    <p><label for="<?php echo wp_kses_post($this->get_field_id( 'link_social_1' )); ?>"><?php esc_html_e( 'Link Social 1:', 'charitxa' ); ?></label>
    <input class="widefat" id="<?php echo wp_kses_post($this->get_field_id( 'link_social_1' )); ?>" name="<?php echo wp_kses_post($this->get_field_name( 'link_social_1' )); ?>" type="text" value="<?php echo wp_kses_post($link_social_1);?>"/></p>

    <p><label for="<?php echo wp_kses_post($this->get_field_id( 'social_1' )); ?>"><?php esc_html_e( 'Social 1:', 'charitxa' ); ?></label>
    <input class="widefat" id="<?php echo wp_kses_post($this->get_field_id( 'social_1' )); ?>" name="<?php echo wp_kses_post($this->get_field_name( 'social_1' )); ?>" type="text" value="<?php echo wp_kses_post($social_1); ?>"/></p>

    <p><label for="<?php echo wp_kses_post($this->get_field_id( 'link_social_2' )); ?>"><?php esc_html_e( 'Link Social 2:', 'charitxa' ); ?></label>
    <input class="widefat" id="<?php echo wp_kses_post($this->get_field_id( 'link_social_2' )); ?>" name="<?php echo wp_kses_post($this->get_field_name( 'link_social_2' )); ?>" type="text" value="<?php echo wp_kses_post($link_social_2); ?>"/></p>

    <p><label for="<?php echo wp_kses_post($this->get_field_id( 'social_2' )); ?>"><?php esc_html_e( 'Social 2:', 'charitxa' ); ?></label>
    <input class="widefat" id="<?php echo wp_kses_post($this->get_field_id( 'social_2' )); ?>" name="<?php echo wp_kses_post($this->get_field_name( 'social_2' )); ?>" type="text" value="<?php echo wp_kses_post($social_2); ?>" /></p>

    <p><label for="<?php echo wp_kses_post($this->get_field_id( 'link_social_3' )); ?>"><?php esc_html_e( 'Link Social 3:', 'charitxa' ); ?></label>
    <input class="widefat" id="<?php echo wp_kses_post($this->get_field_id( 'link_social_3' )); ?>" name="<?php echo wp_kses_post($this->get_field_name( 'link_social_3' )); ?>" type="text" value="<?php echo wp_kses_post($link_social_3); ?>" /></p>

    <p><label for="<?php echo wp_kses_post($this->get_field_id( 'social_3' )); ?>"><?php esc_html_e( 'Social 3:', 'charitxa' ); ?></label>
    <input class="widefat" id="<?php echo wp_kses_post($this->get_field_id( 'social_3' )); ?>" name="<?php echo wp_kses_post($this->get_field_name( 'social_3' )); ?>" type="text" value="<?php echo wp_kses_post($social_3); ?>" /></p>

    <p><label for="<?php echo wp_kses_post($this->get_field_id( 'link_social_4' )); ?>"><?php esc_html_e( 'Link Social 4:', 'charitxa' ); ?></label>
    <input class="widefat" id="<?php echo wp_kses_post($this->get_field_id( 'link_social_4' )); ?>" name="<?php echo wp_kses_post($this->get_field_name( 'link_social_4' )); ?>" type="text" value="<?php echo wp_kses_post($link_social_4);?>" /></p>

    <p><label for="<?php echo wp_kses_post($this->get_field_id( 'social_4' )); ?>"><?php esc_html_e( 'Social 4:', 'charitxa' ); ?></label>
    <input class="widefat" id="<?php echo wp_kses_post($this->get_field_id( 'social_4' )); ?>" name="<?php echo wp_kses_post($this->get_field_name( 'social_4' )); ?>" type="text" value="<?php echo wp_kses_post($social_4); ?>" /></p>
<?php
    }
}

function charitxa_register_custom_widget_footer_social() {
    register_widget( 'charitxa_widget_footer_social' );
}
add_action( 'widgets_init', 'charitxa_register_custom_widget_footer_social' );    