<?php
class charitxa_cause_widget_news extends WP_Widget {

    function __construct() {
        $widget_ops = array('classname' => 'widget_cause_news', 'description' => esc_html__( "The most recent posts on your site", 'charitxa') );
        parent::__construct('recent-cause', esc_html__('Charitxa Recent Causes', 'charitxa'), $widget_ops);
        $this->alt_option_name = 'widget_cause_news';

    }

    function widget($args, $instance) {
        $cache = wp_cache_get('charitxa_cause_widget_news', 'widget');

        if ( !is_array($cache) )
            $cache = array();

        if ( ! isset( $args['widget_id'] ) )
            $args['widget_id'] = $this->id;

        if ( isset( $cache[ $args['widget_id'] ] ) ) {
            echo wp_specialchars_decode(wp_kses_post($cache[ $args['widget_id'] ]));
            return;
        }

        ob_start();
        extract($args);

        $title = ( ! empty( $instance['title'] ) ) ? $instance['title'] : esc_html__( '', 'charitxa' );
        $title = apply_filters( 'widget_title', $title, $instance, $this->id_base );
        $number = ( ! empty( $instance['number'] ) ) ? absint( $instance['number'] ) : 10;

        $args = array(   
          'posts_per_page' => $instance['number'], 
          'post_type' => 'cause',
        ); 
        $wp_query = new \WP_Query($args); 
?>
        <?php echo wp_specialchars_decode(wp_kses_post($before_widget),ENT_QUOTES); ?>
        <?php if ( $title ) echo wp_specialchars_decode(wp_kses_post($before_title),ENT_QUOTES) . wp_kses_post($title) . wp_specialchars_decode(wp_kses_post($after_title),ENT_QUOTES); ?>
        <div class="widget-content">
            <?php while ($wp_query -> have_posts()): $wp_query -> the_post();?> 
            <?php $c_featured_image_7 = get_post_meta(get_the_ID(),'_cmb_c_featured_image_7', true); ?>
            <?php $c_short_title = get_post_meta(get_the_ID(),'_cmb_c_short_title', true); ?>
            <?php $after_donation_raised = get_post_meta(get_the_ID(),'_cmb_after_donation_raised', true); ?>
            <?php $before_donation_goal_2 = get_post_meta(get_the_ID(),'_cmb_before_donation_goal_2', true); ?>
            <?php $donation_goal = get_post_meta(get_the_ID(),'_cmb_donation_goal', true); ?>
            <?php $raised_percent = get_post_meta(get_the_ID(),'_cmb_raised_percent', true); ?>
            <div class="widget-cause-item">
                <?php if(isset($c_featured_image_7) && $c_featured_image_7 != '') { ?>
                <img src="<?php echo wp_get_attachment_url($c_featured_image_7);?>" alt="<?php the_title_attribute(); ?>">
                <?php } else { ?>
                <img src="<?php echo wp_get_attachment_url(get_post_thumbnail_id());?>" alt="<?php the_title_attribute(); ?>">
                <?php } ?>
                <div class="content">
                    <?php if(isset($c_short_title) && $c_short_title != '') { ?>
                    <h6><a href="<?php the_permalink();?>"><?php echo wp_kses_post($c_short_title); ?></a></h6>
                    <?php } else { ?>
                    <h6><a href="<?php the_permalink();?>"><?php the_title(); ?></a></h6>
                    <?php } ?>
                    <span class="price"><?php echo wp_kses_post($raised_percent); ?>% <?php echo wp_kses_post($after_donation_raised); ?> <span class="goal"> <?php echo wp_kses_post($before_donation_goal_2); ?> <?php echo wp_kses_post($donation_goal); ?> </span></span>
                </div>
            </div>
            <?php endwhile; ?>
        </div>
        <?php echo wp_specialchars_decode(wp_kses_post($after_widget)); ?>
<?php
        // Reset the global $the_post as this query will have stomped on it
        wp_reset_postdata();


        $cache[$args['widget_id']] = ob_get_flush();
        wp_cache_set('charitxa_cause_widget_news', $cache, 'widget');
    }

    function update( $new_instance, $old_instance ) {
        $instance = $old_instance;
        $instance['title'] = strip_tags($new_instance['title']);
        $instance['number'] = (int) $new_instance['number'];
        $instance['show_date'] = (bool) $new_instance['show_date'];

        $alloptions = wp_cache_get( 'alloptions', 'options' );
        if ( isset($alloptions['widget_news']) )
            delete_option('widget_news');

        return $instance;
    }


    function form( $instance ) {
        $title     = isset( $instance['title'] ) ? wp_kses_post( $instance['title'] ) : '';
        $number    = isset( $instance['number'] ) ? absint( $instance['number'] ) : 3;
        $show_date = isset( $instance['show_date'] ) ? (bool) $instance['show_date'] : false;
?>
        <p><label for="<?php echo wp_kses_post($this->get_field_id( 'title' )); ?>"><?php esc_html_e( 'Title:', 'charitxa' ); ?></label>
        <input class="widefat" id="<?php echo wp_kses_post($this->get_field_id( 'title' )); ?>" name="<?php echo wp_kses_post($this->get_field_name( 'title' )); ?>" type="text" value="<?php echo wp_kses_post($title); ?>" /></p>

        <p><label for="<?php echo wp_kses_post($this->get_field_id( 'number' )); ?>"><?php esc_html_e( 'Number of posts to show:', 'charitxa' ); ?></label>
        <input id="<?php echo wp_kses_post($this->get_field_id( 'number' )); ?>" name="<?php echo wp_kses_post($this->get_field_name( 'number' )); ?>" type="text" value="<?php echo wp_kses_post($number); ?>" size="3" /></p>
<?php
    }
}
function charitxa_register_cause_custom_widgets() {
    register_widget( 'charitxa_cause_widget_news' );
}
add_action( 'widgets_init', 'charitxa_register_cause_custom_widgets' ); 