<?php
/**
 * Recent_Posts widget class
 *
 * @since 2.8.0
 */
class charitxa_widget_newss extends WP_Widget {

    function __construct() {
        $widget_ops = array('classname' => 'widget_news', 'description' => esc_html__( "The most recent posts on your site", 'charitxa') );
        parent::__construct('recent-posts', esc_html__('Charitxa Recent Posts', 'charitxa'), $widget_ops);
        $this->alt_option_name = 'widget_news';

    }

    function widget($args, $instance) {
        $cache = wp_cache_get('charitxa_widget_newss', 'widget');

        if ( !is_array($cache) )
            $cache = array();

        if ( ! isset( $args['widget_id'] ) )
            $args['widget_id'] = $this->id;

        if ( isset( $cache[ $args['widget_id'] ] ) ) {
            echo wp_specialchars_decode(wp_kses_post($cache[ $args['widget_id'] ]));
            return;
        }

        ob_start();
        extract($args);

        $title = ( ! empty( $instance['title'] ) ) ? $instance['title'] : esc_html__( '', 'charitxa' );
        $title = apply_filters( 'widget_title', $title, $instance, $this->id_base );
        $number = ( ! empty( $instance['number'] ) ) ? absint( $instance['number'] ) : 10;
        if ( ! $number )
            $number = 10;
        $show_date = isset( $instance['show_date'] ) ? $instance['show_date'] : false;

        $r = new WP_Query( apply_filters( 'widget_posts_args', array( 'posts_per_page' => $number, 'no_found_rows' => true, 'post_status' => 'publish', 'ignore_sticky_posts' => true ) ) );
        if ($r->have_posts()) :
?>
        <?php echo wp_specialchars_decode(wp_kses_post($before_widget),ENT_QUOTES); ?>
        <?php if ( $title ) echo wp_specialchars_decode(wp_kses_post($before_title),ENT_QUOTES) . wp_kses_post($title) . wp_specialchars_decode(wp_kses_post($after_title),ENT_QUOTES); ?>
        <ul class="widget-content">
        <?php while ( $r->have_posts() ) : $r->the_post(); ?>
        <?php $featured_image_2 = get_post_meta(get_the_ID(),'_cmb_featured_image_2', true); ?>
        <?php $title_2 = get_post_meta(get_the_ID(),'_cmb_title_2', true); ?>
            <li>
                <?php if(isset($featured_image_2) && $featured_image_2 != '') { ?>
                <div class="image">
                    <img src="<?php echo wp_get_attachment_url($featured_image_2);?>" alt="<?php the_title_attribute(); ?>">
                </div>   
                <?php } elseif ( has_post_thumbnail() ) {  ?> 
                <div class="image">
                    <img src="<?php echo wp_get_attachment_url(get_post_thumbnail_id());?>" alt="<?php the_title_attribute(); ?>">
                </div>
                <?php } ?>
                <div class="content">
                    <h6><a href="<?php the_permalink(); ?>"><?php echo wp_kses_post($title_2);?></a></h6>
                    <i class="far fa-calendar-alt"></i><span class="date"><?php the_time(get_option( 'date_format' ));?></span>
                </div>
            </li>
        <?php endwhile; ?>
        </ul>
        <?php echo wp_specialchars_decode(wp_kses_post($after_widget)); ?>
<?php
        // Reset the global $the_post as this query will have stomped on it
        wp_reset_postdata();

        endif;

        $cache[$args['widget_id']] = ob_get_flush();
        wp_cache_set('charitxa_widget_newss', $cache, 'widget');
    }

    function update( $new_instance, $old_instance ) {
        $instance = $old_instance;
        $instance['title'] = strip_tags($new_instance['title']);
        $instance['number'] = (int) $new_instance['number'];
        $instance['show_date'] = (bool) $new_instance['show_date'];

        $alloptions = wp_cache_get( 'alloptions', 'options' );
        if ( isset($alloptions['widget_news']) )
            delete_option('widget_news');

        return $instance;
    }


    function form( $instance ) {
        $title     = isset( $instance['title'] ) ? wp_kses_post( $instance['title'] ) : '';
        $number    = isset( $instance['number'] ) ? absint( $instance['number'] ) : 3;
        $show_date = isset( $instance['show_date'] ) ? (bool) $instance['show_date'] : false;
?>
        <p><label for="<?php echo wp_kses_post($this->get_field_id( 'title' )); ?>"><?php esc_html_e( 'Title:', 'charitxa' ); ?></label>
        <input class="widefat" id="<?php echo wp_kses_post($this->get_field_id( 'title' )); ?>" name="<?php echo wp_kses_post($this->get_field_name( 'title' )); ?>" type="text" value="<?php echo wp_kses_post($title); ?>" /></p>

        <p><label for="<?php echo wp_kses_post($this->get_field_id( 'number' )); ?>"><?php esc_html_e( 'Number of posts to show:', 'charitxa' ); ?></label>
        <input id="<?php echo wp_kses_post($this->get_field_id( 'number' )); ?>" name="<?php echo wp_kses_post($this->get_field_name( 'number' )); ?>" type="text" value="<?php echo wp_kses_post($number); ?>" size="3" /></p>

        <p><input class="checkbox" type="checkbox" <?php checked( $show_date ); ?> id="<?php echo wp_kses_post($this->get_field_id( 'show_date' )); ?>" name="<?php echo wp_kses_post($this->get_field_name( 'show_date' )); ?>" />
        <label for="<?php echo wp_kses_post($this->get_field_id( 'show_date' )); ?>"><?php esc_html_e( 'Display post date?', 'charitxa' ); ?></label></p>
<?php
    }
}

class charitxa_widget_search extends WP_Widget {

    function __construct() {
        $widget_ops = array('classname' => 'widget_search', 'description' => esc_html__( "Search on your site", 'charitxa') );
        parent::__construct('search', esc_html__('Charitxa Search', 'charitxa'), $widget_ops);
        $this->alt_option_name = 'widget_search';

    }

    function widget($args, $instance) {
        $cache = wp_cache_get('charitxa_widget_search', 'widget');

        if ( !is_array($cache) )
            $cache = array();

        if ( ! isset( $args['widget_id'] ) )
            $args['widget_id'] = $this->id;

        if ( isset( $cache[ $args['widget_id'] ] ) ) {
            echo wp_specialchars_decode(wp_kses_post($cache[ $args['widget_id'] ]));
            return;
        }

        ob_start();
        extract($args);

        $title = ( ! empty( $instance['title'] ) ) ? $instance['title'] : esc_html__( '', 'charitxa' );
        $title = apply_filters( 'widget_title', $title, $instance, $this->id_base );

        ?>
        <?php echo wp_specialchars_decode(wp_kses_post($before_widget),ENT_QUOTES); ?>
         <div class="search">
            <h5 class="work-title">Search</h5>
            <form class="search-form">
                <input type="text" class="input-style-2" name="s" id="s" placeholder="<?php echo wp_kses_post__('Search', 'charitxa' );?>" required>
                <button class="btn-sub" type="submit">
                    <i class="icofont-search"></i>
                </button>
            </form>
        </div>
        <?php echo wp_specialchars_decode(wp_kses_post($after_widget)); ?>
    <?php
        // Reset the global $the_post as this query will have stomped on it
   

        $cache[$args['widget_id']] = ob_get_flush();
        wp_cache_set('charitxa_widget_search', $cache, 'widget');
    }

    function update( $new_instance, $old_instance ) {
        $instance = $old_instance;
        $instance['title'] = strip_tags($new_instance['title']);

        $alloptions = wp_cache_get( 'alloptions', 'options' );
        if ( isset($alloptions['widget_search']) )
            delete_option('widget_search');

        return $instance;
    }

    function form( $instance ) {
        $title     = isset( $instance['title'] ) ? wp_kses_post( $instance['title'] ) : '';
?>
        <p><label for="<?php echo wp_kses_post($this->get_field_id( 'title' )); ?>"><?php esc_html_e( 'Title:', 'charitxa' ); ?></label>
        <input class="" id="<?php echo wp_kses_post($this->get_field_id( 'title' )); ?>" name="<?php echo wp_kses_post($this->get_field_name( 'title' )); ?>" type="text" value="<?php echo wp_kses_post($title); ?>" /></p>

        
<?php
    }
}


function charitxa_register_custom_widgets() {
    register_widget( 'charitxa_widget_search' );
    register_widget( 'charitxa_widget_newss' );
}
add_action( 'widgets_init', 'charitxa_register_custom_widgets' );    