<?php
class charitxa_service_widget_news extends WP_Widget {

    function __construct() {
        $widget_ops = array('classname' => 'widget_service_news', 'description' => esc_html__( "The most recent posts on your site", 'charitxa') );
        parent::__construct('recent-service', esc_html__('Charitxa Recent Servies', 'charitxa'), $widget_ops);
        $this->alt_option_name = 'widget_service_news';

    }

    function widget($args, $instance) {
        $cache = wp_cache_get('charitxa_service_widget_news', 'widget');

        if ( !is_array($cache) )
            $cache = array();

        if ( ! isset( $args['widget_id'] ) )
            $args['widget_id'] = $this->id;

        if ( isset( $cache[ $args['widget_id'] ] ) ) {
            echo wp_specialchars_decode(wp_kses_post($cache[ $args['widget_id'] ]));
            return;
        }

        ob_start();
        extract($args);

        $title = ( ! empty( $instance['title'] ) ) ? $instance['title'] : esc_html__( '', 'charitxa' );
        $title = apply_filters( 'widget_title', $title, $instance, $this->id_base );
        $number = ( ! empty( $instance['number'] ) ) ? absint( $instance['number'] ) : 10;

        $args = array(   
          'posts_per_page' => $instance['number'], 
          'post_type' => 'service',
        ); 
        $wp_query = new \WP_Query($args); 
?>
        <?php echo wp_specialchars_decode(wp_kses_post($before_widget),ENT_QUOTES); ?>
        <?php if ( $title ) echo wp_specialchars_decode(wp_kses_post($before_title),ENT_QUOTES) . wp_kses_post($title) . wp_specialchars_decode(wp_kses_post($after_title),ENT_QUOTES); ?>
          <ul class="widget-content list-style-three">
            <?php while ($wp_query -> have_posts()): $wp_query -> the_post();
              $title2 = get_the_title()                 
            ?> 
            <li><a href="<?php the_permalink();?>"><?php echo wp_kses_post($title2);?></a></li>
            <?php endwhile; ?>
          </ul>     
      
        <?php echo wp_specialchars_decode(wp_kses_post($after_widget)); ?>
<?php
        // Reset the global $the_post as this query will have stomped on it
        wp_reset_postdata();


        $cache[$args['widget_id']] = ob_get_flush();
        wp_cache_set('charitxa_service_widget_news', $cache, 'widget');
    }

    function update( $new_instance, $old_instance ) {
        $instance = $old_instance;
        $instance['title'] = strip_tags($new_instance['title']);
        $instance['number'] = (int) $new_instance['number'];
        $instance['show_date'] = (bool) $new_instance['show_date'];

        $alloptions = wp_cache_get( 'alloptions', 'options' );
        if ( isset($alloptions['widget_news']) )
            delete_option('widget_news');

        return $instance;
    }


    function form( $instance ) {
        $title     = isset( $instance['title'] ) ? wp_kses_post( $instance['title'] ) : '';
        $number    = isset( $instance['number'] ) ? absint( $instance['number'] ) : 3;
        $show_date = isset( $instance['show_date'] ) ? (bool) $instance['show_date'] : false;
?>
        <p><label for="<?php echo wp_kses_post($this->get_field_id( 'title' )); ?>"><?php esc_html_e( 'Title:', 'charitxa' ); ?></label>
        <input class="widefat" id="<?php echo wp_kses_post($this->get_field_id( 'title' )); ?>" name="<?php echo wp_kses_post($this->get_field_name( 'title' )); ?>" type="text" value="<?php echo wp_kses_post($title); ?>" /></p>

        <p><label for="<?php echo wp_kses_post($this->get_field_id( 'number' )); ?>"><?php esc_html_e( 'Number of posts to show:', 'charitxa' ); ?></label>
        <input id="<?php echo wp_kses_post($this->get_field_id( 'number' )); ?>" name="<?php echo wp_kses_post($this->get_field_name( 'number' )); ?>" type="text" value="<?php echo wp_kses_post($number); ?>" size="3" /></p>
<?php
    }
}
function charitxa_register_service_custom_widgets() {
    register_widget( 'charitxa_service_widget_news' );
}
add_action( 'widgets_init', 'charitxa_register_service_custom_widgets' ); 