<?php
/**
 * Sidebar widget widget class
 *
 * @since 2.8.0
 */
class charitxa_donate extends WP_Widget {

    function __construct() {
        $widget_ops = array('classname' => 'donate', 'description' => esc_html__( "Sidebar Donate", 'charitxa') );
        parent::__construct('sidebar-donate', esc_html__('Sidebar Donate', 'charitxa'), $widget_ops);
        $this->alt_option_name = 'donate';
    }

    function widget($args, $instance) {
        $cache = wp_cache_get('charitxa_donate', 'widget');

        if ( !is_array($cache) )
            $cache = array();

        if ( ! isset( $args['widget_id'] ) )
            $args['widget_id'] = $this->id;

        if ( isset( $cache[ $args['widget_id'] ] ) ) {
            echo wp_specialchars_decode(wp_kses_post($cache[ $args['widget_id'] ]));
            return;
        }

        ob_start();
        extract($args);
        $title = ( ! empty( $instance['title'] ) ) ? $instance['title'] : esc_html__( '', 'charitxa' );
        $subtitle = ( ! empty( $instance['subtitle'] ) ) ? $instance['subtitle'] : esc_html__( '', 'charitxa' );
        $text = ( ! empty( $instance['text'] ) ) ? $instance['text'] : esc_html__( '', 'charitxa' );
        $goal = ( ! empty( $instance['goal'] ) ) ? $instance['goal'] : esc_html__( '', 'charitxa' );
        $goal_number = ( ! empty( $instance['goal_number'] ) ) ? $instance['goal_number'] : esc_html__( '', 'charitxa' );
        $raised = ( ! empty( $instance['raised'] ) ) ? $instance['raised'] : esc_html__( '', 'charitxa' );
        $raised_number = ( ! empty( $instance['raised_number'] ) ) ? $instance['raised_number'] : esc_html__( '', 'charitxa' );
        $percent_raised = ( ! empty( $instance['percent_raised'] ) ) ? $instance['percent_raised'] : esc_html__( '', 'charitxa' );
        $button = ( ! empty( $instance['button'] ) ) ? $instance['button'] : esc_html__( '', 'charitxa' );
        ?>
        <?php echo wp_specialchars_decode(wp_kses_post($before_widget),ENT_QUOTES); ?>
        <div class="priorities-details-campaign">
            <div class="campaign-content bgc-yellow">
                <div class="section-title">
                    <?php if(isset($subtitle) && $subtitle != ''){?>
                    <span class="sub-title"><i><b><?php echo wp_kses_post($subtitle); ?></b></i></span>
                    <?php } ?>
                    <?php if(isset($title) && $title != ''){?>
                    <h3><?php echo wp_kses_post($title); ?></h3>
                    <?php } ?>
                    <?php if(isset($text) && $text != ''){?>
                    <p><?php echo wp_kses_post($text); ?></p>
                    <?php } ?>
                </div>
                <div class="cause-price">
                    <span><?php echo wp_kses_post($goal); ?> <b><?php echo wp_kses_post($goal_number); ?></b></span>
                    <span><?php echo wp_kses_post($raised); ?> <b><?php echo wp_kses_post($raised_number); ?></b></span>
                </div>
                <div class="progress">
                  <div class="progress-bar" style="width: <?php echo wp_kses_post($percent_raised); ?>%"></div>
                  <span><?php echo wp_kses_post($percent_raised); ?>%</span>
                </div>
            </div>
            <a href="#" class="theme-btn style-three w-100 d-flex" data-bs-toggle="modal" data-bs-target="#donateModal">
                <span class="btn-text normal"><i class="fas fa-heart"></i> <?php echo wp_kses_post($button); ?></span>
                <span class="btn-text hover"><i class="fas fa-heart"></i> <?php echo wp_kses_post($button); ?></span>
            </a>
        </div>
        <?php echo wp_specialchars_decode(wp_kses_post($after_widget)); ?>
    <?php
        // Reset the global $the_post as this query will have stomped on it
        $cache[$args['widget_id']] = ob_get_flush();
        wp_cache_set('charitxa_donate', $cache, 'widget');
    }

    function update( $new_instance, $old_instance ) {
        $instance = $old_instance;
        $instance['title'] = strip_tags($new_instance['title']);
        $instance['subtitle'] = strip_tags($new_instance['subtitle']);
        $instance['text'] = strip_tags($new_instance['text']);
        $instance['percent_raised'] = strip_tags($new_instance['percent_raised']);
        $instance['button'] = strip_tags($new_instance['button']);
        $instance['goal'] = strip_tags($new_instance['goal']);
        $instance['goal_number'] = strip_tags($new_instance['goal_number']);
        $instance['raised'] = strip_tags($new_instance['raised']);
        $instance['raised_number'] = strip_tags($new_instance['raised_number']);
        
 
        $alloptions = wp_cache_get( 'alloptions', 'options' );
        if ( isset($alloptions['donate']) )
            delete_option('donate');
        return $instance;
    }

    function form( $instance ) {   
        $title     = isset( $instance['title'] ) ? wp_kses_post( $instance['title'] ) : '';
        $subtitle     = isset( $instance['subtitle'] ) ? wp_kses_post( $instance['subtitle'] ) : '';   
        $text     = isset( $instance['text'] ) ? wp_kses_post( $instance['text'] ) : '';   
        $percent_raised     = isset( $instance['percent_raised'] ) ? wp_kses_post( $instance['percent_raised'] ) : '';
        $button     = isset( $instance['button'] ) ? wp_kses_post( $instance['button'] ) : '';
        $goal     = isset( $instance['goal'] ) ? wp_kses_post( $instance['goal'] ) : '';
        $goal_number     = isset( $instance['goal_number'] ) ? wp_kses_post( $instance['goal_number'] ) : '';
        $raised     = isset( $instance['raised'] ) ? wp_kses_post( $instance['raised'] ) : '';
        $raised_number     = isset( $instance['raised_number'] ) ? wp_kses_post( $instance['raised_number'] ) : '';
        
?>
    <p><label for="<?php echo wp_kses_post($this->get_field_id( 'subtitle' )); ?>"><?php esc_html_e( 'Subtitle:', 'charitxa' ); ?></label>
    <input class="widefat" id="<?php echo wp_kses_post($this->get_field_id( 'subtitle' )); ?>" name="<?php echo wp_kses_post($this->get_field_name( 'subtitle' )); ?>" type="text" value="<?php echo wp_kses_post($subtitle); ?>"/></p>

    <p><label for="<?php echo wp_kses_post($this->get_field_id( 'title' )); ?>"><?php esc_html_e( 'Title:', 'charitxa' ); ?></label>
    <input class="widefat" id="<?php echo wp_kses_post($this->get_field_id( 'title' )); ?>" name="<?php echo wp_kses_post($this->get_field_name( 'title' )); ?>" type="text" value="<?php echo wp_kses_post($title); ?>"/></p>

    <p><label for="<?php echo wp_kses_post($this->get_field_id( 'text' )); ?>"><?php esc_html_e( 'Text:', 'charitxa' ); ?></label>
    <input class="widefat" id="<?php echo wp_kses_post($this->get_field_id( 'text' )); ?>" name="<?php echo wp_kses_post($this->get_field_name( 'text' )); ?>" type="text" value="<?php echo wp_kses_post($text); ?>"/></p>

    <p><label for="<?php echo wp_kses_post($this->get_field_id( 'goal' )); ?>"><?php esc_html_e( 'Goal Text:', 'charitxa' ); ?></label>
    <input class="widefat" id="<?php echo wp_kses_post($this->get_field_id( 'goal' )); ?>" name="<?php echo wp_kses_post($this->get_field_name( 'goal' )); ?>" type="text" value="<?php echo wp_kses_post($goal); ?>"/></p>
    <p><label for="<?php echo wp_kses_post($this->get_field_id( 'goal_number' )); ?>"><?php esc_html_e( 'Goal Number:', 'charitxa' ); ?></label>
    <input class="widefat" id="<?php echo wp_kses_post($this->get_field_id( 'goal_number' )); ?>" name="<?php echo wp_kses_post($this->get_field_name( 'goal_number' )); ?>" type="text" value="<?php echo wp_kses_post($goal_number); ?>"/></p>

    <p><label for="<?php echo wp_kses_post($this->get_field_id( 'raised' )); ?>"><?php esc_html_e( 'Raised Text:', 'charitxa' ); ?></label>
    <input class="widefat" id="<?php echo wp_kses_post($this->get_field_id( 'raised' )); ?>" name="<?php echo wp_kses_post($this->get_field_name( 'raised' )); ?>" type="text" value="<?php echo wp_kses_post($raised); ?>"/></p>
    <p><label for="<?php echo wp_kses_post($this->get_field_id( 'raised_number' )); ?>"><?php esc_html_e( 'Raised Number:', 'charitxa' ); ?></label>
    <input class="widefat" id="<?php echo wp_kses_post($this->get_field_id( 'raised_number' )); ?>" name="<?php echo wp_kses_post($this->get_field_name( 'raised_number' )); ?>" type="text" value="<?php echo wp_kses_post($raised_number); ?>"/></p>

    <p><label for="<?php echo wp_kses_post($this->get_field_id( 'percent_raised' )); ?>"><?php esc_html_e( 'Percent Raised:', 'charitxa' ); ?></label>
    <input class="widefat" id="<?php echo wp_kses_post($this->get_field_id( 'percent_raised' )); ?>" name="<?php echo wp_kses_post($this->get_field_name( 'percent_raised' )); ?>" type="text" value="<?php echo wp_kses_post($percent_raised); ?>"/></p>
    <p><label for="<?php echo wp_kses_post($this->get_field_id( 'button' )); ?>"><?php esc_html_e( 'Button:', 'charitxa' ); ?></label>
    <input class="widefat" id="<?php echo wp_kses_post($this->get_field_id( 'button' )); ?>" name="<?php echo wp_kses_post($this->get_field_name( 'button' )); ?>" type="text" value="<?php echo wp_kses_post($button); ?>"/></p>
<?php
    }
}
function charitxa_register_custom_donate() {
    register_widget( 'charitxa_donate' );
}
add_action( 'widgets_init', 'charitxa_register_custom_donate' );
